/// <reference types="react" />
import * as react from 'react';
import { SVGAttributes as SVGAttributes$1, CSSProperties, PropsWithoutRef, RefAttributes, ReactHTML, DetailedHTMLFactory, HTMLAttributes, useEffect, RefObject as RefObject$1 } from 'react';
import * as react_jsx_runtime from 'react/jsx-runtime';

type EasingFunction = (v: number) => number;
type EasingModifier = (easing: EasingFunction) => EasingFunction;
type BezierDefinition = [number, number, number, number];
type EasingDefinition = BezierDefinition | "linear" | "easeIn" | "easeOut" | "easeInOut" | "circIn" | "circOut" | "circInOut" | "backIn" | "backOut" | "backInOut" | "anticipate";
/**
 * The easing function to use. Set as one of:
 *
 * - The name of an in-built easing function.
 * - An array of four numbers to define a cubic bezier curve.
 * - An easing function, that accepts and returns a progress value between `0` and `1`.
 *
 * @public
 */
type Easing = EasingDefinition | EasingFunction;

type GenericKeyframesTarget<V> = [null, ...V[]] | V[];
/**
 * @public
 */
type ResolvedKeyframesTarget = GenericKeyframesTarget<number> | GenericKeyframesTarget<string>;
/**
 * @public
 */
type KeyframesTarget = ResolvedKeyframesTarget | GenericKeyframesTarget<CustomValueType>;
/**
 * @public
 */
type ResolvedSingleTarget = string | number;
/**
 * @public
 */
type SingleTarget = ResolvedSingleTarget | CustomValueType;
/**
 * @public
 */
type ResolvedValueTarget = ResolvedSingleTarget | ResolvedKeyframesTarget;
/**
 * @public
 */
type ValueTarget = SingleTarget | KeyframesTarget;
/**
 * Options for orchestrating the timing of animations.
 *
 * @public
 */
interface Orchestration {
    /**
     * Delay the animation by this duration (in seconds). Defaults to `0`.
     *
     * @remarks
     * ```javascript
     * const transition = {
     *   delay: 0.2
     * }
     * ```
     *
     * @public
     */
    delay?: number;
    /**
     * Describes the relationship between the transition and its children. Set
     * to `false` by default.
     *
     * @remarks
     * When using variants, the transition can be scheduled in relation to its
     * children with either `"beforeChildren"` to finish this transition before
     * starting children transitions, `"afterChildren"` to finish children
     * transitions before starting this transition.
     *
     * ```jsx
     * const list = {
     *   hidden: {
     *     opacity: 0,
     *     transition: { when: "afterChildren" }
     *   }
     * }
     *
     * const item = {
     *   hidden: {
     *     opacity: 0,
     *     transition: { duration: 2 }
     *   }
     * }
     *
     * return (
     *   <motion.ul variants={list} animate="hidden">
     *     <motion.li variants={item} />
     *     <motion.li variants={item} />
     *   </motion.ul>
     * )
     * ```
     *
     * @public
     */
    when?: false | "beforeChildren" | "afterChildren" | string;
    /**
     * When using variants, children animations will start after this duration
     * (in seconds). You can add the `transition` property to both the `Frame` and the `variant` directly. Adding it to the `variant` generally offers more flexibility, as it allows you to customize the delay per visual state.
     *
     * ```jsx
     * const container = {
     *   hidden: { opacity: 0 },
     *   show: {
     *     opacity: 1,
     *     transition: {
     *       delayChildren: 0.5
     *     }
     *   }
     * }
     *
     * const item = {
     *   hidden: { opacity: 0 },
     *   show: { opacity: 1 }
     * }
     *
     * return (
     *   <motion.ul
     *     variants={container}
     *     initial="hidden"
     *     animate="show"
     *   >
     *     <motion.li variants={item} />
     *     <motion.li variants={item} />
     *   </motion.ul>
     * )
     * ```
     *
     * @public
     */
    delayChildren?: number;
    /**
     * When using variants, animations of child components can be staggered by this
     * duration (in seconds).
     *
     * For instance, if `staggerChildren` is `0.01`, the first child will be
     * delayed by `0` seconds, the second by `0.01`, the third by `0.02` and so
     * on.
     *
     * The calculated stagger delay will be added to `delayChildren`.
     *
     * ```jsx
     * const container = {
     *   hidden: { opacity: 0 },
     *   show: {
     *     opacity: 1,
     *     transition: {
     *       staggerChildren: 0.5
     *     }
     *   }
     * }
     *
     * const item = {
     *   hidden: { opacity: 0 },
     *   show: { opacity: 1 }
     * }
     *
     * return (
     *   <motion.ol
     *     variants={container}
     *     initial="hidden"
     *     animate="show"
     *   >
     *     <motion.li variants={item} />
     *     <motion.li variants={item} />
     *   </motion.ol>
     * )
     * ```
     *
     * @public
     */
    staggerChildren?: number;
    /**
     * The direction in which to stagger children.
     *
     * A value of `1` staggers from the first to the last while `-1`
     * staggers from the last to the first.
     *
     * ```jsx
     * const container = {
     *   hidden: { opacity: 0 },
     *   show: {
     *     opacity: 1,
     *     transition: {
     *       staggerChildren: 0.5,
     *       staggerDirection: -1
     *     }
     *   }
     * }
     *
     * const item = {
     *   hidden: { opacity: 0 },
     *   show: { opacity: 1 }
     * }
     *
     * return (
     *   <motion.ul
     *     variants={container}
     *     initial="hidden"
     *     animate="show"
     *   >
     *     <motion.li variants={item} size={50} />
     *     <motion.li variants={item} size={50} />
     *   </motion.ul>
     * )
     * ```
     *
     * @public
     */
    staggerDirection?: number;
}
interface Repeat {
    /**
     * The number of times to repeat the transition. Set to `Infinity` for perpetual repeating.
     *
     * Without setting `repeatType`, this will loop the animation.
     *
     * ```jsx
     * <motion.div
     *   animate={{ rotate: 180 }}
     *   transition={{ repeat: Infinity, duration: 2 }}
     * />
     * ```
     *
     * @public
     */
    repeat?: number;
    /**
     * How to repeat the animation. This can be either:
     *
     * "loop": Repeats the animation from the start
     *
     * "reverse": Alternates between forward and backwards playback
     *
     * "mirror": Switches `from` and `to` alternately
     *
     * ```jsx
     * <motion.div
     *   animate={{ rotate: 180 }}
     *   transition={{
     *     repeat: 1,
     *     repeatType: "reverse",
     *     duration: 2
     *   }}
     * />
     * ```
     *
     * @public
     */
    repeatType?: "loop" | "reverse" | "mirror";
    /**
     * When repeating an animation, `repeatDelay` will set the
     * duration of the time to wait, in seconds, between each repetition.
     *
     * ```jsx
     * <motion.div
     *   animate={{ rotate: 180 }}
     *   transition={{ repeat: Infinity, repeatDelay: 1 }}
     * />
     * ```
     *
     * @public
     */
    repeatDelay?: number;
}
/**
 * An animation that animates between two or more values over a specific duration of time.
 * This is the default animation for non-physical values like `color` and `opacity`.
 *
 * @public
 */
interface Tween extends Repeat {
    /**
     * Set `type` to `"tween"` to use a duration-based tween animation.
     * If any non-orchestration `transition` values are set without a `type` property,
     * this is used as the default animation.
     *
     * ```jsx
     * <motion.path
     *   animate={{ pathLength: 1 }}
     *   transition={{ duration: 2, type: "tween" }}
     * />
     * ```
     *
     * @public
     */
    type?: "tween";
    /**
     * The duration of the tween animation. Set to `0.3` by default, 0r `0.8` if animating a series of keyframes.
     *
     * ```jsx
     * const variants = {
     *   visible: {
     *     opacity: 1,
     *     transition: { duration: 2 }
     *   }
     * }
     * ```
     *
     * @public
     */
    duration?: number;
    /**
     * The easing function to use. Set as one of the below.
     *
     * - The name of an existing easing function.
     *
     * - An array of four numbers to define a cubic bezier curve.
     *
     * - An easing function, that accepts and returns a value `0-1`.
     *
     * If the animating value is set as an array of multiple values for a keyframes
     * animation, `ease` can be set as an array of easing functions to set different easings between
     * each of those values.
     *
     *
     * ```jsx
     * <motion.div
     *   animate={{ opacity: 0 }}
     *   transition={{ ease: [0.17, 0.67, 0.83, 0.67] }}
     * />
     * ```
     *
     * @public
     */
    ease?: Easing | Easing[];
    /**
     * When animating keyframes, `times` can be used to determine where in the animation each keyframe is reached.
     * Each value in `times` is a value between `0` and `1`, representing `duration`.
     *
     * There must be the same number of `times` as there are keyframes.
     * Defaults to an array of evenly-spread durations.
     *
     * ```jsx
     * <motion.div
     *   animate={{ scale: [0, 1, 0.5, 1] }}
     *   transition={{ times: [0, 0.1, 0.9, 1] }}
     * />
     * ```
     *
     * @public
     */
    times?: number[];
    /**
     * When animating keyframes, `easings` can be used to define easing functions between each keyframe. This array should be one item fewer than the number of keyframes, as these easings apply to the transitions between the keyframes.
     *
     * ```jsx
     * <motion.div
     *   animate={{ backgroundColor: ["#0f0", "#00f", "#f00"] }}
     *   transition={{ easings: ["easeIn", "easeOut"] }}
     * />
     * ```
     *
     * @public
     */
    easings?: Easing[];
    /**
     * The value to animate from.
     * By default, this is the current state of the animating value.
     *
     * ```jsx
     * <motion.div
     *   animate={{ rotate: 180 }}
     *   transition={{ from: 90, duration: 2 }}
     * />
     * ```
     *
     * @public
     */
    from?: number | string;
}
/**
 * An animation that simulates spring physics for realistic motion.
 * This is the default animation for physical values like `x`, `y`, `scale` and `rotate`.
 *
 * @public
 */
interface Spring extends Repeat {
    /**
     * Set `type` to `"spring"` to animate using spring physics for natural
     * movement. Type is set to `"spring"` by default.
     *
     * ```jsx
     * <motion.div
     *   animate={{ rotate: 180 }}
     *   transition={{ type: 'spring' }}
     * />
     * ```
     *
     * @public
     */
    type: "spring";
    /**
     * Stiffness of the spring. Higher values will create more sudden movement.
     * Set to `100` by default.
     *
     * ```jsx
     * <motion.section
     *   animate={{ rotate: 180 }}
     *   transition={{ type: 'spring', stiffness: 50 }}
     * />
     * ```
     *
     * @public
     */
    stiffness?: number;
    /**
     * Strength of opposing force. If set to 0, spring will oscillate
     * indefinitely. Set to `10` by default.
     *
     * ```jsx
     * <motion.a
     *   animate={{ rotate: 180 }}
     *   transition={{ type: 'spring', damping: 300 }}
     * />
     * ```
     *
     * @public
     */
    damping?: number;
    /**
     * Mass of the moving object. Higher values will result in more lethargic
     * movement. Set to `1` by default.
     *
     * ```jsx
     * <motion.feTurbulence
     *   animate={{ baseFrequency: 0.5 } as any}
     *   transition={{ type: "spring", mass: 0.5 }}
     * />
     * ```
     *
     * @public
     */
    mass?: number;
    /**
     * The duration of the animation, defined in seconds. Spring animations can be a maximum of 10 seconds.
     *
     * If `bounce` is set, this defaults to `0.8`.
     *
     * Note: `duration` and `bounce` will be overridden if `stiffness`, `damping` or `mass` are set.
     *
     * ```jsx
     * <motion.div
     *   animate={{ x: 100 }}
     *   transition={{ type: "spring", duration: 0.8 }}
     * />
     * ```
     *
     * @public
     */
    duration?: number;
    /**
     * `bounce` determines the "bounciness" of a spring animation.
     *
     * `0` is no bounce, and `1` is extremely bouncy.
     *
     * If `duration` is set, this defaults to `0.25`.
     *
     * Note: `bounce` and `duration` will be overridden if `stiffness`, `damping` or `mass` are set.
     *
     * ```jsx
     * <motion.div
     *   animate={{ x: 100 }}
     *   transition={{ type: "spring", bounce: 0.25 }}
     * />
     * ```
     *
     * @public
     */
    bounce?: number;
    /**
     * End animation if absolute speed (in units per second) drops below this
     * value and delta is smaller than `restDelta`. Set to `0.01` by default.
     *
     * ```jsx
     * <motion.div
     *   animate={{ rotate: 180 }}
     *   transition={{ type: 'spring', restSpeed: 0.5 }}
     * />
     * ```
     *
     * @public
     */
    restSpeed?: number;
    /**
     * End animation if distance is below this value and speed is below
     * `restSpeed`. When animation ends, spring gets “snapped” to. Set to
     * `0.01` by default.
     *
     * ```jsx
     * <motion.div
     *   animate={{ rotate: 180 }}
     *   transition={{ type: 'spring', restDelta: 0.5 }}
     * />
     * ```
     *
     * @public
     */
    restDelta?: number;
    /**
     * The value to animate from.
     * By default, this is the initial state of the animating value.
     *
     * ```jsx
     * <motion.div
     *   animate={{ rotate: 180 }}
     *   transition={{ type: 'spring', from: 90 }}
     * />
     * ```
     *
     * @public
     */
    from?: number | string;
    /**
     * The initial velocity of the spring. By default this is the current velocity of the component.
     *
     * ```jsx
     * <motion.div
     *   animate={{ rotate: 180 }}
     *   transition={{ type: 'spring', velocity: 2 }}
     * />
     * ```
     *
     * @public
     */
    velocity?: number;
}
/**
 * An animation that decelerates a value based on its initial velocity,
 * usually used to implement inertial scrolling.
 *
 * Optionally, `min` and `max` boundaries can be defined, and inertia
 * will snap to these with a spring animation.
 *
 * This animation will automatically precalculate a target value,
 * which can be modified with the `modifyTarget` property.
 *
 * This allows you to add snap-to-grid or similar functionality.
 *
 * Inertia is also the animation used for `dragTransition`, and can be configured via that prop.
 *
 * @public
 */
interface Inertia {
    /**
     * Set `type` to animate using the inertia animation. Set to `"tween"` by
     * default. This can be used for natural deceleration, like momentum scrolling.
     *
     * ```jsx
     * <motion.div
     *   animate={{ rotate: 180 }}
     *   transition={{ type: "inertia", velocity: 50 }}
     * />
     * ```
     *
     * @public
     */
    type: "inertia";
    /**
     * A function that receives the automatically-calculated target and returns a new one. Useful for snapping the target to a grid.
     *
     * ```jsx
     * <motion.div
     *   drag
     *   dragTransition={{
     *     power: 0,
     *     // Snap calculated target to nearest 50 pixels
     *     modifyTarget: target => Math.round(target / 50) * 50
     *   }}
     * />
     * ```
     *
     * @public
     */
    modifyTarget?(v: number): number;
    /**
     * If `min` or `max` is set, this affects the stiffness of the bounce
     * spring. Higher values will create more sudden movement. Set to `500` by
     * default.
     *
     * ```jsx
     * <motion.div
     *   drag
     *   dragTransition={{
     *     min: 0,
     *     max: 100,
     *     bounceStiffness: 100
     *   }}
     * />
     * ```
     *
     * @public
     */
    bounceStiffness?: number;
    /**
     * If `min` or `max` is set, this affects the damping of the bounce spring.
     * If set to `0`, spring will oscillate indefinitely. Set to `10` by
     * default.
     *
     * ```jsx
     * <motion.div
     *   drag
     *   dragTransition={{
     *     min: 0,
     *     max: 100,
     *     bounceDamping: 8
     *   }}
     * />
     * ```
     *
     * @public
     */
    bounceDamping?: number;
    /**
     * A higher power value equals a further target. Set to `0.8` by default.
     *
     * ```jsx
     * <motion.div
     *   drag
     *   dragTransition={{ power: 0.2 }}
     * />
     * ```
     *
     * @public
     */
    power?: number;
    /**
     * Adjusting the time constant will change the duration of the
     * deceleration, thereby affecting its feel. Set to `700` by default.
     *
     * ```jsx
     * <motion.div
     *   drag
     *   dragTransition={{ timeConstant: 200 }}
     * />
     * ```
     *
     * @public
     */
    timeConstant?: number;
    /**
     * End the animation if the distance to the animation target is below this value, and the absolute speed is below `restSpeed`.
     * When the animation ends, the value gets snapped to the animation target. Set to `0.01` by default.
     * Generally the default values provide smooth animation endings, only in rare cases should you need to customize these.
     *
     * ```jsx
     * <motion.div
     *   drag
     *   dragTransition={{ restDelta: 10 }}
     * />
     * ```
     *
     * @public
     */
    restDelta?: number;
    /**
     * Minimum constraint. If set, the value will "bump" against this value (or immediately spring to it if the animation starts as less than this value).
     *
     * ```jsx
     * <motion.div
     *   drag
     *   dragTransition={{ min: 0, max: 100 }}
     * />
     * ```
     *
     * @public
     */
    min?: number;
    /**
     * Maximum constraint. If set, the value will "bump" against this value (or immediately snap to it, if the initial animation value exceeds this value).
     *
     * ```jsx
     * <motion.div
     *   drag
     *   dragTransition={{ min: 0, max: 100 }}
     * />
     * ```
     *
     * @public
     */
    max?: number;
    /**
     * The value to animate from. By default, this is the current state of the animating value.
     *
     * ```jsx
     * <Frame
     *   drag
     *   dragTransition={{ from: 50 }}
     * />
     * ```
     *
     * @public
     */
    from?: number | string;
    /**
     * The initial velocity of the animation.
     * By default this is the current velocity of the component.
     *
     * ```jsx
     * <motion.div
     *   animate={{ rotate: 180 }}
     *   transition={{ type: 'inertia', velocity: 200 }}
     * />
     * ```
     *
     * @public
     */
    velocity?: number;
}
/**
 * Keyframes tweens between multiple `values`.
 *
 * These tweens can be arranged using the `duration`, `easings`, and `times` properties.
 */
interface Keyframes {
    /**
     * Set `type` to `"keyframes"` to animate using the keyframes animation.
     * Set to `"tween"` by default. This can be used to animate between a series of values.
     *
     * @public
     */
    type: "keyframes";
    /**
     * An array of numbers between 0 and 1, where `1` represents the `total` duration.
     *
     * Each value represents at which point during the animation each item in the animation target should be hit, so the array should be the same length as `values`.
     *
     * Defaults to an array of evenly-spread durations.
     *
     * @public
     */
    times?: number[];
    /**
     * An array of easing functions for each generated tween, or a single easing function applied to all tweens.
     *
     * This array should be one item less than `values`, as these easings apply to the transitions *between* the `values`.
     *
     * ```jsx
     * const transition = {
     *   backgroundColor: {
     *     type: 'keyframes',
     *     easings: ['circIn', 'circOut']
     *   }
     * }
     * ```
     *
     * @public
     */
    ease?: Easing | Easing[];
    /**
     * The total duration of the animation. Set to `0.3` by default.
     *
     * ```jsx
     * const transition = {
     *   type: "keyframes",
     *   duration: 2
     * }
     *
     * <Frame
     *   animate={{ opacity: 0 }}
     *   transition={transition}
     * />
     * ```
     *
     * @public
     */
    duration?: number;
    /**
     * @public
     */
    repeatDelay?: number;
}
/**
 * @public
 */
interface Just {
    /**
     * @public
     */
    type: "just";
}
/**
 * @public
 */
interface None {
    /**
     * Set `type` to `false` for an instant transition.
     *
     * @public
     */
    type: false;
}
/**
 * @public
 */
type PermissiveTransitionDefinition = {
    [key: string]: any;
};
/**
 * @public
 */
type TransitionDefinition = Tween | Spring | Keyframes | Inertia | Just | None | PermissiveTransitionDefinition;
type TransitionMap = Orchestration & TransitionDefinition & {
    [key: string]: TransitionDefinition;
};
/**
 * Transition props
 *
 * @public
 */
type Transition$1 = (Orchestration & Repeat & TransitionDefinition) | (Orchestration & Repeat & TransitionMap);
type Omit$1<T, K extends keyof T> = Pick<T, Exclude<keyof T, K>>;
type CSSPropertiesWithoutTransitionOrSingleTransforms = Omit$1<CSSProperties, "transition" | "rotate" | "scale" | "perspective">;
type SVGTransformAttributes = {
    attrX?: number;
    attrY?: number;
    attrScale?: number;
};
type TargetProperties = CSSPropertiesWithoutTransitionOrSingleTransforms & SVGAttributes$1<SVGElement> & SVGTransformAttributes & TransformProperties & CustomStyles & SVGPathProperties;
/**
 * @public
 */
type MakeCustomValueType<T> = {
    [K in keyof T]: T[K] | CustomValueType;
};
/**
 * @public
 */
type Target = MakeCustomValueType<TargetProperties>;
/**
 * @public
 */
type MakeKeyframes<T> = {
    [K in keyof T]: T[K] | T[K][] | [null, ...T[K][]];
};
/**
 * @public
 */
type TargetWithKeyframes = MakeKeyframes<Target>;
/**
 * An object that specifies values to animate to. Each value may be set either as
 * a single value, or an array of values.
 *
 * It may also option contain these properties:
 *
 * - `transition`: Specifies transitions for all or individual values.
 * - `transitionEnd`: Specifies values to set when the animation finishes.
 *
 * ```jsx
 * const target = {
 *   x: "0%",
 *   opacity: 0,
 *   transition: { duration: 1 },
 *   transitionEnd: { display: "none" }
 * }
 * ```
 *
 * @public
 */
type TargetAndTransition = TargetWithKeyframes & {
    transition?: Transition$1;
    transitionEnd?: Target;
};
type TargetResolver = (custom: any, current: Target, velocity: Target) => TargetAndTransition | string;
/**
 * @public
 */
type Variant = TargetAndTransition | TargetResolver;
/**
 * @public
 */
type Variants = {
    [key: string]: Variant;
};
/**
 * @public
 */
interface CustomValueType {
    mix: (from: any, to: any) => (p: number) => number | string;
    toValue: () => number | string;
}

interface Point {
    x: number;
    y: number;
}
interface Axis {
    min: number;
    max: number;
}
interface Box {
    x: Axis;
    y: Axis;
}
interface BoundingBox {
    top: number;
    right: number;
    bottom: number;
    left: number;
}
interface AxisDelta {
    translate: number;
    scale: number;
    origin: number;
    originPoint: number;
}
interface Delta {
    x: AxisDelta;
    y: AxisDelta;
}
type TransformPoint = (point: Point) => Point;

type ReducedMotionConfig = "always" | "never" | "user";
/**
 * @public
 */
interface MotionConfigContext {
    /**
     * Internal, exported only for usage in Framer
     */
    transformPagePoint: TransformPoint;
    /**
     * Internal. Determines whether this is a static context ie the Framer canvas. If so,
     * it'll disable all dynamic functionality.
     */
    isStatic: boolean;
    /**
     * Defines a new default transition for the entire tree.
     *
     * @public
     */
    transition?: Transition$1;
    /**
     * If true, will respect the device prefersReducedMotion setting by switching
     * transform animations off.
     *
     * @public
     */
    reducedMotion?: ReducedMotionConfig;
    /**
     * A custom `nonce` attribute used when wanting to enforce a Content Security Policy (CSP).
     * For more details see:
     * https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Security-Policy/style-src#unsafe_inline_styles
     *
     * @public
     */
    nonce?: string;
}
/**
 * @public
 */
declare const MotionConfigContext: react.Context<MotionConfigContext>;

interface VisualState<Instance, RenderState> {
    renderState: RenderState;
    latestValues: ResolvedValues$1;
    mount?: (instance: Instance) => void;
}
type UseVisualState<Instance, RenderState> = (props: MotionProps, isStatic: boolean) => VisualState<Instance, RenderState>;
interface UseVisualStateConfig<Instance, RenderState> {
    applyWillChange?: boolean;
    scrapeMotionValuesFromProps: ScrapeMotionValuesFromProps;
    createRenderState: () => RenderState;
    onMount?: (props: MotionProps, instance: Instance, visualState: VisualState<Instance, RenderState>) => void;
}
declare const makeUseVisualState: <I, RS>(config: UseVisualStateConfig<I, RS>) => UseVisualState<I, RS>;

/**
 * @public
 */
interface PresenceContextProps {
    id: string;
    isPresent: boolean;
    register: (id: string | number) => () => void;
    onExitComplete?: (id: string | number) => void;
    initial?: false | VariantLabels;
    custom?: any;
}
/**
 * @public
 */
declare const PresenceContext: react.Context<PresenceContextProps | null>;

type VariantStateContext = {
    initial?: string | string[];
    animate?: string | string[];
    exit?: string | string[];
    whileHover?: string | string[];
    whileDrag?: string | string[];
    whileFocus?: string | string[];
    whileTap?: string | string[];
};
type ScrapeMotionValuesFromProps = (props: MotionProps, prevProps: MotionProps, visualElement?: VisualElement) => {
    [key: string]: MotionValue | string | number;
};
type VisualElementOptions<Instance, RenderState = any> = {
    visualState: VisualState<Instance, RenderState>;
    parent?: VisualElement<unknown>;
    variantParent?: VisualElement<unknown>;
    presenceContext: PresenceContextProps | null;
    props: MotionProps;
    blockInitialAnimation?: boolean;
    reducedMotionConfig?: ReducedMotionConfig;
};
/**
 * A generic set of string/number values
 */
interface ResolvedValues$1 {
    [key: string]: string | number;
}
interface VisualElementEventCallbacks {
    BeforeLayoutMeasure: () => void;
    LayoutMeasure: (layout: Box, prevLayout?: Box) => void;
    LayoutUpdate: (layout: Axis, prevLayout: Axis) => void;
    Update: (latest: ResolvedValues$1) => void;
    AnimationStart: (definition: AnimationDefinition) => void;
    AnimationComplete: (definition: AnimationDefinition) => void;
    LayoutAnimationStart: () => void;
    LayoutAnimationComplete: () => void;
    SetAxisTarget: () => void;
    Unmount: () => void;
}
interface LayoutLifecycles {
    onBeforeLayoutMeasure?(box: Box): void;
    onLayoutMeasure?(box: Box, prevBox: Box): void;
}
interface AnimationLifecycles {
    /**
     * Callback with latest motion values, fired max once per frame.
     *
     * ```jsx
     * function onUpdate(latest) {
     *   console.log(latest.x, latest.opacity)
     * }
     *
     * <motion.div animate={{ x: 100, opacity: 0 }} onUpdate={onUpdate} />
     * ```
     */
    onUpdate?(latest: ResolvedValues$1): void;
    /**
     * Callback when animation defined in `animate` begins.
     *
     * The provided callback will be called with the triggering animation definition.
     * If this is a variant, it'll be the variant name, and if a target object
     * then it'll be the target object.
     *
     * This way, it's possible to figure out which animation has started.
     *
     * ```jsx
     * function onStart() {
     *   console.log("Animation started")
     * }
     *
     * <motion.div animate={{ x: 100 }} onAnimationStart={onStart} />
     * ```
     */
    onAnimationStart?(definition: AnimationDefinition): void;
    /**
     * Callback when animation defined in `animate` is complete.
     *
     * The provided callback will be called with the triggering animation definition.
     * If this is a variant, it'll be the variant name, and if a target object
     * then it'll be the target object.
     *
     * This way, it's possible to figure out which animation has completed.
     *
     * ```jsx
     * function onComplete() {
     *   console.log("Animation completed")
     * }
     *
     * <motion.div
     *   animate={{ x: 100 }}
     *   onAnimationComplete={definition => {
     *     console.log('Completed animating', definition)
     *   }}
     * />
     * ```
     */
    onAnimationComplete?(definition: AnimationDefinition): void;
}
type EventProps = LayoutLifecycles & AnimationLifecycles;
type CreateVisualElement<Instance> = (Component: string | React.ComponentType<React.PropsWithChildren<unknown>>, options: VisualElementOptions<Instance>) => VisualElement<Instance>;

declare class NodeStack {
    lead?: IProjectionNode;
    prevLead?: IProjectionNode;
    members: IProjectionNode[];
    add(node: IProjectionNode): void;
    remove(node: IProjectionNode): void;
    relegate(node: IProjectionNode): boolean;
    promote(node: IProjectionNode, preserveFollowOpacity?: boolean): void;
    exitAnimationComplete(): void;
    scheduleRender(): void;
    /**
     * Clear any leads that have been removed this render to prevent them from being
     * used in future animations and to prevent memory leaks
     */
    removeLeadSnapshot(): void;
}

interface WithDepth {
    depth: number;
}

declare class FlatTree {
    private children;
    private isDirty;
    add(child: WithDepth): void;
    remove(child: WithDepth): void;
    forEach(callback: (child: WithDepth) => void): void;
}

interface SwitchLayoutGroup {
    register?: (member: IProjectionNode) => void;
    deregister?: (member: IProjectionNode) => void;
}
type InitialPromotionConfig = {
    /**
     * The initial transition to use when the elements in this group mount (and automatically promoted).
     * Subsequent updates should provide a transition in the promote method.
     */
    transition?: Transition$1;
    /**
     * If the follow tree should preserve its opacity when the lead is promoted on mount
     */
    shouldPreserveFollowOpacity?: (member: IProjectionNode) => boolean;
};
type SwitchLayoutGroupContext = SwitchLayoutGroup & InitialPromotionConfig;
/**
 * Internal, exported only for usage in Framer
 */
declare const SwitchLayoutGroupContext: react.Context<SwitchLayoutGroupContext>;

interface Measurements {
    animationId: number;
    measuredBox: Box;
    layoutBox: Box;
    latestValues: ResolvedValues$1;
    source: number;
}
type Phase = "snapshot" | "measure";
interface ScrollMeasurements {
    animationId: number;
    phase: Phase;
    offset: Point;
    isRoot: boolean;
    wasRoot: boolean;
}
type LayoutEvents = "willUpdate" | "didUpdate" | "beforeMeasure" | "measure" | "projectionUpdate" | "animationStart" | "animationComplete";
interface IProjectionNode<I = unknown> {
    id: number;
    animationId: number;
    parent?: IProjectionNode;
    relativeParent?: IProjectionNode;
    root?: IProjectionNode;
    children: Set<IProjectionNode>;
    path: IProjectionNode[];
    nodes?: FlatTree;
    depth: number;
    instance: I;
    mount: (node: I, isLayoutDirty?: boolean) => void;
    unmount: () => void;
    options: ProjectionNodeOptions;
    setOptions(options: ProjectionNodeOptions): void;
    layout?: Measurements;
    snapshot?: Measurements;
    target?: Box;
    relativeTarget?: Box;
    relativeTargetOrigin?: Box;
    targetDelta?: Delta;
    targetWithTransforms?: Box;
    scroll?: ScrollMeasurements;
    treeScale?: Point;
    projectionDelta?: Delta;
    projectionDeltaWithTransform?: Delta;
    latestValues: ResolvedValues$1;
    isLayoutDirty: boolean;
    isProjectionDirty: boolean;
    isSharedProjectionDirty: boolean;
    isTransformDirty: boolean;
    resolvedRelativeTargetAt?: number;
    shouldResetTransform: boolean;
    prevTransformTemplateValue: string | undefined;
    isUpdateBlocked(): boolean;
    updateManuallyBlocked: boolean;
    updateBlockedByResize: boolean;
    blockUpdate(): void;
    unblockUpdate(): void;
    isUpdating: boolean;
    needsReset: boolean;
    startUpdate(): void;
    willUpdate(notifyListeners?: boolean): void;
    didUpdate(): void;
    measure(removeTransform?: boolean): Measurements;
    measurePageBox(): Box;
    updateLayout(): void;
    updateSnapshot(): void;
    clearSnapshot(): void;
    updateScroll(phase?: Phase): void;
    scheduleUpdateProjection(): void;
    scheduleCheckAfterUnmount(): void;
    checkUpdateFailed(): void;
    sharedNodes: Map<string, NodeStack>;
    registerSharedNode(id: string, node: IProjectionNode): void;
    getStack(): NodeStack | undefined;
    isVisible: boolean;
    hide(): void;
    show(): void;
    scheduleRender(notifyAll?: boolean): void;
    getClosestProjectingParent(): IProjectionNode | undefined;
    setTargetDelta(delta: Delta): void;
    resetTransform(): void;
    resetSkewAndRotation(): void;
    applyTransform(box: Box, transformOnly?: boolean): Box;
    resolveTargetDelta(force?: boolean): void;
    calcProjection(): void;
    getProjectionStyles(styleProp?: MotionStyle$2): MotionStyle$2 | undefined;
    clearMeasurements(): void;
    resetTree(): void;
    isProjecting(): boolean;
    animationValues?: ResolvedValues$1;
    currentAnimation?: AnimationPlaybackControls;
    isTreeAnimating?: boolean;
    isAnimationBlocked?: boolean;
    isTreeAnimationBlocked: () => boolean;
    setAnimationOrigin(delta: Delta): void;
    startAnimation(transition: Transition$1): void;
    finishAnimation(): void;
    hasCheckedOptimisedAppear: boolean;
    isLead(): boolean;
    promote(options?: {
        needsReset?: boolean;
        transition?: Transition$1;
        preserveFollowOpacity?: boolean;
    }): void;
    relegate(): boolean;
    resumeFrom?: IProjectionNode;
    resumingFrom?: IProjectionNode;
    isPresent?: boolean;
    addEventListener(name: LayoutEvents, handler: any): VoidFunction;
    notifyListeners(name: LayoutEvents, ...args: any): void;
    hasListeners(name: LayoutEvents): boolean;
    hasTreeAnimated: boolean;
    preserveOpacity?: boolean;
}
interface ProjectionNodeOptions {
    animate?: boolean;
    layoutScroll?: boolean;
    layoutRoot?: boolean;
    alwaysMeasureLayout?: boolean;
    onExitComplete?: VoidFunction;
    animationType?: "size" | "position" | "both" | "preserve-aspect";
    layoutId?: string;
    layout?: boolean | string;
    visualElement?: VisualElement;
    crossfade?: boolean;
    transition?: Transition$1;
    initialPromotionConfig?: InitialPromotionConfig;
}

type AnimationType = "animate" | "whileHover" | "whileTap" | "whileDrag" | "whileFocus" | "whileInView" | "exit";

type VisualElementAnimationOptions = {
    delay?: number;
    transitionOverride?: Transition$1;
    custom?: any;
    type?: AnimationType;
};

interface AnimationState$1 {
    animateChanges: (type?: AnimationType) => Promise<any>;
    setActive: (type: AnimationType, isActive: boolean, options?: VisualElementAnimationOptions) => Promise<any>;
    setAnimateFunction: (fn: any) => void;
    getState: () => {
        [key: string]: AnimationTypeState;
    };
    reset: () => void;
}
interface AnimationTypeState {
    isActive: boolean;
    protectedKeys: {
        [key: string]: true;
    };
    needsAnimating: {
        [key: string]: boolean;
    };
    prevResolvedValues: {
        [key: string]: any;
    };
    prevProp?: VariantLabels | TargetAndTransition;
}

type UnresolvedKeyframes<T extends string | number> = Array<T | null>;
type ResolvedKeyframes<T extends string | number> = Array<T>;
type OnKeyframesResolved<T extends string | number> = (resolvedKeyframes: ResolvedKeyframes<T>, finalKeyframe: T) => void;
declare class KeyframeResolver<T extends string | number = any> {
    name?: string;
    element?: VisualElement<any>;
    finalKeyframe?: T;
    suspendedScrollY?: number;
    protected unresolvedKeyframes: UnresolvedKeyframes<string | number>;
    private motionValue?;
    private onComplete;
    /**
     * Track whether this resolver has completed. Once complete, it never
     * needs to attempt keyframe resolution again.
     */
    private isComplete;
    /**
     * Track whether this resolver is async. If it is, it'll be added to the
     * resolver queue and flushed in the next frame. Resolvers that aren't going
     * to trigger read/write thrashing don't need to be async.
     */
    private isAsync;
    /**
     * Track whether this resolver needs to perform a measurement
     * to resolve its keyframes.
     */
    needsMeasurement: boolean;
    /**
     * Track whether this resolver is currently scheduled to resolve
     * to allow it to be cancelled and resumed externally.
     */
    isScheduled: boolean;
    constructor(unresolvedKeyframes: UnresolvedKeyframes<string | number>, onComplete: OnKeyframesResolved<T>, name?: string, motionValue?: MotionValue<T>, element?: VisualElement<any>, isAsync?: boolean);
    scheduleResolve(): void;
    readKeyframes(): void;
    setFinalKeyframe(): void;
    measureInitialState(): void;
    renderEndStyles(): void;
    measureEndState(): void;
    complete(): void;
    cancel(): void;
    resume(): void;
}

/**
 * A VisualElement is an imperative abstraction around UI elements such as
 * HTMLElement, SVGElement, Three.Object3D etc.
 */
declare abstract class VisualElement<Instance = unknown, RenderState = unknown, Options extends {} = {}> {
    /**
     * VisualElements are arranged in trees mirroring that of the React tree.
     * Each type of VisualElement has a unique name, to detect when we're crossing
     * type boundaries within that tree.
     */
    abstract type: string;
    /**
     * An `Array.sort` compatible function that will compare two Instances and
     * compare their respective positions within the tree.
     */
    abstract sortInstanceNodePosition(a: Instance, b: Instance): number;
    /**
     * Measure the viewport-relative bounding box of the Instance.
     */
    abstract measureInstanceViewportBox(instance: Instance, props: MotionProps & Partial<MotionConfigContext>): Box;
    /**
     * When a value has been removed from all animation props we need to
     * pick a target to animate back to. For instance, for HTMLElements
     * we can look in the style prop.
     */
    abstract getBaseTargetFromProps(props: MotionProps, key: string): string | number | undefined | MotionValue;
    /**
     * When we first animate to a value we need to animate it *from* a value.
     * Often this have been specified via the initial prop but it might be
     * that the value needs to be read from the Instance.
     */
    abstract readValueFromInstance(instance: Instance, key: string, options: Options): string | number | null | undefined;
    /**
     * When a value has been removed from the VisualElement we use this to remove
     * it from the inherting class' unique render state.
     */
    abstract removeValueFromRenderState(key: string, renderState: RenderState): void;
    /**
     * Run before a React or VisualElement render, builds the latest motion
     * values into an Instance-specific format. For example, HTMLVisualElement
     * will use this step to build `style` and `var` values.
     */
    abstract build(renderState: RenderState, latestValues: ResolvedValues$1, props: MotionProps): void;
    /**
     * Apply the built values to the Instance. For example, HTMLElements will have
     * styles applied via `setProperty` and the style attribute, whereas SVGElements
     * will have values applied to attributes.
     */
    abstract renderInstance(instance: Instance, renderState: RenderState, styleProp?: MotionStyle$2, projection?: IProjectionNode): void;
    /**
     * If true, will-change will be applied to the element. Only HTMLVisualElements
     * currently support this.
     */
    applyWillChange: boolean;
    /**
     * If the component child is provided as a motion value, handle subscriptions
     * with the renderer-specific VisualElement.
     */
    handleChildMotionValue?(): void;
    /**
     * This method takes React props and returns found MotionValues. For example, HTML
     * MotionValues will be found within the style prop, whereas for Three.js within attribute arrays.
     *
     * This isn't an abstract method as it needs calling in the constructor, but it is
     * intended to be one.
     */
    scrapeMotionValuesFromProps(_props: MotionProps, _prevProps: MotionProps, _visualElement: VisualElement): {
        [key: string]: MotionValue | string | number;
    };
    /**
     * A reference to the current underlying Instance, e.g. a HTMLElement
     * or Three.Mesh etc.
     */
    current: Instance | null;
    /**
     * A reference to the parent VisualElement (if exists).
     */
    parent: VisualElement | undefined;
    /**
     * A set containing references to this VisualElement's children.
     */
    children: Set<VisualElement<unknown, unknown, {}>>;
    /**
     * The depth of this VisualElement within the overall VisualElement tree.
     */
    depth: number;
    /**
     * The current render state of this VisualElement. Defined by inherting VisualElements.
     */
    renderState: RenderState;
    /**
     * An object containing the latest static values for each of this VisualElement's
     * MotionValues.
     */
    latestValues: ResolvedValues$1;
    /**
     * Determine what role this visual element should take in the variant tree.
     */
    isVariantNode: boolean;
    isControllingVariants: boolean;
    /**
     * If this component is part of the variant tree, it should track
     * any children that are also part of the tree. This is essentially
     * a shadow tree to simplify logic around how to stagger over children.
     */
    variantChildren?: Set<VisualElement>;
    /**
     * Decides whether this VisualElement should animate in reduced motion
     * mode.
     *
     * TODO: This is currently set on every individual VisualElement but feels
     * like it could be set globally.
     */
    shouldReduceMotion: boolean | null;
    /**
     * Normally, if a component is controlled by a parent's variants, it can
     * rely on that ancestor to trigger animations further down the tree.
     * However, if a component is created after its parent is mounted, the parent
     * won't trigger that mount animation so the child needs to.
     *
     * TODO: This might be better replaced with a method isParentMounted
     */
    manuallyAnimateOnMount: boolean;
    /**
     * This can be set by AnimatePresence to force components that mount
     * at the same time as it to mount as if they have initial={false} set.
     */
    blockInitialAnimation: boolean;
    /**
     * A reference to this VisualElement's projection node, used in layout animations.
     */
    projection?: IProjectionNode;
    /**
     * A map of all motion values attached to this visual element. Motion
     * values are source of truth for any given animated value. A motion
     * value might be provided externally by the component via props.
     */
    values: Map<string, MotionValue<any>>;
    /**
     * The AnimationState, this is hydrated by the animation Feature.
     */
    animationState?: AnimationState$1;
    KeyframeResolver: typeof KeyframeResolver;
    /**
     * The options used to create this VisualElement. The Options type is defined
     * by the inheriting VisualElement and is passed straight through to the render functions.
     */
    readonly options: Options;
    /**
     * A reference to the latest props provided to the VisualElement's host React component.
     */
    props: MotionProps;
    prevProps?: MotionProps;
    presenceContext: PresenceContextProps | null;
    prevPresenceContext?: PresenceContextProps | null;
    /**
     * Cleanup functions for active features (hover/tap/exit etc)
     */
    private features;
    /**
     * A map of every subscription that binds the provided or generated
     * motion values onChange listeners to this visual element.
     */
    private valueSubscriptions;
    /**
     * A reference to the ReducedMotionConfig passed to the VisualElement's host React component.
     */
    private reducedMotionConfig;
    /**
     * On mount, this will be hydrated with a callback to disconnect
     * this visual element from its parent on unmount.
     */
    private removeFromVariantTree;
    /**
     * A reference to the previously-provided motion values as returned
     * from scrapeMotionValuesFromProps. We use the keys in here to determine
     * if any motion values need to be removed after props are updated.
     */
    private prevMotionValues;
    /**
     * When values are removed from all animation props we need to search
     * for a fallback value to animate to. These values are tracked in baseTarget.
     */
    private baseTarget;
    /**
     * Create an object of the values we initially animated from (if initial prop present).
     */
    private initialValues;
    /**
     * An object containing a SubscriptionManager for each active event.
     */
    private events;
    /**
     * An object containing an unsubscribe function for each prop event subscription.
     * For example, every "Update" event can have multiple subscribers via
     * VisualElement.on(), but only one of those can be defined via the onUpdate prop.
     */
    private propEventSubscriptions;
    constructor({ parent, props, presenceContext, reducedMotionConfig, blockInitialAnimation, visualState, }: VisualElementOptions<Instance, RenderState>, options?: Options);
    mount(instance: Instance): void;
    unmount(): void;
    private bindToMotionValue;
    sortNodePosition(other: VisualElement<Instance>): number;
    updateFeatures(): void;
    notifyUpdate: () => void;
    triggerBuild(): void;
    render: () => void;
    private isRenderScheduled;
    scheduleRender: () => void;
    /**
     * Measure the current viewport box with or without transforms.
     * Only measures axis-aligned boxes, rotate and skew must be manually
     * removed with a re-render to work.
     */
    measureViewportBox(): Box;
    getStaticValue(key: string): string | number;
    setStaticValue(key: string, value: string | number): void;
    /**
     * Update the provided props. Ensure any newly-added motion values are
     * added to our map, old ones removed, and listeners updated.
     */
    update(props: MotionProps, presenceContext: PresenceContextProps | null): void;
    getProps(): MotionProps;
    /**
     * Returns the variant definition with a given name.
     */
    getVariant(name: string): Variant | undefined;
    /**
     * Returns the defined default transition on this component.
     */
    getDefaultTransition(): Transition$1 | undefined;
    getTransformPagePoint(): any;
    getClosestVariantNode(): VisualElement | undefined;
    getVariantContext(startAtParent?: boolean): undefined | VariantStateContext;
    /**
     * Add a child visual element to our set of children.
     */
    addVariantChild(child: VisualElement): (() => boolean) | undefined;
    /**
     * Add a motion value and bind it to this visual element.
     */
    addValue(key: string, value: MotionValue): void;
    /**
     * Remove a motion value and unbind any active subscriptions.
     */
    removeValue(key: string): void;
    /**
     * Check whether we have a motion value for this key
     */
    hasValue(key: string): boolean;
    /**
     * Get a motion value for this key. If called with a default
     * value, we'll create one if none exists.
     */
    getValue(key: string): MotionValue | undefined;
    getValue(key: string, defaultValue: string | number | null): MotionValue;
    /**
     * If we're trying to animate to a previously unencountered value,
     * we need to check for it in our state and as a last resort read it
     * directly from the instance (which might have performance implications).
     */
    readValue(key: string, target?: string | number | null): any;
    /**
     * Set the base target to later animate back to. This is currently
     * only hydrated on creation and when we first read a value.
     */
    setBaseTarget(key: string, value: string | number): void;
    /**
     * Find the base target for a value thats been removed from all animation
     * props.
     */
    getBaseTarget(key: string): ResolvedValues$1[string] | undefined | null;
    on<EventName extends keyof VisualElementEventCallbacks>(eventName: EventName, callback: VisualElementEventCallbacks[EventName]): VoidFunction;
    notify<EventName extends keyof VisualElementEventCallbacks>(eventName: EventName, ...args: any): void;
}

/**
 * An update function. It accepts a timestamp used to advance the animation.
 */
type Update = (timestamp: number) => void;
/**
 * Drivers accept a update function and call it at an interval. This interval
 * could be a synchronous loop, a setInterval, or tied to the device's framerate.
 */
interface DriverControls {
    start: () => void;
    stop: () => void;
    now: () => number;
}
type Driver = (update: Update) => DriverControls;

interface SVGAttributes {
    accentHeight?: number | string | undefined;
    accumulate?: "none" | "sum" | undefined;
    additive?: "replace" | "sum" | undefined;
    alignmentBaseline?: "auto" | "baseline" | "before-edge" | "text-before-edge" | "middle" | "central" | "after-edge" | "text-after-edge" | "ideographic" | "alphabetic" | "hanging" | "mathematical" | "inherit" | undefined;
    allowReorder?: "no" | "yes" | undefined;
    alphabetic?: number | string | undefined;
    amplitude?: number | string | undefined;
    arabicForm?: "initial" | "medial" | "terminal" | "isolated" | undefined;
    ascent?: number | string | undefined;
    attributeName?: string | undefined;
    attributeType?: string | undefined;
    autoReverse?: boolean | undefined;
    azimuth?: number | string | undefined;
    baseFrequency?: number | string | undefined;
    baselineShift?: number | string | undefined;
    baseProfile?: number | string | undefined;
    bbox?: number | string | undefined;
    begin?: number | string | undefined;
    bias?: number | string | undefined;
    by?: number | string | undefined;
    calcMode?: number | string | undefined;
    capHeight?: number | string | undefined;
    clip?: number | string | undefined;
    clipPath?: string | undefined;
    clipPathUnits?: number | string | undefined;
    clipRule?: number | string | undefined;
    colorInterpolation?: number | string | undefined;
    colorInterpolationFilters?: "auto" | "sRGB" | "linearRGB" | "inherit" | undefined;
    colorProfile?: number | string | undefined;
    colorRendering?: number | string | undefined;
    contentScriptType?: number | string | undefined;
    contentStyleType?: number | string | undefined;
    cursor?: number | string | undefined;
    cx?: number | string | undefined;
    cy?: number | string | undefined;
    d?: string | undefined;
    decelerate?: number | string | undefined;
    descent?: number | string | undefined;
    diffuseConstant?: number | string | undefined;
    direction?: number | string | undefined;
    display?: number | string | undefined;
    divisor?: number | string | undefined;
    dominantBaseline?: number | string | undefined;
    dur?: number | string | undefined;
    dx?: number | string | undefined;
    dy?: number | string | undefined;
    edgeMode?: number | string | undefined;
    elevation?: number | string | undefined;
    enableBackground?: number | string | undefined;
    end?: number | string | undefined;
    exponent?: number | string | undefined;
    externalResourcesRequired?: boolean | undefined;
    fill?: string | undefined;
    fillOpacity?: number | string | undefined;
    fillRule?: "nonzero" | "evenodd" | "inherit" | undefined;
    filter?: string | undefined;
    filterRes?: number | string | undefined;
    filterUnits?: number | string | undefined;
    floodColor?: number | string | undefined;
    floodOpacity?: number | string | undefined;
    focusable?: boolean | "auto" | undefined;
    fontFamily?: string | undefined;
    fontSize?: number | string | undefined;
    fontSizeAdjust?: number | string | undefined;
    fontStretch?: number | string | undefined;
    fontStyle?: number | string | undefined;
    fontVariant?: number | string | undefined;
    fontWeight?: number | string | undefined;
    format?: number | string | undefined;
    fr?: number | string | undefined;
    from?: number | string | undefined;
    fx?: number | string | undefined;
    fy?: number | string | undefined;
    g1?: number | string | undefined;
    g2?: number | string | undefined;
    glyphName?: number | string | undefined;
    glyphOrientationHorizontal?: number | string | undefined;
    glyphOrientationVertical?: number | string | undefined;
    glyphRef?: number | string | undefined;
    gradientTransform?: string | undefined;
    gradientUnits?: string | undefined;
    hanging?: number | string | undefined;
    horizAdvX?: number | string | undefined;
    horizOriginX?: number | string | undefined;
    href?: string | undefined;
    ideographic?: number | string | undefined;
    imageRendering?: number | string | undefined;
    in2?: number | string | undefined;
    in?: string | undefined;
    intercept?: number | string | undefined;
    k1?: number | string | undefined;
    k2?: number | string | undefined;
    k3?: number | string | undefined;
    k4?: number | string | undefined;
    k?: number | string | undefined;
    kernelMatrix?: number | string | undefined;
    kernelUnitLength?: number | string | undefined;
    kerning?: number | string | undefined;
    keyPoints?: number | string | undefined;
    keySplines?: number | string | undefined;
    keyTimes?: number | string | undefined;
    lengthAdjust?: number | string | undefined;
    letterSpacing?: number | string | undefined;
    lightingColor?: number | string | undefined;
    limitingConeAngle?: number | string | undefined;
    local?: number | string | undefined;
    markerEnd?: string | undefined;
    markerHeight?: number | string | undefined;
    markerMid?: string | undefined;
    markerStart?: string | undefined;
    markerUnits?: number | string | undefined;
    markerWidth?: number | string | undefined;
    mask?: string | undefined;
    maskContentUnits?: number | string | undefined;
    maskUnits?: number | string | undefined;
    mathematical?: number | string | undefined;
    mode?: number | string | undefined;
    numOctaves?: number | string | undefined;
    offset?: number | string | undefined;
    opacity?: number | string | undefined;
    operator?: number | string | undefined;
    order?: number | string | undefined;
    orient?: number | string | undefined;
    orientation?: number | string | undefined;
    origin?: number | string | undefined;
    overflow?: number | string | undefined;
    overlinePosition?: number | string | undefined;
    overlineThickness?: number | string | undefined;
    paintOrder?: number | string | undefined;
    panose1?: number | string | undefined;
    path?: string | undefined;
    pathLength?: number | string | undefined;
    patternContentUnits?: string | undefined;
    patternTransform?: number | string | undefined;
    patternUnits?: string | undefined;
    pointerEvents?: number | string | undefined;
    points?: string | undefined;
    pointsAtX?: number | string | undefined;
    pointsAtY?: number | string | undefined;
    pointsAtZ?: number | string | undefined;
    preserveAlpha?: boolean | undefined;
    preserveAspectRatio?: string | undefined;
    primitiveUnits?: number | string | undefined;
    r?: number | string | undefined;
    radius?: number | string | undefined;
    refX?: number | string | undefined;
    refY?: number | string | undefined;
    renderingIntent?: number | string | undefined;
    repeatCount?: number | string | undefined;
    repeatDur?: number | string | undefined;
    requiredExtensions?: number | string | undefined;
    requiredFeatures?: number | string | undefined;
    restart?: number | string | undefined;
    result?: string | undefined;
    rotate?: number | string | undefined;
    rx?: number | string | undefined;
    ry?: number | string | undefined;
    scale?: number | string | undefined;
    seed?: number | string | undefined;
    shapeRendering?: number | string | undefined;
    slope?: number | string | undefined;
    spacing?: number | string | undefined;
    specularConstant?: number | string | undefined;
    specularExponent?: number | string | undefined;
    speed?: number | string | undefined;
    spreadMethod?: string | undefined;
    startOffset?: number | string | undefined;
    stdDeviation?: number | string | undefined;
    stemh?: number | string | undefined;
    stemv?: number | string | undefined;
    stitchTiles?: number | string | undefined;
    stopColor?: string | undefined;
    stopOpacity?: number | string | undefined;
    strikethroughPosition?: number | string | undefined;
    strikethroughThickness?: number | string | undefined;
    string?: number | string | undefined;
    stroke?: string | undefined;
    strokeDasharray?: string | number | undefined;
    strokeDashoffset?: string | number | undefined;
    strokeLinecap?: "butt" | "round" | "square" | "inherit" | undefined;
    strokeLinejoin?: "miter" | "round" | "bevel" | "inherit" | undefined;
    strokeMiterlimit?: number | string | undefined;
    strokeOpacity?: number | string | undefined;
    strokeWidth?: number | string | undefined;
    surfaceScale?: number | string | undefined;
    systemLanguage?: number | string | undefined;
    tableValues?: number | string | undefined;
    targetX?: number | string | undefined;
    targetY?: number | string | undefined;
    textAnchor?: string | undefined;
    textDecoration?: number | string | undefined;
    textLength?: number | string | undefined;
    textRendering?: number | string | undefined;
    to?: number | string | undefined;
    transform?: string | undefined;
    u1?: number | string | undefined;
    u2?: number | string | undefined;
    underlinePosition?: number | string | undefined;
    underlineThickness?: number | string | undefined;
    unicode?: number | string | undefined;
    unicodeBidi?: number | string | undefined;
    unicodeRange?: number | string | undefined;
    unitsPerEm?: number | string | undefined;
    vAlphabetic?: number | string | undefined;
    values?: string | undefined;
    vectorEffect?: number | string | undefined;
    version?: string | undefined;
    vertAdvY?: number | string | undefined;
    vertOriginX?: number | string | undefined;
    vertOriginY?: number | string | undefined;
    vHanging?: number | string | undefined;
    vIdeographic?: number | string | undefined;
    viewBox?: string | undefined;
    viewTarget?: number | string | undefined;
    visibility?: number | string | undefined;
    vMathematical?: number | string | undefined;
    widths?: number | string | undefined;
    wordSpacing?: number | string | undefined;
    writingMode?: number | string | undefined;
    x1?: number | string | undefined;
    x2?: number | string | undefined;
    x?: number | string | undefined;
    xChannelSelector?: string | undefined;
    xHeight?: number | string | undefined;
    xlinkActuate?: string | undefined;
    xlinkArcrole?: string | undefined;
    xlinkHref?: string | undefined;
    xlinkRole?: string | undefined;
    xlinkShow?: string | undefined;
    xlinkTitle?: string | undefined;
    xlinkType?: string | undefined;
    xmlBase?: string | undefined;
    xmlLang?: string | undefined;
    xmlns?: string | undefined;
    xmlnsXlink?: string | undefined;
    xmlSpace?: string | undefined;
    y1?: number | string | undefined;
    y2?: number | string | undefined;
    y?: number | string | undefined;
    yChannelSelector?: string | undefined;
    z?: number | string | undefined;
    zoomAndPan?: string | undefined;
}

interface ProgressTimeline {
    currentTime: null | {
        value: number;
    };
    cancel?: VoidFunction;
}

interface AnimationPlaybackLifecycles<V> {
    onUpdate?: (latest: V) => void;
    onPlay?: () => void;
    onComplete?: () => void;
    onRepeat?: () => void;
    onStop?: () => void;
}
interface Transition extends AnimationPlaybackOptions, Omit<SpringOptions, "keyframes">, Omit<InertiaOptions$1, "keyframes">, KeyframeOptions {
    delay?: number;
    elapsed?: number;
    driver?: Driver;
    type?: "decay" | "spring" | "keyframes" | "tween" | "inertia";
    duration?: number;
    autoplay?: boolean;
    startTime?: number;
}
interface ValueAnimationTransition<V = any> extends Transition, AnimationPlaybackLifecycles<V> {
}
type ResolveKeyframes<V extends string | number> = (keyframes: V[], onComplete: OnKeyframesResolved<V>, name?: string, motionValue?: any) => KeyframeResolver<V>;
interface ValueAnimationOptions<V extends string | number = number> extends ValueAnimationTransition {
    keyframes: V[];
    KeyframeResolver?: typeof KeyframeResolver;
    name?: string;
    motionValue?: MotionValue<V>;
    element?: VisualElement;
    from?: V;
    isGenerator?: boolean;
}
interface AnimationScope<T = any> {
    readonly current: T;
    animations: AnimationPlaybackControls[];
}
type StyleTransitions = {
    [K in keyof CSSStyleDeclarationWithTransform]?: Transition;
};
type SVGPathTransitions = {
    [K in keyof SVGPathProperties]: Transition;
};
type SVGTransitions = {
    [K in keyof SVGAttributes]: Transition;
};
type VariableTransitions = {
    [key: `--${string}`]: Transition;
};
type AnimationOptionsWithValueOverrides<V = any> = StyleTransitions & SVGPathTransitions & SVGTransitions & VariableTransitions & ValueAnimationTransition<V>;
interface DynamicAnimationOptions extends Omit<AnimationOptionsWithValueOverrides, "delay"> {
    delay?: number | DynamicOption<number>;
}
type ElementOrSelector = Element | Element[] | NodeListOf<Element> | string;
/**
 * @public
 */
interface AnimationPlaybackControls {
    time: number;
    speed: number;
    startTime: number | null;
    state?: AnimationPlayState;
    duration: number;
    stop: () => void;
    play: () => void;
    pause: () => void;
    complete: () => void;
    cancel: () => void;
    then: (onResolve: VoidFunction, onReject?: VoidFunction) => Promise<void>;
    attachTimeline?: (timeline: ProgressTimeline) => VoidFunction;
}
type DynamicOption<T> = (i: number, total: number) => T;
interface CSSStyleDeclarationWithTransform extends Omit<CSSStyleDeclaration, "direction" | "transition" | "x" | "y" | "z"> {
    x: number | string;
    y: number | string;
    z: number | string;
    rotateX: number | string;
    rotateY: number | string;
    rotateZ: number | string;
    scaleX: number;
    scaleY: number;
    scaleZ: number;
    skewX: number | string;
    skewY: number | string;
}
type ValueKeyframe = string | number;
type UnresolvedValueKeyframe = ValueKeyframe | null;
type ValueKeyframesDefinition = ValueKeyframe | ValueKeyframe[] | UnresolvedValueKeyframe[];
type StyleKeyframesDefinition = {
    [K in keyof CSSStyleDeclarationWithTransform]?: ValueKeyframesDefinition;
};
type SVGKeyframesDefinition = {
    [K in keyof SVGAttributes]?: ValueKeyframesDefinition;
};
type VariableKeyframesDefinition = {
    [key: `--${string}`]: ValueKeyframesDefinition;
};
type SVGPathKeyframesDefinition = {
    [K in keyof SVGPathProperties]?: ValueKeyframesDefinition;
};
type DOMKeyframesDefinition = StyleKeyframesDefinition & SVGKeyframesDefinition & SVGPathKeyframesDefinition & VariableKeyframesDefinition;
interface VelocityOptions {
    velocity?: number;
    restSpeed?: number;
    restDelta?: number;
}
type RepeatType = "loop" | "reverse" | "mirror";
interface AnimationPlaybackOptions {
    repeat?: number;
    repeatType?: RepeatType;
    repeatDelay?: number;
}
interface DurationSpringOptions {
    duration?: number;
    bounce?: number;
}
interface SpringOptions extends DurationSpringOptions, VelocityOptions {
    stiffness?: number;
    damping?: number;
    mass?: number;
}
interface DecayOptions extends VelocityOptions {
    keyframes?: number[];
    power?: number;
    timeConstant?: number;
    modifyTarget?: (v: number) => number;
}
interface InertiaOptions$1 extends DecayOptions {
    bounceStiffness?: number;
    bounceDamping?: number;
    min?: number;
    max?: number;
}
interface KeyframeOptions {
    ease?: Easing | Easing[];
    times?: number[];
}
type AnimationDefinition = VariantLabels | TargetAndTransition | TargetResolver;
/**
 * @public
 */
interface AnimationControls {
    /**
     * Starts an animation on all linked components.
     *
     * @remarks
     *
     * ```jsx
     * controls.start("variantLabel")
     * controls.start({
     *   x: 0,
     *   transition: { duration: 1 }
     * })
     * ```
     *
     * @param definition - Properties or variant label to animate to
     * @param transition - Optional `transtion` to apply to a variant
     * @returns - A `Promise` that resolves when all animations have completed.
     *
     * @public
     */
    start(definition: AnimationDefinition, transitionOverride?: Transition): Promise<any>;
    /**
     * Instantly set to a set of properties or a variant.
     *
     * ```jsx
     * // With properties
     * controls.set({ opacity: 0 })
     *
     * // With variants
     * controls.set("hidden")
     * ```
     *
     * @privateRemarks
     * We could perform a similar trick to `.start` where this can be called before mount
     * and we maintain a list of of pending actions that get applied on mount. But the
     * expectation of `set` is that it happens synchronously and this would be difficult
     * to do before any children have even attached themselves. It's also poor practise
     * and we should discourage render-synchronous `.start` calls rather than lean into this.
     *
     * @public
     */
    set(definition: AnimationDefinition): void;
    /**
     * Stops animations on all linked components.
     *
     * ```jsx
     * controls.stop()
     * ```
     *
     * @public
     */
    stop(): void;
    mount(): () => void;
}

/**
 * @public
 */
type Subscriber<T> = (v: T) => void;
/**
 * @public
 */
type PassiveEffect<T> = (v: T, safeSetter: (v: T) => void) => void;
interface MotionValueEventCallbacks<V> {
    animationStart: () => void;
    animationComplete: () => void;
    animationCancel: () => void;
    change: (latestValue: V) => void;
    renderRequest: () => void;
}
interface ResolvedValues {
    [key: string]: string | number;
}
interface Owner {
    current: HTMLElement | unknown;
    getProps: () => {
        onUpdate?: (latest: ResolvedValues) => void;
    };
}
interface MotionValueOptions {
    owner?: Owner;
}
/**
 * `MotionValue` is used to track the state and velocity of motion values.
 *
 * @public
 */
declare class MotionValue<V = any> {
    /**
     * This will be replaced by the build step with the latest version number.
     * When MotionValues are provided to motion components, warn if versions are mixed.
     */
    version: string;
    /**
     * If a MotionValue has an owner, it was created internally within Framer Motion
     * and therefore has no external listeners. It is therefore safe to animate via WAAPI.
     */
    owner?: Owner;
    /**
     * The current state of the `MotionValue`.
     */
    private current;
    /**
     * The previous state of the `MotionValue`.
     */
    private prev;
    /**
     * The previous state of the `MotionValue` at the end of the previous frame.
     */
    private prevFrameValue;
    /**
     * The last time the `MotionValue` was updated.
     */
    private updatedAt;
    /**
     * The time `prevFrameValue` was updated.
     */
    private prevUpdatedAt;
    private stopPassiveEffect?;
    /**
     * A reference to the currently-controlling animation.
     */
    animation?: AnimationPlaybackControls;
    setCurrent(current: V): void;
    setPrevFrameValue(prevFrameValue?: V | undefined): void;
    /**
     * Adds a function that will be notified when the `MotionValue` is updated.
     *
     * It returns a function that, when called, will cancel the subscription.
     *
     * When calling `onChange` inside a React component, it should be wrapped with the
     * `useEffect` hook. As it returns an unsubscribe function, this should be returned
     * from the `useEffect` function to ensure you don't add duplicate subscribers..
     *
     * ```jsx
     * export const MyComponent = () => {
     *   const x = useMotionValue(0)
     *   const y = useMotionValue(0)
     *   const opacity = useMotionValue(1)
     *
     *   useEffect(() => {
     *     function updateOpacity() {
     *       const maxXY = Math.max(x.get(), y.get())
     *       const newOpacity = transform(maxXY, [0, 100], [1, 0])
     *       opacity.set(newOpacity)
     *     }
     *
     *     const unsubscribeX = x.on("change", updateOpacity)
     *     const unsubscribeY = y.on("change", updateOpacity)
     *
     *     return () => {
     *       unsubscribeX()
     *       unsubscribeY()
     *     }
     *   }, [])
     *
     *   return <motion.div style={{ x }} />
     * }
     * ```
     *
     * @param subscriber - A function that receives the latest value.
     * @returns A function that, when called, will cancel this subscription.
     *
     * @deprecated
     */
    onChange(subscription: Subscriber<V>): () => void;
    /**
     * An object containing a SubscriptionManager for each active event.
     */
    private events;
    on<EventName extends keyof MotionValueEventCallbacks<V>>(eventName: EventName, callback: MotionValueEventCallbacks<V>[EventName]): VoidFunction;
    clearListeners(): void;
    /**
     * Sets the state of the `MotionValue`.
     *
     * @remarks
     *
     * ```jsx
     * const x = useMotionValue(0)
     * x.set(10)
     * ```
     *
     * @param latest - Latest value to set.
     * @param render - Whether to notify render subscribers. Defaults to `true`
     *
     * @public
     */
    set(v: V, render?: boolean): void;
    setWithVelocity(prev: V, current: V, delta: number): void;
    /**
     * Set the state of the `MotionValue`, stopping any active animations,
     * effects, and resets velocity to `0`.
     */
    jump(v: V, endAnimation?: boolean): void;
    updateAndNotify: (v: V, render?: boolean) => void;
    /**
     * Returns the latest state of `MotionValue`
     *
     * @returns - The latest state of `MotionValue`
     *
     * @public
     */
    get(): NonNullable<V>;
    /**
     * @public
     */
    getPrevious(): V | undefined;
    /**
     * Returns the latest velocity of `MotionValue`
     *
     * @returns - The latest velocity of `MotionValue`. Returns `0` if the state is non-numerical.
     *
     * @public
     */
    getVelocity(): number;
    hasAnimated: boolean;
    /**
     * Stop the currently active animation.
     *
     * @public
     */
    stop(): void;
    /**
     * Returns `true` if this value is currently animating.
     *
     * @public
     */
    isAnimating(): boolean;
    private clearAnimation;
    /**
     * Destroy and clean up subscribers to this `MotionValue`.
     *
     * The `MotionValue` hooks like `useMotionValue` and `useTransform` automatically
     * handle the lifecycle of the returned `MotionValue`, so this method is only necessary if you've manually
     * created a `MotionValue` via the `motionValue` function.
     *
     * @public
     */
    destroy(): void;
}
declare function motionValue<V>(init: V, options?: MotionValueOptions): MotionValue<V>;

type RefObject<T> = {
    current: T | null;
};

/**
 * Passed in to pan event handlers like `onPan` the `PanInfo` object contains
 * information about the current state of the tap gesture such as its
 * `point`, `delta`, `offset` and `velocity`.
 *
 * ```jsx
 * <motion.div onPan={(event, info) => {
 *   console.log(info.point.x, info.point.y)
 * }} />
 * ```
 *
 * @public
 */
interface PanInfo {
    /**
     * Contains `x` and `y` values for the current pan position relative
     * to the device or page.
     *
     * ```jsx
     * function onPan(event, info) {
     *   console.log(info.point.x, info.point.y)
     * }
     *
     * <motion.div onPan={onPan} />
     * ```
     *
     * @public
     */
    point: Point;
    /**
     * Contains `x` and `y` values for the distance moved since
     * the last event.
     *
     * ```jsx
     * function onPan(event, info) {
     *   console.log(info.delta.x, info.delta.y)
     * }
     *
     * <motion.div onPan={onPan} />
     * ```
     *
     * @public
     */
    delta: Point;
    /**
     * Contains `x` and `y` values for the distance moved from
     * the first pan event.
     *
     * ```jsx
     * function onPan(event, info) {
     *   console.log(info.offset.x, info.offset.y)
     * }
     *
     * <motion.div onPan={onPan} />
     * ```
     *
     * @public
     */
    offset: Point;
    /**
     * Contains `x` and `y` values for the current velocity of the pointer, in px/ms.
     *
     * ```jsx
     * function onPan(event, info) {
     *   console.log(info.velocity.x, info.velocity.y)
     * }
     *
     * <motion.div onPan={onPan} />
     * ```
     *
     * @public
     */
    velocity: Point;
}

interface DragControlOptions {
    snapToCursor?: boolean;
    cursorProgress?: Point;
}

/**
 * Can manually trigger a drag gesture on one or more `drag`-enabled `motion` components.
 *
 * ```jsx
 * const dragControls = useDragControls()
 *
 * function startDrag(event) {
 *   dragControls.start(event, { snapToCursor: true })
 * }
 *
 * return (
 *   <>
 *     <div onPointerDown={startDrag} />
 *     <motion.div drag="x" dragControls={dragControls} />
 *   </>
 * )
 * ```
 *
 * @public
 */
declare class DragControls {
    private componentControls;
    /**
     * Start a drag gesture on every `motion` component that has this set of drag controls
     * passed into it via the `dragControls` prop.
     *
     * ```jsx
     * dragControls.start(e, {
     *   snapToCursor: true
     * })
     * ```
     *
     * @param event - PointerEvent
     * @param options - Options
     *
     * @public
     */
    start(event: react.PointerEvent | PointerEvent, options?: DragControlOptions): void;
}
/**
 * Usually, dragging is initiated by pressing down on a `motion` component with a `drag` prop
 * and moving it. For some use-cases, for instance clicking at an arbitrary point on a video scrubber, we
 * might want to initiate that dragging from a different component than the draggable one.
 *
 * By creating a `dragControls` using the `useDragControls` hook, we can pass this into
 * the draggable component's `dragControls` prop. It exposes a `start` method
 * that can start dragging from pointer events on other components.
 *
 * ```jsx
 * const dragControls = useDragControls()
 *
 * function startDrag(event) {
 *   dragControls.start(event, { snapToCursor: true })
 * }
 *
 * return (
 *   <>
 *     <div onPointerDown={startDrag} />
 *     <motion.div drag="x" dragControls={dragControls} />
 *   </>
 * )
 * ```
 *
 * @public
 */
declare function useDragControls(): DragControls;

type DragElastic = boolean | number | Partial<BoundingBox>;
/**
 * @public
 */
interface DragHandlers {
    /**
     * Callback function that fires when dragging starts.
     *
     * ```jsx
     * <motion.div
     *   drag
     *   onDragStart={
     *     (event, info) => console.log(info.point.x, info.point.y)
     *   }
     * />
     * ```
     *
     * @public
     */
    onDragStart?(event: MouseEvent | TouchEvent | PointerEvent, info: PanInfo): void;
    /**
     * Callback function that fires when dragging ends.
     *
     * ```jsx
     * <motion.div
     *   drag
     *   onDragEnd={
     *     (event, info) => console.log(info.point.x, info.point.y)
     *   }
     * />
     * ```
     *
     * @public
     */
    onDragEnd?(event: MouseEvent | TouchEvent | PointerEvent, info: PanInfo): void;
    /**
     * Callback function that fires when the component is dragged.
     *
     * ```jsx
     * <motion.div
     *   drag
     *   onDrag={
     *     (event, info) => console.log(info.point.x, info.point.y)
     *   }
     * />
     * ```
     *
     * @public
     */
    onDrag?(event: MouseEvent | TouchEvent | PointerEvent, info: PanInfo): void;
    /**
     * Callback function that fires a drag direction is determined.
     *
     * ```jsx
     * <motion.div
     *   drag
     *   dragDirectionLock
     *   onDirectionLock={axis => console.log(axis)}
     * />
     * ```
     *
     * @public
     */
    onDirectionLock?(axis: "x" | "y"): void;
    /**
     * Callback function that fires when drag momentum/bounce transition finishes.
     *
     * ```jsx
     * <motion.div
     *   drag
     *   onDragTransitionEnd={() => console.log('Drag transition complete')}
     * />
     * ```
     *
     * @public
     */
    onDragTransitionEnd?(): void;
}
/**
 * @public
 */
type InertiaOptions = Partial<Omit<Inertia, "velocity" | "type">>;
/**
 * @public
 */
interface DraggableProps extends DragHandlers {
    /**
     * Enable dragging for this element. Set to `false` by default.
     * Set `true` to drag in both directions.
     * Set `"x"` or `"y"` to only drag in a specific direction.
     *
     * ```jsx
     * <motion.div drag="x" />
     * ```
     */
    drag?: boolean | "x" | "y";
    /**
     * Properties or variant label to animate to while the drag gesture is recognised.
     *
     * ```jsx
     * <motion.div whileDrag={{ scale: 1.2 }} />
     * ```
     */
    whileDrag?: VariantLabels | TargetAndTransition;
    /**
     * If `true`, this will lock dragging to the initially-detected direction. Defaults to `false`.
     *
     * ```jsx
     * <motion.div drag dragDirectionLock />
     * ```
     */
    dragDirectionLock?: boolean;
    /**
     * Allows drag gesture propagation to child components. Set to `false` by
     * default.
     *
     * ```jsx
     * <motion.div drag="x" dragPropagation />
     * ```
     */
    dragPropagation?: boolean;
    /**
     * Applies constraints on the permitted draggable area.
     *
     * It can accept an object of optional `top`, `left`, `right`, and `bottom` values, measured in pixels.
     * This will define a distance the named edge of the draggable component.
     *
     * Alternatively, it can accept a `ref` to another component created with React's `useRef` hook.
     * This `ref` should be passed both to the draggable component's `dragConstraints` prop, and the `ref`
     * of the component you want to use as constraints.
     *
     * ```jsx
     * // In pixels
     * <motion.div
     *   drag="x"
     *   dragConstraints={{ left: 0, right: 300 }}
     * />
     *
     * // As a ref to another component
     * const MyComponent = () => {
     *   const constraintsRef = useRef(null)
     *
     *   return (
     *      <motion.div ref={constraintsRef}>
     *          <motion.div drag dragConstraints={constraintsRef} />
     *      </motion.div>
     *   )
     * }
     * ```
     */
    dragConstraints?: false | Partial<BoundingBox> | RefObject<Element>;
    /**
     * The degree of movement allowed outside constraints. 0 = no movement, 1 =
     * full movement.
     *
     * Set to `0.5` by default. Can also be set as `false` to disable movement.
     *
     * By passing an object of `top`/`right`/`bottom`/`left`, individual values can be set
     * per constraint. Any missing values will be set to `0`.
     *
     * ```jsx
     * <motion.div
     *   drag
     *   dragConstraints={{ left: 0, right: 300 }}
     *   dragElastic={0.2}
     * />
     * ```
     */
    dragElastic?: DragElastic;
    /**
     * Apply momentum from the pan gesture to the component when dragging
     * finishes. Set to `true` by default.
     *
     * ```jsx
     * <motion.div
     *   drag
     *   dragConstraints={{ left: 0, right: 300 }}
     *   dragMomentum={false}
     * />
     * ```
     */
    dragMomentum?: boolean;
    /**
     * Allows you to change dragging inertia parameters.
     * When releasing a draggable Frame, an animation with type `inertia` starts. The animation is based on your dragging velocity. This property allows you to customize it.
     * See {@link https://framer.com/api/animation/#inertia | Inertia} for all properties you can use.
     *
     * ```jsx
     * <motion.div
     *   drag
     *   dragTransition={{ bounceStiffness: 600, bounceDamping: 10 }}
     * />
     * ```
     */
    dragTransition?: InertiaOptions;
    /**
     * Usually, dragging is initiated by pressing down on a component and moving it. For some
     * use-cases, for instance clicking at an arbitrary point on a video scrubber, we
     * might want to initiate dragging from a different component than the draggable one.
     *
     * By creating a `dragControls` using the `useDragControls` hook, we can pass this into
     * the draggable component's `dragControls` prop. It exposes a `start` method
     * that can start dragging from pointer events on other components.
     *
     * ```jsx
     * const dragControls = useDragControls()
     *
     * function startDrag(event) {
     *   dragControls.start(event, { snapToCursor: true })
     * }
     *
     * return (
     *   <>
     *     <div onPointerDown={startDrag} />
     *     <motion.div drag="x" dragControls={dragControls} />
     *   </>
     * )
     * ```
     */
    dragControls?: DragControls;
    /**
     * If true, element will snap back to its origin when dragging ends.
     *
     * Enabling this is the equivalent of setting all `dragConstraints` axes to `0`
     * with `dragElastic={1}`, but when used together `dragConstraints` can define
     * a wider draggable area and `dragSnapToOrigin` will ensure the element
     * animates back to its origin on release.
     */
    dragSnapToOrigin?: boolean;
    /**
     * By default, if `drag` is defined on a component then an event listener will be attached
     * to automatically initiate dragging when a user presses down on it.
     *
     * By setting `dragListener` to `false`, this event listener will not be created.
     *
     * ```jsx
     * const dragControls = useDragControls()
     *
     * function startDrag(event) {
     *   dragControls.start(event, { snapToCursor: true })
     * }
     *
     * return (
     *   <>
     *     <div onPointerDown={startDrag} />
     *     <motion.div
     *       drag="x"
     *       dragControls={dragControls}
     *       dragListener={false}
     *     />
     *   </>
     * )
     * ```
     */
    dragListener?: boolean;
    /**
     * If `dragConstraints` is set to a React ref, this callback will call with the measured drag constraints.
     *
     * @public
     */
    onMeasureDragConstraints?: (constraints: BoundingBox) => BoundingBox | void;
    /**
     * Usually, dragging uses the layout project engine, and applies transforms to the underlying VisualElement.
     * Passing MotionValues as _dragX and _dragY instead applies drag updates to these motion values.
     * This allows you to manually control how updates from a drag gesture on an element is applied.
     *
     * @public
     */
    _dragX?: MotionValue<number>;
    /**
     * Usually, dragging uses the layout project engine, and applies transforms to the underlying VisualElement.
     * Passing MotionValues as _dragX and _dragY instead applies drag updates to these motion values.
     * This allows you to manually control how updates from a drag gesture on an element is applied.
     *
     * @public
     */
    _dragY?: MotionValue<number>;
}

/**
 * @public
 */
interface LayoutProps {
    /**
     * If `true`, this component will automatically animate to its new position when
     * its layout changes.
     *
     * ```jsx
     * <motion.div layout />
     * ```
     *
     * This will perform a layout animation using performant transforms. Part of this technique
     * involved animating an element's scale. This can introduce visual distortions on children,
     * `boxShadow` and `borderRadius`.
     *
     * To correct distortion on immediate children, add `layout` to those too.
     *
     * `boxShadow` and `borderRadius` will automatically be corrected if they are already being
     * animated on this component. Otherwise, set them directly via the `initial` prop.
     *
     * If `layout` is set to `"position"`, the size of the component will change instantly and
     * only its position will animate. If `layout` is set to `"size"`, the position of the
     * component will change instantly but its size will animate.
     *
     * If `layout` is set to `"size"`, the position of the component will change instantly and
     * only its size will animate.
     *
     * If `layout` is set to `"preserve-aspect"`, the component will animate size & position if
     * the aspect ratio remains the same between renders, and just position if the ratio changes.
     *
     * @public
     */
    layout?: boolean | "position" | "size" | "preserve-aspect";
    /**
     * Enable shared layout transitions between different components with the same `layoutId`.
     *
     * When a component with a layoutId is removed from the React tree, and then
     * added elsewhere, it will visually animate from the previous component's bounding box
     * and its latest animated values.
     *
     * ```jsx
     *   {items.map(item => (
     *      <motion.li layout>
     *         {item.name}
     *         {item.isSelected && <motion.div layoutId="underline" />}
     *      </motion.li>
     *   ))}
     * ```
     *
     * If the previous component remains in the tree it will crossfade with the new component.
     *
     * @public
     */
    layoutId?: string;
    /**
     * A callback that will fire when a layout animation on this component starts.
     *
     * @public
     */
    onLayoutAnimationStart?(): void;
    /**
     * A callback that will fire when a layout animation on this component completes.
     *
     * @public
     */
    onLayoutAnimationComplete?(): void;
    /**
     * @public
     */
    layoutDependency?: any;
    /**
     * Whether a projection node should measure its scroll when it or its descendants update their layout.
     *
     * @public
     */
    layoutScroll?: boolean;
    /**
     * Whether an element should be considered a "layout root", where
     * all children will be forced to resolve relatively to it.
     * Currently used for `position: sticky` elements in Framer.
     */
    layoutRoot?: boolean;
    /**
     * Attached to a portal root to ensure we attach the child to the document root and don't
     * perform scale correction on it.
     */
    "data-framer-portal-id"?: string;
}

/** @public */
interface EventInfo {
    point: Point;
}

/**
 * @public
 */
interface FocusHandlers {
    /**
     * Properties or variant label to animate to while the focus gesture is recognised.
     *
     * ```jsx
     * <motion.input whileFocus={{ scale: 1.2 }} />
     * ```
     */
    whileFocus?: VariantLabels | TargetAndTransition;
}
/**
 * Passed in to tap event handlers like `onTap` the `TapInfo` object contains
 * information about the tap gesture such as it‘s location.
 *
 * ```jsx
 * function onTap(event, info) {
 *   console.log(info.point.x, info.point.y)
 * }
 *
 * <motion.div onTap={onTap} />
 * ```
 *
 * @public
 */
interface TapInfo {
    /**
     * Contains `x` and `y` values for the tap gesture relative to the
     * device or page.
     *
     * ```jsx
     * function onTapStart(event, info) {
     *   console.log(info.point.x, info.point.y)
     * }
     *
     * <motion.div onTapStart={onTapStart} />
     * ```
     *
     * @public
     */
    point: Point;
}
/**
 * @public
 */
interface TapHandlers {
    /**
     * Callback when the tap gesture successfully ends on this element.
     *
     * ```jsx
     * function onTap(event, info) {
     *   console.log(info.point.x, info.point.y)
     * }
     *
     * <motion.div onTap={onTap} />
     * ```
     *
     * @param event - The originating pointer event.
     * @param info - An {@link TapInfo} object containing `x` and `y` values for the `point` relative to the device or page.
     */
    onTap?(event: MouseEvent | TouchEvent | PointerEvent, info: TapInfo): void;
    /**
     * Callback when the tap gesture starts on this element.
     *
     * ```jsx
     * function onTapStart(event, info) {
     *   console.log(info.point.x, info.point.y)
     * }
     *
     * <motion.div onTapStart={onTapStart} />
     * ```
     *
     * @param event - The originating pointer event.
     * @param info - An {@link TapInfo} object containing `x` and `y` values for the `point` relative to the device or page.
     */
    onTapStart?(event: MouseEvent | TouchEvent | PointerEvent, info: TapInfo): void;
    /**
     * Callback when the tap gesture ends outside this element.
     *
     * ```jsx
     * function onTapCancel(event, info) {
     *   console.log(info.point.x, info.point.y)
     * }
     *
     * <motion.div onTapCancel={onTapCancel} />
     * ```
     *
     * @param event - The originating pointer event.
     * @param info - An {@link TapInfo} object containing `x` and `y` values for the `point` relative to the device or page.
     */
    onTapCancel?(event: MouseEvent | TouchEvent | PointerEvent, info: TapInfo): void;
    /**
     * Properties or variant label to animate to while the component is pressed.
     *
     * ```jsx
     * <motion.div whileTap={{ scale: 0.8 }} />
     * ```
     */
    whileTap?: VariantLabels | TargetAndTransition;
    /**
     * If `true`, the tap gesture will attach its start listener to window.
     *
     * Note: This is not supported publically.
     */
    globalTapTarget?: boolean;
}
/**
 * @public
 */
interface PanHandlers {
    /**
     * Callback function that fires when the pan gesture is recognised on this element.
     *
     * **Note:** For pan gestures to work correctly with touch input, the element needs
     * touch scrolling to be disabled on either x/y or both axis with the
     * [touch-action](https://developer.mozilla.org/en-US/docs/Web/CSS/touch-action) CSS rule.
     *
     * ```jsx
     * function onPan(event, info) {
     *   console.log(info.point.x, info.point.y)
     * }
     *
     * <motion.div onPan={onPan} />
     * ```
     *
     * @param event - The originating pointer event.
     * @param info - A {@link PanInfo} object containing `x` and `y` values for:
     *
     *   - `point`: Relative to the device or page.
     *   - `delta`: Distance moved since the last event.
     *   - `offset`: Offset from the original pan event.
     *   - `velocity`: Current velocity of the pointer.
     */
    onPan?(event: PointerEvent, info: PanInfo): void;
    /**
     * Callback function that fires when the pan gesture begins on this element.
     *
     * ```jsx
     * function onPanStart(event, info) {
     *   console.log(info.point.x, info.point.y)
     * }
     *
     * <motion.div onPanStart={onPanStart} />
     * ```
     *
     * @param event - The originating pointer event.
     * @param info - A {@link PanInfo} object containing `x`/`y` values for:
     *
     *   - `point`: Relative to the device or page.
     *   - `delta`: Distance moved since the last event.
     *   - `offset`: Offset from the original pan event.
     *   - `velocity`: Current velocity of the pointer.
     */
    onPanStart?(event: PointerEvent, info: PanInfo): void;
    /**
     * Callback function that fires when we begin detecting a pan gesture. This
     * is analogous to `onMouseStart` or `onTouchStart`.
     *
     * ```jsx
     * function onPanSessionStart(event, info) {
     *   console.log(info.point.x, info.point.y)
     * }
     *
     * <motion.div onPanSessionStart={onPanSessionStart} />
     * ```
     *
     * @param event - The originating pointer event.
     * @param info - An {@link EventInfo} object containing `x`/`y` values for:
     *
     *   - `point`: Relative to the device or page.
     */
    onPanSessionStart?(event: PointerEvent, info: EventInfo): void;
    /**
     * Callback function that fires when the pan gesture ends on this element.
     *
     * ```jsx
     * function onPanEnd(event, info) {
     *   console.log(info.point.x, info.point.y)
     * }
     *
     * <motion.div onPanEnd={onPanEnd} />
     * ```
     *
     * @param event - The originating pointer event.
     * @param info - A {@link PanInfo} object containing `x`/`y` values for:
     *
     *   - `point`: Relative to the device or page.
     *   - `delta`: Distance moved since the last event.
     *   - `offset`: Offset from the original pan event.
     *   - `velocity`: Current velocity of the pointer.
     */
    onPanEnd?(event: PointerEvent, info: PanInfo): void;
}
/**
 * @public
 */
interface HoverHandlers {
    /**
     * Properties or variant label to animate to while the hover gesture is recognised.
     *
     * ```jsx
     * <motion.div whileHover={{ scale: 1.2 }} />
     * ```
     */
    whileHover?: VariantLabels | TargetAndTransition;
    /**
     * Callback function that fires when pointer starts hovering over the component.
     *
     * ```jsx
     * <motion.div onHoverStart={() => console.log('Hover starts')} />
     * ```
     */
    onHoverStart?(event: MouseEvent, info: EventInfo): void;
    /**
     * Callback function that fires when pointer stops hovering over the component.
     *
     * ```jsx
     * <motion.div onHoverEnd={() => console.log("Hover ends")} />
     * ```
     */
    onHoverEnd?(event: MouseEvent, info: EventInfo): void;
}

type ViewportEventHandler = (entry: IntersectionObserverEntry | null) => void;
interface ViewportOptions {
    root?: RefObject<Element>;
    once?: boolean;
    margin?: string;
    amount?: "some" | "all" | number;
}
interface ViewportProps {
    whileInView?: VariantLabels | TargetAndTransition;
    onViewportEnter?: ViewportEventHandler;
    onViewportLeave?: ViewportEventHandler;
    viewport?: ViewportOptions;
}

/**
 * Either a string, or array of strings, that reference variants defined via the `variants` prop.
 * @public
 */
type VariantLabels = string | string[];
interface TransformProperties {
    x?: string | number;
    y?: string | number;
    z?: string | number;
    translateX?: string | number;
    translateY?: string | number;
    translateZ?: string | number;
    rotate?: string | number;
    rotateX?: string | number;
    rotateY?: string | number;
    rotateZ?: string | number;
    scale?: string | number;
    scaleX?: string | number;
    scaleY?: string | number;
    scaleZ?: string | number;
    skew?: string | number;
    skewX?: string | number;
    skewY?: string | number;
    originX?: string | number;
    originY?: string | number;
    originZ?: string | number;
    perspective?: string | number;
    transformPerspective?: string | number;
}
/**
 * @public
 */
interface SVGPathProperties {
    pathLength?: number;
    pathOffset?: number;
    pathSpacing?: number;
}
interface CustomStyles {
    /**
     * Framer Library custom prop types. These are not actually supported in Motion - preferably
     * we'd have a way of external consumers injecting supported styles into this library.
     */
    size?: string | number;
    radius?: string | number;
    shadow?: string;
    image?: string;
}
type MakeMotion<T> = MakeCustomValueType<{
    [K in keyof T]: T[K] | MotionValue<number> | MotionValue<string> | MotionValue<any>;
}>;
type MotionCSS = MakeMotion<Omit$1<CSSProperties, "rotate" | "scale" | "perspective">>;
/**
 * @public
 */
type MotionTransform = MakeMotion<TransformProperties>;
/**
 * @public
 */
type MotionStyle$2 = MotionCSS & MotionTransform & MakeMotion<SVGPathProperties> & MakeCustomValueType<CustomStyles>;
/**
 * @public
 */
interface RelayoutInfo {
    delta: {
        x: number;
        y: number;
        width: number;
        height: number;
    };
}
/**
 * @public
 */
type ResolveLayoutTransition = (info: RelayoutInfo) => Transition$1 | boolean;
/**
 * @public
 */
interface AnimationProps {
    /**
     * Properties, variant label or array of variant labels to start in.
     *
     * Set to `false` to initialise with the values in `animate` (disabling the mount animation)
     *
     * ```jsx
     * // As values
     * <motion.div initial={{ opacity: 1 }} />
     *
     * // As variant
     * <motion.div initial="visible" variants={variants} />
     *
     * // Multiple variants
     * <motion.div initial={["visible", "active"]} variants={variants} />
     *
     * // As false (disable mount animation)
     * <motion.div initial={false} animate={{ opacity: 0 }} />
     * ```
     */
    initial?: boolean | Target | VariantLabels;
    /**
     * Values to animate to, variant label(s), or `AnimationControls`.
     *
     * ```jsx
     * // As values
     * <motion.div animate={{ opacity: 1 }} />
     *
     * // As variant
     * <motion.div animate="visible" variants={variants} />
     *
     * // Multiple variants
     * <motion.div animate={["visible", "active"]} variants={variants} />
     *
     * // AnimationControls
     * <motion.div animate={animation} />
     * ```
     */
    animate?: AnimationControls | TargetAndTransition | VariantLabels | boolean;
    /**
     * A target to animate to when this component is removed from the tree.
     *
     * This component **must** be the first animatable child of an `AnimatePresence` to enable this exit animation.
     *
     * This limitation exists because React doesn't allow components to defer unmounting until after
     * an animation is complete. Once this limitation is fixed, the `AnimatePresence` component will be unnecessary.
     *
     * ```jsx
     * import { AnimatePresence, motion } from 'framer-motion'
     *
     * export const MyComponent = ({ isVisible }) => {
     *   return (
     *     <AnimatePresence>
     *        {isVisible && (
     *          <motion.div
     *            initial={{ opacity: 0 }}
     *            animate={{ opacity: 1 }}
     *            exit={{ opacity: 0 }}
     *          />
     *        )}
     *     </AnimatePresence>
     *   )
     * }
     * ```
     */
    exit?: TargetAndTransition | VariantLabels;
    /**
     * Variants allow you to define animation states and organise them by name. They allow
     * you to control animations throughout a component tree by switching a single `animate` prop.
     *
     * Using `transition` options like `delayChildren` and `staggerChildren`, you can orchestrate
     * when children animations play relative to their parent.

     *
     * After passing variants to one or more `motion` component's `variants` prop, these variants
     * can be used in place of values on the `animate`, `initial`, `whileFocus`, `whileTap` and `whileHover` props.
     *
     * ```jsx
     * const variants = {
     *   active: {
     *       backgroundColor: "#f00"
     *   },
     *   inactive: {
     *     backgroundColor: "#fff",
     *     transition: { duration: 2 }
     *   }
     * }
     *
     * <motion.div variants={variants} animate="active" />
     * ```
     */
    variants?: Variants;
    /**
     * Default transition. If no `transition` is defined in `animate`, it will use the transition defined here.
     * ```jsx
     * const spring = {
     *   type: "spring",
     *   damping: 10,
     *   stiffness: 100
     * }
     *
     * <motion.div transition={spring} animate={{ scale: 1.2 }} />
     * ```
     */
    transition?: Transition$1;
}
/**
 * @public
 */
interface MotionAdvancedProps {
    /**
     * Custom data to use to resolve dynamic variants differently for each animating component.
     *
     * ```jsx
     * const variants = {
     *   visible: (custom) => ({
     *     opacity: 1,
     *     transition: { delay: custom * 0.2 }
     *   })
     * }
     *
     * <motion.div custom={0} animate="visible" variants={variants} />
     * <motion.div custom={1} animate="visible" variants={variants} />
     * <motion.div custom={2} animate="visible" variants={variants} />
     * ```
     *
     * @public
     */
    custom?: any;
    /**
     * @public
     * Set to `false` to prevent inheriting variant changes from its parent.
     */
    inherit?: boolean;
    /**
     * @public
     * Set to `false` to prevent throwing an error when a `motion` component is used within a `LazyMotion` set to strict.
     */
    ignoreStrict?: boolean;
}
/**
 * Props for `motion` components.
 *
 * @public
 */
interface MotionProps extends AnimationProps, EventProps, PanHandlers, TapHandlers, HoverHandlers, FocusHandlers, ViewportProps, DraggableProps, LayoutProps, MotionAdvancedProps {
    /**
     *
     * The React DOM `style` prop, enhanced with support for `MotionValue`s and separate `transform` values.
     *
     * ```jsx
     * export const MyComponent = () => {
     *   const x = useMotionValue(0)
     *
     *   return <motion.div style={{ x, opacity: 1, scale: 0.5 }} />
     * }
     * ```
     */
    style?: MotionStyle$2;
    /**
     * By default, Framer Motion generates a `transform` property with a sensible transform order. `transformTemplate`
     * can be used to create a different order, or to append/preprend the automatically generated `transform` property.
     *
     * ```jsx
     * <motion.div
     *   style={{ x: 0, rotate: 180 }}
     *   transformTemplate={
     *     ({ x, rotate }) => `rotate(${rotate}deg) translateX(${x}px)`
     *   }
     * />
     * ```
     *
     * @param transform - The latest animated transform props.
     * @param generatedTransform - The transform string as automatically generated by Framer Motion
     *
     * @public
     */
    transformTemplate?(transform: TransformProperties, generatedTransform: string): string;
    children?: React.ReactNode | MotionValue<number> | MotionValue<string>;
    "data-framer-appear-id"?: string;
}

type UnionStringArray$1<T extends Readonly<string[]>> = T[number];
declare const htmlElements: readonly ["a", "abbr", "address", "area", "article", "aside", "audio", "b", "base", "bdi", "bdo", "big", "blockquote", "body", "br", "button", "canvas", "caption", "cite", "code", "col", "colgroup", "data", "datalist", "dd", "del", "details", "dfn", "dialog", "div", "dl", "dt", "em", "embed", "fieldset", "figcaption", "figure", "footer", "form", "h1", "h2", "h3", "h4", "h5", "h6", "head", "header", "hgroup", "hr", "html", "i", "iframe", "img", "input", "ins", "kbd", "keygen", "label", "legend", "li", "link", "main", "map", "mark", "menu", "menuitem", "meta", "meter", "nav", "noscript", "object", "ol", "optgroup", "option", "output", "p", "param", "picture", "pre", "progress", "q", "rp", "rt", "ruby", "s", "samp", "script", "section", "select", "small", "source", "span", "strong", "style", "sub", "summary", "sup", "table", "tbody", "td", "textarea", "tfoot", "th", "thead", "time", "title", "tr", "track", "u", "ul", "var", "video", "wbr", "webview"];
type HTMLElements = UnionStringArray$1<typeof htmlElements>;

interface TransformOrigin {
    originX?: number | string;
    originY?: number | string;
    originZ?: number | string;
}
interface HTMLRenderState {
    /**
     * A mutable record of transforms we want to apply directly to the rendered Element
     * every frame. We use a mutable data structure to reduce GC during animations.
     */
    transform: ResolvedValues$1;
    /**
     * A mutable record of transform origins we want to apply directly to the rendered Element
     * every frame. We use a mutable data structure to reduce GC during animations.
     */
    transformOrigin: TransformOrigin;
    /**
     * A mutable record of styles we want to apply directly to the rendered Element
     * every frame. We use a mutable data structure to reduce GC during animations.
     */
    style: ResolvedValues$1;
    /**
     * A mutable record of CSS variables we want to apply directly to the rendered Element
     * every frame. We use a mutable data structure to reduce GC during animations.
     */
    vars: ResolvedValues$1;
}
/**
 * @public
 */
type ForwardRefComponent<T, P> = {
    readonly $$typeof: symbol;
} & ((props: PropsWithoutRef<P> & RefAttributes<T>) => JSX.Element);
/**
 * Support for React component props
 */
type UnwrapFactoryAttributes<F> = F extends DetailedHTMLFactory<infer P, any> ? P : never;
type UnwrapFactoryElement<F> = F extends DetailedHTMLFactory<any, infer P> ? P : never;
type HTMLAttributesWithoutMotionProps<Attributes extends HTMLAttributes<Element>, Element extends HTMLElement> = {
    [K in Exclude<keyof Attributes, keyof MotionProps>]?: Attributes[K];
};
/**
 * @public
 */
type HTMLMotionProps<TagName extends keyof ReactHTML> = HTMLAttributesWithoutMotionProps<UnwrapFactoryAttributes<ReactHTML[TagName]>, UnwrapFactoryElement<ReactHTML[TagName]>> & MotionProps;
/**
 * Motion-optimised versions of React's HTML components.
 *
 * @public
 */
type HTMLMotionComponents = {
    [K in HTMLElements]: ForwardRefComponent<UnwrapFactoryElement<ReactHTML[K]>, HTMLMotionProps<K>>;
};

type UnionStringArray<T extends Readonly<string[]>> = T[number];
declare const svgElements: readonly ["animate", "circle", "defs", "desc", "ellipse", "g", "image", "line", "filter", "marker", "mask", "metadata", "path", "pattern", "polygon", "polyline", "rect", "stop", "svg", "switch", "symbol", "text", "tspan", "use", "view", "clipPath", "feBlend", "feColorMatrix", "feComponentTransfer", "feComposite", "feConvolveMatrix", "feDiffuseLighting", "feDisplacementMap", "feDistantLight", "feDropShadow", "feFlood", "feFuncA", "feFuncB", "feFuncG", "feFuncR", "feGaussianBlur", "feImage", "feMerge", "feMergeNode", "feMorphology", "feOffset", "fePointLight", "feSpecularLighting", "feSpotLight", "feTile", "feTurbulence", "foreignObject", "linearGradient", "radialGradient", "textPath"];
type SVGElements = UnionStringArray<typeof svgElements>;

interface SVGRenderState extends HTMLRenderState {
    /**
     * Measured dimensions of the SVG element to be used to calculate a transform-origin.
     */
    dimensions?: SVGDimensions;
    /**
     * A mutable record of attributes we want to apply directly to the rendered Element
     * every frame. We use a mutable data structure to reduce GC during animations.
     */
    attrs: ResolvedValues$1;
}
type SVGDimensions = {
    x: number;
    y: number;
    width: number;
    height: number;
};
interface SVGAttributesWithoutMotionProps<T> extends Pick<SVGAttributes$1<T>, Exclude<keyof SVGAttributes$1<T>, keyof MotionProps>> {
}
/**
 * Blanket-accept any SVG attribute as a `MotionValue`
 * @public
 */
type SVGAttributesAsMotionValues<T> = MakeMotion<SVGAttributesWithoutMotionProps<T>>;
type UnwrapSVGFactoryElement<F> = F extends React.SVGProps<infer P> ? P : never;
/**
 * @public
 */
interface SVGMotionProps<T> extends SVGAttributesAsMotionValues<T>, MotionProps {
}
/**
 * Motion-optimised versions of React's SVG components.
 *
 * @public
 */
type SVGMotionComponents = {
    [K in SVGElements]: ForwardRefComponent<UnwrapSVGFactoryElement<JSX.IntrinsicElements[K]>, SVGMotionProps<UnwrapSVGFactoryElement<JSX.IntrinsicElements[K]>>>;
};

declare function createMotionComponent<Props extends {}, Instance = HTMLElement | SVGElement, RenderState = HTMLRenderState | SVGRenderState>(Component: string | React.ComponentType<React.PropsWithChildren<Props>>, options?: {
    forwardMotionProps: boolean;
}): react.ForwardRefExoticComponent<react.PropsWithoutRef<{ [K in Exclude<keyof Props, keyof MotionProps>]?: Props[K] | undefined; } & MotionProps> & react.RefAttributes<Instance>>;

declare function createMinimalMotionComponent<Props extends {}, Instance = HTMLElement | SVGElement, RenderState = HTMLRenderState | SVGRenderState>(Component: string | React.ComponentType<React.PropsWithChildren<Props>>, options?: {
    forwardMotionProps: boolean;
}): react.ForwardRefExoticComponent<react.PropsWithoutRef<{ [K in Exclude<keyof Props, keyof MotionProps>]?: Props[K] | undefined; } & MotionProps> & react.RefAttributes<Instance>>;

/**
 * HTML components
 */
declare const MotionA$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    type?: string | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    media?: string | undefined;
    target?: react.HTMLAttributeAnchorTarget | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    href?: string | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLAnchorElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLAnchorElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLAnchorElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLAnchorElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLAnchorElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLAnchorElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLAnchorElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLAnchorElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLAnchorElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLAnchorElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLAnchorElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLAnchorElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLAnchorElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLAnchorElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLAnchorElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLAnchorElement> | undefined;
    onChange?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onInput?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onReset?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onError?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLAnchorElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLAnchorElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLAnchorElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLAnchorElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLAnchorElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLAnchorElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLAnchorElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLAnchorElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLAnchorElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLAnchorElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLAnchorElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLAnchorElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLAnchorElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLAnchorElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLAnchorElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLAnchorElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLAnchorElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLAnchorElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLAnchorElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLAnchorElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLAnchorElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLAnchorElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLAnchorElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLAnchorElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLAnchorElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    download?: any;
    hrefLang?: string | undefined;
    ping?: string | undefined;
    referrerPolicy?: react.HTMLAttributeReferrerPolicy | undefined;
} & MotionProps & react.RefAttributes<HTMLAnchorElement>>;
declare const MotionAbbr$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionAddress$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionArea$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    media?: string | undefined;
    target?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    href?: string | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLAreaElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLAreaElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLAreaElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLAreaElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLAreaElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLAreaElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLAreaElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLAreaElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLAreaElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLAreaElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLAreaElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLAreaElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLAreaElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLAreaElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLAreaElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLAreaElement> | undefined;
    onChange?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onInput?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onReset?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onError?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLAreaElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLAreaElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLAreaElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLAreaElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLAreaElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLAreaElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLAreaElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLAreaElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLAreaElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLAreaElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLAreaElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLAreaElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLAreaElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLAreaElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLAreaElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLAreaElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLAreaElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLAreaElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLAreaElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLAreaElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLAreaElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLAreaElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLAreaElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLAreaElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLAreaElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    download?: any;
    hrefLang?: string | undefined;
    referrerPolicy?: react.HTMLAttributeReferrerPolicy | undefined;
    alt?: string | undefined;
    coords?: string | undefined;
    shape?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLAreaElement>>;
declare const MotionArticle$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionAside$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionAudio$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    crossOrigin?: "" | "anonymous" | "use-credentials" | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLAudioElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLAudioElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLAudioElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLAudioElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLAudioElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLAudioElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLAudioElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLAudioElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLAudioElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLAudioElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLAudioElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLAudioElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLAudioElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLAudioElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLAudioElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLAudioElement> | undefined;
    onChange?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onInput?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onReset?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onError?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLAudioElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLAudioElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLAudioElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLAudioElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLAudioElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLAudioElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLAudioElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLAudioElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLAudioElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLAudioElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLAudioElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLAudioElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLAudioElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLAudioElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLAudioElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLAudioElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLAudioElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLAudioElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLAudioElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLAudioElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLAudioElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLAudioElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLAudioElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLAudioElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLAudioElement> | undefined;
    loop?: boolean | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    autoPlay?: boolean | undefined;
    controls?: boolean | undefined;
    controlsList?: string | undefined;
    mediaGroup?: string | undefined;
    muted?: boolean | undefined;
    playsInline?: boolean | undefined;
    preload?: string | undefined;
    src?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLAudioElement>>;
declare const MotionB$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionBase$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    target?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    href?: string | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLBaseElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLBaseElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLBaseElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLBaseElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLBaseElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLBaseElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLBaseElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLBaseElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLBaseElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLBaseElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLBaseElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLBaseElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLBaseElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLBaseElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLBaseElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLBaseElement> | undefined;
    onChange?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onInput?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onReset?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onError?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLBaseElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLBaseElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLBaseElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLBaseElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLBaseElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLBaseElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLBaseElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLBaseElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLBaseElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLBaseElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLBaseElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLBaseElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLBaseElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLBaseElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLBaseElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLBaseElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLBaseElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLBaseElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLBaseElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLBaseElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLBaseElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLBaseElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLBaseElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLBaseElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLBaseElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLBaseElement>>;
declare const MotionBdi$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionBdo$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionBig$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionBlockquote$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLQuoteElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLQuoteElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLQuoteElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLQuoteElement> | undefined;
    onChange?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onInput?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onReset?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onError?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLQuoteElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLQuoteElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLQuoteElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLQuoteElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLQuoteElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLQuoteElement> | undefined;
    nonce?: string | undefined;
    cite?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLQuoteElement>>;
declare const MotionBody$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLBodyElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLBodyElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLBodyElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLBodyElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLBodyElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLBodyElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLBodyElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLBodyElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLBodyElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLBodyElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLBodyElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLBodyElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLBodyElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLBodyElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLBodyElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLBodyElement> | undefined;
    onChange?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onInput?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onReset?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onError?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLBodyElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLBodyElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLBodyElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLBodyElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLBodyElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLBodyElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLBodyElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLBodyElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLBodyElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLBodyElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLBodyElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLBodyElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLBodyElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLBodyElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLBodyElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLBodyElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLBodyElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLBodyElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLBodyElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLBodyElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLBodyElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLBodyElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLBodyElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLBodyElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLBodyElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLBodyElement>>;
declare const MotionButton$1: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    type?: "button" | "reset" | "submit" | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLButtonElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLButtonElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLButtonElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLButtonElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLButtonElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLButtonElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLButtonElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLButtonElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLButtonElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLButtonElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLButtonElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLButtonElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLButtonElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLButtonElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLButtonElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLButtonElement> | undefined;
    onChange?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onInput?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onReset?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onError?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLButtonElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLButtonElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLButtonElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLButtonElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLButtonElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLButtonElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLButtonElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLButtonElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLButtonElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLButtonElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLButtonElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLButtonElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLButtonElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLButtonElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLButtonElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLButtonElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLButtonElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLButtonElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLButtonElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLButtonElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLButtonElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLButtonElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLButtonElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLButtonElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLButtonElement> | undefined;
    nonce?: string | undefined;
    disabled?: boolean | undefined;
    form?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    formAction?: string | undefined;
    formEncType?: string | undefined;
    formMethod?: string | undefined;
    formNoValidate?: boolean | undefined;
    formTarget?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLButtonElement>>;
declare const MotionCanvas$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLCanvasElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLCanvasElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLCanvasElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLCanvasElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLCanvasElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLCanvasElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLCanvasElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLCanvasElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLCanvasElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLCanvasElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLCanvasElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLCanvasElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLCanvasElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLCanvasElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLCanvasElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLCanvasElement> | undefined;
    onChange?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onInput?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onReset?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onError?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLCanvasElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLCanvasElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLCanvasElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLCanvasElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLCanvasElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLCanvasElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLCanvasElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLCanvasElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLCanvasElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLCanvasElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLCanvasElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLCanvasElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLCanvasElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLCanvasElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLCanvasElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLCanvasElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLCanvasElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLCanvasElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLCanvasElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLCanvasElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLCanvasElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLCanvasElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLCanvasElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLCanvasElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLCanvasElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLCanvasElement>>;
declare const MotionCaption$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionCite$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionCode$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionCol$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableColElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableColElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableColElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableColElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableColElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableColElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableColElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableColElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableColElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableColElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    span?: number | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTableColElement>>;
declare const MotionColgroup$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableColElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableColElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableColElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableColElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableColElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableColElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableColElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableColElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableColElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableColElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    span?: number | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTableColElement>>;
declare const MotionData$1: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLDataElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLDataElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLDataElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLDataElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLDataElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLDataElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLDataElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLDataElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLDataElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLDataElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLDataElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLDataElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLDataElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLDataElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLDataElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLDataElement> | undefined;
    onChange?: react.FormEventHandler<HTMLDataElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLDataElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLDataElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLDataElement> | undefined;
    onInput?: react.FormEventHandler<HTMLDataElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLDataElement> | undefined;
    onReset?: react.FormEventHandler<HTMLDataElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLDataElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLDataElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLDataElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLDataElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLDataElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onError?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLDataElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLDataElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLDataElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLDataElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLDataElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLDataElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLDataElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLDataElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLDataElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLDataElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLDataElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLDataElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLDataElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLDataElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLDataElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLDataElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLDataElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLDataElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLDataElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLDataElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLDataElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLDataElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLDataElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLDataElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLDataElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLDataElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLDataElement>>;
declare const MotionDatalist$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLDataListElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLDataListElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLDataListElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLDataListElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLDataListElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLDataListElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLDataListElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLDataListElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLDataListElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLDataListElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLDataListElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLDataListElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLDataListElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLDataListElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLDataListElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLDataListElement> | undefined;
    onChange?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onInput?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onReset?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onError?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLDataListElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLDataListElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLDataListElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLDataListElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLDataListElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLDataListElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLDataListElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLDataListElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLDataListElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLDataListElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLDataListElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLDataListElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLDataListElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLDataListElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLDataListElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLDataListElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLDataListElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLDataListElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLDataListElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLDataListElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLDataListElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLDataListElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLDataListElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLDataListElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLDataListElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLDataListElement>>;
declare const MotionDd$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionDel$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLModElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLModElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLModElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLModElement> | undefined;
    onChange?: react.FormEventHandler<HTMLModElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLModElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onInput?: react.FormEventHandler<HTMLModElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onReset?: react.FormEventHandler<HTMLModElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLModElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLModElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onError?: react.ReactEventHandler<HTMLModElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLModElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLModElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLModElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLModElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLModElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLModElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLModElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLModElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLModElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLModElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLModElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLModElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLModElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLModElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLModElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLModElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLModElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLModElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLModElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLModElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLModElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLModElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLModElement> | undefined;
    nonce?: string | undefined;
    cite?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    dateTime?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLModElement>>;
declare const MotionDetails$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLDetailsElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLDetailsElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLDetailsElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLDetailsElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLDetailsElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLDetailsElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLDetailsElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLDetailsElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLDetailsElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLDetailsElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLDetailsElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLDetailsElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLDetailsElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLDetailsElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLDetailsElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLDetailsElement> | undefined;
    onChange?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onInput?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onReset?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onError?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLDetailsElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLDetailsElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLDetailsElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLDetailsElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLDetailsElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLDetailsElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLDetailsElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLDetailsElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLDetailsElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLDetailsElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLDetailsElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLDetailsElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLDetailsElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLDetailsElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLDetailsElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLDetailsElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLDetailsElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLDetailsElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLDetailsElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLDetailsElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLDetailsElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLDetailsElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLDetailsElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLDetailsElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLDetailsElement> | undefined;
    nonce?: string | undefined;
    open?: boolean | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    onToggle?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
} & MotionProps & react.RefAttributes<HTMLDetailsElement>>;
declare const MotionDfn$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionDialog$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLDialogElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLDialogElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLDialogElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLDialogElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLDialogElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLDialogElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLDialogElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLDialogElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLDialogElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLDialogElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLDialogElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLDialogElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLDialogElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLDialogElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLDialogElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLDialogElement> | undefined;
    onChange?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onInput?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onReset?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onError?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLDialogElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLDialogElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLDialogElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLDialogElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLDialogElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLDialogElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLDialogElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLDialogElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLDialogElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLDialogElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLDialogElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLDialogElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLDialogElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLDialogElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLDialogElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLDialogElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLDialogElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLDialogElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLDialogElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLDialogElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLDialogElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLDialogElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLDialogElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLDialogElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLDialogElement> | undefined;
    nonce?: string | undefined;
    open?: boolean | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    onCancel?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onClose?: react.ReactEventHandler<HTMLDialogElement> | undefined;
} & MotionProps & react.RefAttributes<HTMLDialogElement>>;
declare const MotionDiv$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLDivElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLDivElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLDivElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLDivElement> | undefined;
    onChange?: react.FormEventHandler<HTMLDivElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLDivElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    onInput?: react.FormEventHandler<HTMLDivElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    onReset?: react.FormEventHandler<HTMLDivElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLDivElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLDivElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onError?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLDivElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLDivElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLDivElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLDivElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLDivElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLDivElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLDivElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLDivElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLDivElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLDivElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLDivElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLDivElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLDivElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLDivElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLDivElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLDivElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLDivElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLDivElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLDivElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLDivElement>>;
declare const MotionDl$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLDListElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLDListElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLDListElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLDListElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLDListElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLDListElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLDListElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLDListElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLDListElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLDListElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLDListElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLDListElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLDListElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLDListElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLDListElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLDListElement> | undefined;
    onChange?: react.FormEventHandler<HTMLDListElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLDListElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLDListElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLDListElement> | undefined;
    onInput?: react.FormEventHandler<HTMLDListElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLDListElement> | undefined;
    onReset?: react.FormEventHandler<HTMLDListElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLDListElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLDListElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLDListElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLDListElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLDListElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onError?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLDListElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLDListElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLDListElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLDListElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLDListElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLDListElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLDListElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLDListElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLDListElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLDListElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLDListElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLDListElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLDListElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLDListElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLDListElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLDListElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLDListElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLDListElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLDListElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLDListElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLDListElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLDListElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLDListElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLDListElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLDListElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLDListElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLDListElement>>;
declare const MotionDt$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionEm$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionEmbed$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    type?: string | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLEmbedElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLEmbedElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLEmbedElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLEmbedElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLEmbedElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLEmbedElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLEmbedElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLEmbedElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLEmbedElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLEmbedElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLEmbedElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLEmbedElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLEmbedElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLEmbedElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLEmbedElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLEmbedElement> | undefined;
    onChange?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onInput?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onReset?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onError?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLEmbedElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLEmbedElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLEmbedElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLEmbedElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLEmbedElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLEmbedElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLEmbedElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLEmbedElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLEmbedElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLEmbedElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLEmbedElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLEmbedElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLEmbedElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLEmbedElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLEmbedElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLEmbedElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLEmbedElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLEmbedElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLEmbedElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLEmbedElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLEmbedElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLEmbedElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLEmbedElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLEmbedElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLEmbedElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    src?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLEmbedElement>>;
declare const MotionFieldset$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLFieldSetElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLFieldSetElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLFieldSetElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLFieldSetElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLFieldSetElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLFieldSetElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLFieldSetElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLFieldSetElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLFieldSetElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLFieldSetElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLFieldSetElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLFieldSetElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLFieldSetElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLFieldSetElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLFieldSetElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLFieldSetElement> | undefined;
    onChange?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onInput?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onReset?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onError?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLFieldSetElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLFieldSetElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLFieldSetElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLFieldSetElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLFieldSetElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLFieldSetElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLFieldSetElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLFieldSetElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLFieldSetElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLFieldSetElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLFieldSetElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLFieldSetElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLFieldSetElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLFieldSetElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLFieldSetElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLFieldSetElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLFieldSetElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLFieldSetElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLFieldSetElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLFieldSetElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLFieldSetElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLFieldSetElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLFieldSetElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLFieldSetElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLFieldSetElement> | undefined;
    nonce?: string | undefined;
    disabled?: boolean | undefined;
    form?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLFieldSetElement>>;
declare const MotionFigcaption$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionFigure$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionFooter$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionForm$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    method?: string | undefined;
    name?: string | undefined;
    target?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLFormElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLFormElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLFormElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLFormElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLFormElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLFormElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLFormElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLFormElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLFormElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLFormElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLFormElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLFormElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLFormElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLFormElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLFormElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLFormElement> | undefined;
    onChange?: react.FormEventHandler<HTMLFormElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLFormElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLFormElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLFormElement> | undefined;
    onInput?: react.FormEventHandler<HTMLFormElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLFormElement> | undefined;
    onReset?: react.FormEventHandler<HTMLFormElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLFormElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLFormElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLFormElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLFormElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLFormElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onError?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLFormElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLFormElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLFormElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLFormElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLFormElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLFormElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLFormElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLFormElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLFormElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLFormElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLFormElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLFormElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLFormElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLFormElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLFormElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLFormElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLFormElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLFormElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLFormElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLFormElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLFormElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLFormElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLFormElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLFormElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLFormElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLFormElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    acceptCharset?: string | undefined;
    action?: string | undefined;
    autoComplete?: string | undefined;
    encType?: string | undefined;
    noValidate?: boolean | undefined;
} & MotionProps & react.RefAttributes<HTMLFormElement>>;
declare const MotionH1$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onChange?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onReset?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onError?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHeadingElement>>;
declare const MotionH2$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onChange?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onReset?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onError?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHeadingElement>>;
declare const MotionH3$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onChange?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onReset?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onError?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHeadingElement>>;
declare const MotionH4$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onChange?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onReset?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onError?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHeadingElement>>;
declare const MotionH5$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onChange?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onReset?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onError?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHeadingElement>>;
declare const MotionH6$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onChange?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onReset?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onError?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHeadingElement>>;
declare const MotionHead$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHeadElement>>;
declare const MotionHeader$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionHgroup$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionHr$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLHRElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLHRElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLHRElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLHRElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLHRElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLHRElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLHRElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLHRElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLHRElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLHRElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLHRElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLHRElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLHRElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLHRElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLHRElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLHRElement> | undefined;
    onChange?: react.FormEventHandler<HTMLHRElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLHRElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLHRElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLHRElement> | undefined;
    onInput?: react.FormEventHandler<HTMLHRElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLHRElement> | undefined;
    onReset?: react.FormEventHandler<HTMLHRElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLHRElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLHRElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLHRElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLHRElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLHRElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onError?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLHRElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLHRElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLHRElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLHRElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLHRElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLHRElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLHRElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLHRElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLHRElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLHRElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLHRElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLHRElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLHRElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLHRElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLHRElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLHRElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLHRElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLHRElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLHRElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLHRElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLHRElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLHRElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLHRElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLHRElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLHRElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLHRElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHRElement>>;
declare const MotionHtml$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLHtmlElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLHtmlElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLHtmlElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLHtmlElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLHtmlElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLHtmlElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLHtmlElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLHtmlElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLHtmlElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLHtmlElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLHtmlElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLHtmlElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLHtmlElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLHtmlElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLHtmlElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLHtmlElement> | undefined;
    onChange?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onInput?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onReset?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onError?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLHtmlElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLHtmlElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLHtmlElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLHtmlElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLHtmlElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLHtmlElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLHtmlElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLHtmlElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLHtmlElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLHtmlElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLHtmlElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLHtmlElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLHtmlElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLHtmlElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLHtmlElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLHtmlElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLHtmlElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLHtmlElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLHtmlElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLHtmlElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLHtmlElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLHtmlElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLHtmlElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLHtmlElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLHtmlElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    manifest?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHtmlElement>>;
declare const MotionI$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionIframe$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLIFrameElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLIFrameElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLIFrameElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLIFrameElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLIFrameElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLIFrameElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLIFrameElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLIFrameElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLIFrameElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLIFrameElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLIFrameElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLIFrameElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLIFrameElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLIFrameElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLIFrameElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLIFrameElement> | undefined;
    onChange?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onInput?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onReset?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onError?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLIFrameElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLIFrameElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLIFrameElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLIFrameElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLIFrameElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLIFrameElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLIFrameElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLIFrameElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLIFrameElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLIFrameElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLIFrameElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLIFrameElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLIFrameElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLIFrameElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLIFrameElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLIFrameElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLIFrameElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLIFrameElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLIFrameElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLIFrameElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLIFrameElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLIFrameElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLIFrameElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLIFrameElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLIFrameElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    referrerPolicy?: react.HTMLAttributeReferrerPolicy | undefined;
    src?: string | undefined;
    allow?: string | undefined;
    allowFullScreen?: boolean | undefined;
    allowTransparency?: boolean | undefined;
    frameBorder?: string | number | undefined;
    loading?: "eager" | "lazy" | undefined;
    marginHeight?: number | undefined;
    marginWidth?: number | undefined;
    sandbox?: string | undefined;
    scrolling?: string | undefined;
    seamless?: boolean | undefined;
    srcDoc?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLIFrameElement>>;
declare const MotionImg$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    crossOrigin?: "" | "anonymous" | "use-credentials" | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLImageElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLImageElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLImageElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLImageElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLImageElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLImageElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLImageElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLImageElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLImageElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLImageElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLImageElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLImageElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLImageElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLImageElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLImageElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLImageElement> | undefined;
    onChange?: react.FormEventHandler<HTMLImageElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLImageElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLImageElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLImageElement> | undefined;
    onInput?: react.FormEventHandler<HTMLImageElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLImageElement> | undefined;
    onReset?: react.FormEventHandler<HTMLImageElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLImageElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLImageElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLImageElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLImageElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLImageElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onError?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLImageElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLImageElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLImageElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLImageElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLImageElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLImageElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLImageElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLImageElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLImageElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLImageElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLImageElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLImageElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLImageElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLImageElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLImageElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLImageElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLImageElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLImageElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLImageElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLImageElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLImageElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLImageElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLImageElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLImageElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLImageElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLImageElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    referrerPolicy?: react.HTMLAttributeReferrerPolicy | undefined;
    alt?: string | undefined;
    src?: string | undefined;
    loading?: "eager" | "lazy" | undefined;
    decoding?: "auto" | "async" | "sync" | undefined;
    fetchPriority?: "auto" | "high" | "low" | undefined;
    sizes?: string | undefined;
    srcSet?: string | undefined;
    useMap?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLImageElement>>;
declare const MotionInput$1: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    size?: number | undefined;
    hidden?: boolean | undefined;
    type?: react.HTMLInputTypeAttribute | undefined;
    min?: string | number | undefined;
    max?: string | number | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLInputElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLInputElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLInputElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLInputElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLInputElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLInputElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLInputElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLInputElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLInputElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLInputElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLInputElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLInputElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLInputElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLInputElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLInputElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLInputElement> | undefined;
    onChange?: react.ChangeEventHandler<HTMLInputElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLInputElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLInputElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLInputElement> | undefined;
    onInput?: react.FormEventHandler<HTMLInputElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLInputElement> | undefined;
    onReset?: react.FormEventHandler<HTMLInputElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLInputElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLInputElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLInputElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLInputElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLInputElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onError?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLInputElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLInputElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLInputElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLInputElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLInputElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLInputElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLInputElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLInputElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLInputElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLInputElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLInputElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLInputElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLInputElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLInputElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLInputElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLInputElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLInputElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLInputElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLInputElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLInputElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLInputElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLInputElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLInputElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLInputElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLInputElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLInputElement> | undefined;
    nonce?: string | undefined;
    multiple?: boolean | undefined;
    disabled?: boolean | undefined;
    form?: string | undefined;
    list?: string | undefined;
    step?: string | number | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    pattern?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    alt?: string | undefined;
    src?: string | undefined;
    formAction?: string | undefined;
    formEncType?: string | undefined;
    formMethod?: string | undefined;
    formNoValidate?: boolean | undefined;
    formTarget?: string | undefined;
    autoComplete?: react.HTMLInputAutoCompleteAttribute | undefined;
    accept?: string | undefined;
    capture?: boolean | "user" | "environment" | undefined;
    checked?: boolean | undefined;
    enterKeyHint?: "done" | "search" | "enter" | "go" | "next" | "previous" | "send" | undefined;
    maxLength?: number | undefined;
    minLength?: number | undefined;
    placeholder?: string | undefined;
    readOnly?: boolean | undefined;
    required?: boolean | undefined;
} & MotionProps & react.RefAttributes<HTMLInputElement>>;
declare const MotionIns$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLModElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLModElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLModElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLModElement> | undefined;
    onChange?: react.FormEventHandler<HTMLModElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLModElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onInput?: react.FormEventHandler<HTMLModElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onReset?: react.FormEventHandler<HTMLModElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLModElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLModElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onError?: react.ReactEventHandler<HTMLModElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLModElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLModElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLModElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLModElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLModElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLModElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLModElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLModElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLModElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLModElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLModElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLModElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLModElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLModElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLModElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLModElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLModElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLModElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLModElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLModElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLModElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLModElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLModElement> | undefined;
    nonce?: string | undefined;
    cite?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    dateTime?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLModElement>>;
declare const MotionKbd$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionKeygen$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    disabled?: boolean | undefined;
    form?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    challenge?: string | undefined;
    keyType?: string | undefined;
    keyParams?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionLabel$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLLabelElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLLabelElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLLabelElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLLabelElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLLabelElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLLabelElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLLabelElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLLabelElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLLabelElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLLabelElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLLabelElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLLabelElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLLabelElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLLabelElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLLabelElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLLabelElement> | undefined;
    onChange?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onInput?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onReset?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onError?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLLabelElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLLabelElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLLabelElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLLabelElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLLabelElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLLabelElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLLabelElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLLabelElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLLabelElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLLabelElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLLabelElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLLabelElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLLabelElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLLabelElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLLabelElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLLabelElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLLabelElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLLabelElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLLabelElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLLabelElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLLabelElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLLabelElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLLabelElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLLabelElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLLabelElement> | undefined;
    nonce?: string | undefined;
    form?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    htmlFor?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLLabelElement>>;
declare const MotionLegend$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLLegendElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLLegendElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLLegendElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLLegendElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLLegendElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLLegendElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLLegendElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLLegendElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLLegendElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLLegendElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLLegendElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLLegendElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLLegendElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLLegendElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLLegendElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLLegendElement> | undefined;
    onChange?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onInput?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onReset?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onError?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLLegendElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLLegendElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLLegendElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLLegendElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLLegendElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLLegendElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLLegendElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLLegendElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLLegendElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLLegendElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLLegendElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLLegendElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLLegendElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLLegendElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLLegendElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLLegendElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLLegendElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLLegendElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLLegendElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLLegendElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLLegendElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLLegendElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLLegendElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLLegendElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLLegendElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLLegendElement>>;
declare const MotionLi$1: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLLIElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLLIElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLLIElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLLIElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLLIElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLLIElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLLIElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLLIElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLLIElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLLIElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLLIElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLLIElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLLIElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLLIElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLLIElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLLIElement> | undefined;
    onChange?: react.FormEventHandler<HTMLLIElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLLIElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLLIElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLLIElement> | undefined;
    onInput?: react.FormEventHandler<HTMLLIElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLLIElement> | undefined;
    onReset?: react.FormEventHandler<HTMLLIElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLLIElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLLIElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLLIElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLLIElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLLIElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onError?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLLIElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLLIElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLLIElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLLIElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLLIElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLLIElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLLIElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLLIElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLLIElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLLIElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLLIElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLLIElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLLIElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLLIElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLLIElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLLIElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLLIElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLLIElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLLIElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLLIElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLLIElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLLIElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLLIElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLLIElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLLIElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLLIElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLLIElement>>;
declare const MotionLink$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    type?: string | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    media?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    crossOrigin?: "" | "anonymous" | "use-credentials" | undefined;
    href?: string | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLLinkElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLLinkElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLLinkElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLLinkElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLLinkElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLLinkElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLLinkElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLLinkElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLLinkElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLLinkElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLLinkElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLLinkElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLLinkElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLLinkElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLLinkElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLLinkElement> | undefined;
    onChange?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onInput?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onReset?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onError?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLLinkElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLLinkElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLLinkElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLLinkElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLLinkElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLLinkElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLLinkElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLLinkElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLLinkElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLLinkElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLLinkElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLLinkElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLLinkElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLLinkElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLLinkElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLLinkElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLLinkElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLLinkElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLLinkElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLLinkElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLLinkElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLLinkElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLLinkElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLLinkElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLLinkElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    hrefLang?: string | undefined;
    referrerPolicy?: react.HTMLAttributeReferrerPolicy | undefined;
    fetchPriority?: "auto" | "high" | "low" | undefined;
    sizes?: string | undefined;
    as?: string | undefined;
    integrity?: string | undefined;
    imageSrcSet?: string | undefined;
    imageSizes?: string | undefined;
    charSet?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLLinkElement>>;
declare const MotionMain$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionMap$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLMapElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLMapElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLMapElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLMapElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLMapElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLMapElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLMapElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLMapElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLMapElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLMapElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLMapElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLMapElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLMapElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLMapElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLMapElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLMapElement> | undefined;
    onChange?: react.FormEventHandler<HTMLMapElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLMapElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLMapElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLMapElement> | undefined;
    onInput?: react.FormEventHandler<HTMLMapElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLMapElement> | undefined;
    onReset?: react.FormEventHandler<HTMLMapElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLMapElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLMapElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLMapElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLMapElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLMapElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onError?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLMapElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLMapElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLMapElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLMapElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLMapElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLMapElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLMapElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLMapElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLMapElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLMapElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLMapElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLMapElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLMapElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLMapElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLMapElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLMapElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLMapElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLMapElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLMapElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLMapElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLMapElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLMapElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLMapElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLMapElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLMapElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLMapElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLMapElement>>;
declare const MotionMark$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionMenu$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    type?: string | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionMenuitem$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionMeter$1: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    min?: string | number | undefined;
    max?: string | number | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLMeterElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLMeterElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLMeterElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLMeterElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLMeterElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLMeterElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLMeterElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLMeterElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLMeterElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLMeterElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLMeterElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLMeterElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLMeterElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLMeterElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLMeterElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLMeterElement> | undefined;
    onChange?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onInput?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onReset?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onError?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLMeterElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLMeterElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLMeterElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLMeterElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLMeterElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLMeterElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLMeterElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLMeterElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLMeterElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLMeterElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLMeterElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLMeterElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLMeterElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLMeterElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLMeterElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLMeterElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLMeterElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLMeterElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLMeterElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLMeterElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLMeterElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLMeterElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLMeterElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLMeterElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLMeterElement> | undefined;
    nonce?: string | undefined;
    form?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    high?: number | undefined;
    low?: number | undefined;
    optimum?: number | undefined;
} & MotionProps & react.RefAttributes<HTMLMeterElement>>;
declare const MotionNav$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionObject$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    type?: string | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLObjectElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLObjectElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLObjectElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLObjectElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLObjectElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLObjectElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLObjectElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLObjectElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLObjectElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLObjectElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLObjectElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLObjectElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLObjectElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLObjectElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLObjectElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLObjectElement> | undefined;
    onChange?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onInput?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onReset?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onError?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLObjectElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLObjectElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLObjectElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLObjectElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLObjectElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLObjectElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLObjectElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLObjectElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLObjectElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLObjectElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLObjectElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLObjectElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLObjectElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLObjectElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLObjectElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLObjectElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLObjectElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLObjectElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLObjectElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLObjectElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLObjectElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLObjectElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLObjectElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLObjectElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLObjectElement> | undefined;
    nonce?: string | undefined;
    form?: string | undefined;
    data?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    useMap?: string | undefined;
    classID?: string | undefined;
    wmode?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLObjectElement>>;
declare const MotionOl$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    start?: number | undefined;
    type?: "1" | "a" | "i" | "A" | "I" | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLOListElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLOListElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLOListElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLOListElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLOListElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLOListElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLOListElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLOListElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLOListElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLOListElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLOListElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLOListElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLOListElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLOListElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLOListElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLOListElement> | undefined;
    onChange?: react.FormEventHandler<HTMLOListElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLOListElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLOListElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLOListElement> | undefined;
    onInput?: react.FormEventHandler<HTMLOListElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLOListElement> | undefined;
    onReset?: react.FormEventHandler<HTMLOListElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLOListElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLOListElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLOListElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLOListElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLOListElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onError?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLOListElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLOListElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLOListElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLOListElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLOListElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLOListElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLOListElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLOListElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLOListElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLOListElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLOListElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLOListElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLOListElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLOListElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLOListElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLOListElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLOListElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLOListElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLOListElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLOListElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLOListElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLOListElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLOListElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLOListElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLOListElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLOListElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    reversed?: boolean | undefined;
} & MotionProps & react.RefAttributes<HTMLOListElement>>;
declare const MotionOptgroup$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLOptGroupElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLOptGroupElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLOptGroupElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLOptGroupElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLOptGroupElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLOptGroupElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLOptGroupElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLOptGroupElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLOptGroupElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLOptGroupElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLOptGroupElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLOptGroupElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLOptGroupElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLOptGroupElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLOptGroupElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLOptGroupElement> | undefined;
    onChange?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onInput?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onReset?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onError?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLOptGroupElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLOptGroupElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLOptGroupElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLOptGroupElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLOptGroupElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLOptGroupElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLOptGroupElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLOptGroupElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLOptGroupElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLOptGroupElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLOptGroupElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLOptGroupElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLOptGroupElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLOptGroupElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLOptGroupElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLOptGroupElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLOptGroupElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLOptGroupElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLOptGroupElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLOptGroupElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLOptGroupElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLOptGroupElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLOptGroupElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLOptGroupElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLOptGroupElement> | undefined;
    nonce?: string | undefined;
    disabled?: boolean | undefined;
    label?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLOptGroupElement>>;
declare const MotionOption$1: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLOptionElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLOptionElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLOptionElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLOptionElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLOptionElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLOptionElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLOptionElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLOptionElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLOptionElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLOptionElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLOptionElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLOptionElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLOptionElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLOptionElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLOptionElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLOptionElement> | undefined;
    onChange?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onInput?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onReset?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onError?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLOptionElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLOptionElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLOptionElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLOptionElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLOptionElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLOptionElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLOptionElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLOptionElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLOptionElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLOptionElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLOptionElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLOptionElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLOptionElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLOptionElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLOptionElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLOptionElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLOptionElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLOptionElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLOptionElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLOptionElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLOptionElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLOptionElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLOptionElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLOptionElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLOptionElement> | undefined;
    nonce?: string | undefined;
    disabled?: boolean | undefined;
    label?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    selected?: boolean | undefined;
} & MotionProps & react.RefAttributes<HTMLOptionElement>>;
declare const MotionOutput$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLOutputElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLOutputElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLOutputElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLOutputElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLOutputElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLOutputElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLOutputElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLOutputElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLOutputElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLOutputElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLOutputElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLOutputElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLOutputElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLOutputElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLOutputElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLOutputElement> | undefined;
    onChange?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onInput?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onReset?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onError?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLOutputElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLOutputElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLOutputElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLOutputElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLOutputElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLOutputElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLOutputElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLOutputElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLOutputElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLOutputElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLOutputElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLOutputElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLOutputElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLOutputElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLOutputElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLOutputElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLOutputElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLOutputElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLOutputElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLOutputElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLOutputElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLOutputElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLOutputElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLOutputElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLOutputElement> | undefined;
    nonce?: string | undefined;
    form?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    htmlFor?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLOutputElement>>;
declare const MotionP$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLParagraphElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLParagraphElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLParagraphElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLParagraphElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLParagraphElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLParagraphElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLParagraphElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLParagraphElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLParagraphElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLParagraphElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLParagraphElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLParagraphElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLParagraphElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLParagraphElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLParagraphElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLParagraphElement> | undefined;
    onChange?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onInput?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onReset?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onError?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLParagraphElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLParagraphElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLParagraphElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLParagraphElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLParagraphElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLParagraphElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLParagraphElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLParagraphElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLParagraphElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLParagraphElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLParagraphElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLParagraphElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLParagraphElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLParagraphElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLParagraphElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLParagraphElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLParagraphElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLParagraphElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLParagraphElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLParagraphElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLParagraphElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLParagraphElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLParagraphElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLParagraphElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLParagraphElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLParagraphElement>>;
declare const MotionParam$1: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLParamElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLParamElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLParamElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLParamElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLParamElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLParamElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLParamElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLParamElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLParamElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLParamElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLParamElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLParamElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLParamElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLParamElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLParamElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLParamElement> | undefined;
    onChange?: react.FormEventHandler<HTMLParamElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLParamElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLParamElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLParamElement> | undefined;
    onInput?: react.FormEventHandler<HTMLParamElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLParamElement> | undefined;
    onReset?: react.FormEventHandler<HTMLParamElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLParamElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLParamElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLParamElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLParamElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLParamElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onError?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLParamElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLParamElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLParamElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLParamElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLParamElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLParamElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLParamElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLParamElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLParamElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLParamElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLParamElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLParamElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLParamElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLParamElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLParamElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLParamElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLParamElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLParamElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLParamElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLParamElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLParamElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLParamElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLParamElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLParamElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLParamElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLParamElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLParamElement>>;
declare const MotionPicture$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionPre$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLPreElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLPreElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLPreElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLPreElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLPreElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLPreElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLPreElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLPreElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLPreElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLPreElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLPreElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLPreElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLPreElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLPreElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLPreElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLPreElement> | undefined;
    onChange?: react.FormEventHandler<HTMLPreElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLPreElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLPreElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLPreElement> | undefined;
    onInput?: react.FormEventHandler<HTMLPreElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLPreElement> | undefined;
    onReset?: react.FormEventHandler<HTMLPreElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLPreElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLPreElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLPreElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLPreElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLPreElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onError?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLPreElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLPreElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLPreElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLPreElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLPreElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLPreElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLPreElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLPreElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLPreElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLPreElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLPreElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLPreElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLPreElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLPreElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLPreElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLPreElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLPreElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLPreElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLPreElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLPreElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLPreElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLPreElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLPreElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLPreElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLPreElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLPreElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLPreElement>>;
declare const MotionProgress$1: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    max?: string | number | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLProgressElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLProgressElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLProgressElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLProgressElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLProgressElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLProgressElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLProgressElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLProgressElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLProgressElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLProgressElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLProgressElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLProgressElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLProgressElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLProgressElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLProgressElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLProgressElement> | undefined;
    onChange?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onInput?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onReset?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onError?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLProgressElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLProgressElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLProgressElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLProgressElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLProgressElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLProgressElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLProgressElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLProgressElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLProgressElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLProgressElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLProgressElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLProgressElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLProgressElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLProgressElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLProgressElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLProgressElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLProgressElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLProgressElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLProgressElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLProgressElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLProgressElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLProgressElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLProgressElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLProgressElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLProgressElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLProgressElement>>;
declare const MotionQ$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLQuoteElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLQuoteElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLQuoteElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLQuoteElement> | undefined;
    onChange?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onInput?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onReset?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onError?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLQuoteElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLQuoteElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLQuoteElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLQuoteElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLQuoteElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLQuoteElement> | undefined;
    nonce?: string | undefined;
    cite?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLQuoteElement>>;
declare const MotionRp$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionRt$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionRuby$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionS$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionSamp$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionScript$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    type?: string | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    crossOrigin?: "" | "anonymous" | "use-credentials" | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLScriptElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLScriptElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLScriptElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLScriptElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLScriptElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLScriptElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLScriptElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLScriptElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLScriptElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLScriptElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLScriptElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLScriptElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLScriptElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLScriptElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLScriptElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLScriptElement> | undefined;
    onChange?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onInput?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onReset?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onError?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLScriptElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLScriptElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLScriptElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLScriptElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLScriptElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLScriptElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLScriptElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLScriptElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLScriptElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLScriptElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLScriptElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLScriptElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLScriptElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLScriptElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLScriptElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLScriptElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLScriptElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLScriptElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLScriptElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLScriptElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLScriptElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLScriptElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLScriptElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLScriptElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLScriptElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    referrerPolicy?: react.HTMLAttributeReferrerPolicy | undefined;
    src?: string | undefined;
    integrity?: string | undefined;
    charSet?: string | undefined;
    async?: boolean | undefined;
    defer?: boolean | undefined;
    noModule?: boolean | undefined;
} & MotionProps & react.RefAttributes<HTMLScriptElement>>;
declare const MotionSection$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionSelect$1: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    size?: number | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLSelectElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLSelectElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLSelectElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLSelectElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLSelectElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLSelectElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLSelectElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLSelectElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLSelectElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLSelectElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLSelectElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLSelectElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLSelectElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLSelectElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLSelectElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLSelectElement> | undefined;
    onChange?: react.ChangeEventHandler<HTMLSelectElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onInput?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onReset?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onError?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLSelectElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLSelectElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLSelectElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLSelectElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLSelectElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLSelectElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLSelectElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLSelectElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLSelectElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLSelectElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLSelectElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLSelectElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLSelectElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLSelectElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLSelectElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLSelectElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLSelectElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLSelectElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLSelectElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLSelectElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLSelectElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLSelectElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLSelectElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLSelectElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLSelectElement> | undefined;
    nonce?: string | undefined;
    multiple?: boolean | undefined;
    disabled?: boolean | undefined;
    form?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    autoComplete?: string | undefined;
    required?: boolean | undefined;
} & MotionProps & react.RefAttributes<HTMLSelectElement>>;
declare const MotionSmall$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionSource$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    type?: string | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    media?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLSourceElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLSourceElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLSourceElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLSourceElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLSourceElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLSourceElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLSourceElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLSourceElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLSourceElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLSourceElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLSourceElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLSourceElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLSourceElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLSourceElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLSourceElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLSourceElement> | undefined;
    onChange?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onInput?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onReset?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onError?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLSourceElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLSourceElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLSourceElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLSourceElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLSourceElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLSourceElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLSourceElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLSourceElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLSourceElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLSourceElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLSourceElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLSourceElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLSourceElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLSourceElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLSourceElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLSourceElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLSourceElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLSourceElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLSourceElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLSourceElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLSourceElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLSourceElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLSourceElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLSourceElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLSourceElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    src?: string | undefined;
    sizes?: string | undefined;
    srcSet?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLSourceElement>>;
declare const MotionSpan$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLSpanElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLSpanElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLSpanElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLSpanElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLSpanElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLSpanElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLSpanElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLSpanElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLSpanElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLSpanElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLSpanElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLSpanElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLSpanElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLSpanElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLSpanElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLSpanElement> | undefined;
    onChange?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onInput?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onReset?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onError?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLSpanElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLSpanElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLSpanElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLSpanElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLSpanElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLSpanElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLSpanElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLSpanElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLSpanElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLSpanElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLSpanElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLSpanElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLSpanElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLSpanElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLSpanElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLSpanElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLSpanElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLSpanElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLSpanElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLSpanElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLSpanElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLSpanElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLSpanElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLSpanElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLSpanElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLSpanElement>>;
declare const MotionStrong$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionStyle$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    type?: string | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    media?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLStyleElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLStyleElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLStyleElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLStyleElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLStyleElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLStyleElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLStyleElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLStyleElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLStyleElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLStyleElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLStyleElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLStyleElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLStyleElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLStyleElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLStyleElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLStyleElement> | undefined;
    onChange?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onInput?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onReset?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onError?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLStyleElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLStyleElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLStyleElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLStyleElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLStyleElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLStyleElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLStyleElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLStyleElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLStyleElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLStyleElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLStyleElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLStyleElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLStyleElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLStyleElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLStyleElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLStyleElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLStyleElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLStyleElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLStyleElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLStyleElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLStyleElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLStyleElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLStyleElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLStyleElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLStyleElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    scoped?: boolean | undefined;
} & MotionProps & react.RefAttributes<HTMLStyleElement>>;
declare const MotionSub$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionSummary$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionSup$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionTable$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    border?: number | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    summary?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    frame?: boolean | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    align?: "left" | "right" | "center" | undefined;
    bgcolor?: string | undefined;
    cellPadding?: string | number | undefined;
    cellSpacing?: string | number | undefined;
    rules?: "all" | "columns" | "none" | "rows" | "groups" | undefined;
} & MotionProps & react.RefAttributes<HTMLTableElement>>;
declare const MotionTbody$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableSectionElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableSectionElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableSectionElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableSectionElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableSectionElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTableSectionElement>>;
declare const MotionTd$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableDataCellElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableDataCellElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableDataCellElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableDataCellElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableDataCellElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableDataCellElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableDataCellElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableDataCellElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableDataCellElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableDataCellElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableDataCellElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableDataCellElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableDataCellElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableDataCellElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableDataCellElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableDataCellElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableDataCellElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableDataCellElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableDataCellElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableDataCellElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableDataCellElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableDataCellElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableDataCellElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableDataCellElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableDataCellElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableDataCellElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableDataCellElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableDataCellElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableDataCellElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableDataCellElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableDataCellElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableDataCellElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableDataCellElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableDataCellElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableDataCellElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableDataCellElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableDataCellElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableDataCellElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableDataCellElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableDataCellElement> | undefined;
    nonce?: string | undefined;
    abbr?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    align?: "left" | "right" | "center" | "justify" | "char" | undefined;
    colSpan?: number | undefined;
    headers?: string | undefined;
    rowSpan?: number | undefined;
    scope?: string | undefined;
    valign?: "bottom" | "top" | "baseline" | "middle" | undefined;
} & MotionProps & react.RefAttributes<HTMLTableDataCellElement>>;
declare const MotionTextarea$1: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTextAreaElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTextAreaElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTextAreaElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTextAreaElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTextAreaElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTextAreaElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTextAreaElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTextAreaElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTextAreaElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTextAreaElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTextAreaElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTextAreaElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTextAreaElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTextAreaElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTextAreaElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTextAreaElement> | undefined;
    onChange?: react.ChangeEventHandler<HTMLTextAreaElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTextAreaElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTextAreaElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTextAreaElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTextAreaElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTextAreaElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTextAreaElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTextAreaElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTextAreaElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTextAreaElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTextAreaElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTextAreaElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTextAreaElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTextAreaElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTextAreaElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTextAreaElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTextAreaElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTextAreaElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTextAreaElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTextAreaElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTextAreaElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTextAreaElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTextAreaElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTextAreaElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTextAreaElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTextAreaElement> | undefined;
    nonce?: string | undefined;
    wrap?: string | undefined;
    disabled?: boolean | undefined;
    form?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    autoComplete?: string | undefined;
    maxLength?: number | undefined;
    minLength?: number | undefined;
    placeholder?: string | undefined;
    readOnly?: boolean | undefined;
    required?: boolean | undefined;
    cols?: number | undefined;
    dirName?: string | undefined;
    rows?: number | undefined;
} & MotionProps & react.RefAttributes<HTMLTextAreaElement>>;
declare const MotionTfoot$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableSectionElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableSectionElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableSectionElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableSectionElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableSectionElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTableSectionElement>>;
declare const MotionTh$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableHeaderCellElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableHeaderCellElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableHeaderCellElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableHeaderCellElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableHeaderCellElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableHeaderCellElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableHeaderCellElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableHeaderCellElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableHeaderCellElement> | undefined;
    nonce?: string | undefined;
    abbr?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    align?: "left" | "right" | "center" | "justify" | "char" | undefined;
    colSpan?: number | undefined;
    headers?: string | undefined;
    rowSpan?: number | undefined;
    scope?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTableHeaderCellElement>>;
declare const MotionThead$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableSectionElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableSectionElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableSectionElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableSectionElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableSectionElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTableSectionElement>>;
declare const MotionTime$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTimeElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTimeElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTimeElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTimeElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTimeElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTimeElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTimeElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTimeElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTimeElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTimeElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTimeElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTimeElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTimeElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTimeElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTimeElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTimeElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTimeElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTimeElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTimeElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTimeElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTimeElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTimeElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTimeElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTimeElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTimeElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTimeElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTimeElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTimeElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTimeElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTimeElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTimeElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTimeElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTimeElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTimeElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTimeElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTimeElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTimeElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTimeElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTimeElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTimeElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTimeElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    dateTime?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTimeElement>>;
declare const MotionTitle$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTitleElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTitleElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTitleElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTitleElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTitleElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTitleElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTitleElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTitleElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTitleElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTitleElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTitleElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTitleElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTitleElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTitleElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTitleElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTitleElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTitleElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTitleElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTitleElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTitleElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTitleElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTitleElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTitleElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTitleElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTitleElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTitleElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTitleElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTitleElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTitleElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTitleElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTitleElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTitleElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTitleElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTitleElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTitleElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTitleElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTitleElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTitleElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTitleElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTitleElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTitleElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTitleElement>>;
declare const MotionTr$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableRowElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableRowElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableRowElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableRowElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableRowElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableRowElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableRowElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableRowElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableRowElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableRowElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableRowElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableRowElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableRowElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableRowElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableRowElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableRowElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableRowElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableRowElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableRowElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableRowElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableRowElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableRowElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableRowElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableRowElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableRowElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableRowElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableRowElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableRowElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableRowElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableRowElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableRowElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableRowElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableRowElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableRowElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableRowElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableRowElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableRowElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableRowElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableRowElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableRowElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableRowElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTableRowElement>>;
declare const MotionTrack$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    default?: boolean | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTrackElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTrackElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTrackElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTrackElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTrackElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTrackElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTrackElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTrackElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTrackElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTrackElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTrackElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTrackElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTrackElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTrackElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTrackElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTrackElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTrackElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTrackElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTrackElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTrackElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTrackElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTrackElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTrackElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTrackElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTrackElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTrackElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTrackElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTrackElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTrackElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTrackElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTrackElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTrackElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTrackElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTrackElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTrackElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTrackElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTrackElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTrackElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTrackElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTrackElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTrackElement> | undefined;
    nonce?: string | undefined;
    label?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    src?: string | undefined;
    kind?: string | undefined;
    srcLang?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTrackElement>>;
declare const MotionU$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionUl$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLUListElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLUListElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLUListElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLUListElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLUListElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLUListElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLUListElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLUListElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLUListElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLUListElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLUListElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLUListElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLUListElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLUListElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLUListElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLUListElement> | undefined;
    onChange?: react.FormEventHandler<HTMLUListElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLUListElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLUListElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLUListElement> | undefined;
    onInput?: react.FormEventHandler<HTMLUListElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLUListElement> | undefined;
    onReset?: react.FormEventHandler<HTMLUListElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLUListElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLUListElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLUListElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLUListElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLUListElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onError?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLUListElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLUListElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLUListElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLUListElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLUListElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLUListElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLUListElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLUListElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLUListElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLUListElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLUListElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLUListElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLUListElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLUListElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLUListElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLUListElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLUListElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLUListElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLUListElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLUListElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLUListElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLUListElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLUListElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLUListElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLUListElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLUListElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLUListElement>>;
declare const MotionVideo$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    crossOrigin?: "" | "anonymous" | "use-credentials" | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLVideoElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLVideoElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLVideoElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLVideoElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLVideoElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLVideoElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLVideoElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLVideoElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLVideoElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLVideoElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLVideoElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLVideoElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLVideoElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLVideoElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLVideoElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLVideoElement> | undefined;
    onChange?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onInput?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onReset?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onError?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLVideoElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLVideoElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLVideoElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLVideoElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLVideoElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLVideoElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLVideoElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLVideoElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLVideoElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLVideoElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLVideoElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLVideoElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLVideoElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLVideoElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLVideoElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLVideoElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLVideoElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLVideoElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLVideoElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLVideoElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLVideoElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLVideoElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLVideoElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLVideoElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLVideoElement> | undefined;
    loop?: boolean | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    autoPlay?: boolean | undefined;
    controls?: boolean | undefined;
    controlsList?: string | undefined;
    mediaGroup?: string | undefined;
    muted?: boolean | undefined;
    playsInline?: boolean | undefined;
    preload?: string | undefined;
    src?: string | undefined;
    poster?: string | undefined;
    disablePictureInPicture?: boolean | undefined;
    disableRemotePlayback?: boolean | undefined;
} & MotionProps & react.RefAttributes<HTMLVideoElement>>;
declare const MotionWbr$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionWebview$1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLWebViewElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLWebViewElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLWebViewElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLWebViewElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLWebViewElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLWebViewElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLWebViewElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLWebViewElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLWebViewElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLWebViewElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLWebViewElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLWebViewElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLWebViewElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLWebViewElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLWebViewElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLWebViewElement> | undefined;
    onChange?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onInput?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onReset?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onError?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLWebViewElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLWebViewElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLWebViewElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLWebViewElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLWebViewElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLWebViewElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLWebViewElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLWebViewElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLWebViewElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLWebViewElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLWebViewElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLWebViewElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLWebViewElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLWebViewElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLWebViewElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLWebViewElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLWebViewElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLWebViewElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLWebViewElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLWebViewElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLWebViewElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLWebViewElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLWebViewElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLWebViewElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLWebViewElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    preload?: string | undefined;
    src?: string | undefined;
    allowFullScreen?: boolean | undefined;
    allowpopups?: boolean | undefined;
    autosize?: boolean | undefined;
    blinkfeatures?: string | undefined;
    disableblinkfeatures?: string | undefined;
    disableguestresize?: boolean | undefined;
    disablewebsecurity?: boolean | undefined;
    guestinstance?: string | undefined;
    httpreferrer?: string | undefined;
    nodeintegration?: boolean | undefined;
    partition?: string | undefined;
    plugins?: boolean | undefined;
    useragent?: string | undefined;
    webpreferences?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLWebViewElement>>;
/**
 * SVG components
 * TODO: Generate list with props/instance
 */
declare const MotionAnimate$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionCircle$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionDefs$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionDesc$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionEllipse$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionG$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionImage$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionLine$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFilter$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionMarker$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionMask$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionMetadata$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionPath$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionPattern$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionPolygon$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionPolyline$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionRect$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionStop$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionSvg$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionSymbol$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionText$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionTspan$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionUse$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionView$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionClipPath$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeBlend$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeColorMatrix$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeComponentTransfer$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeComposite$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeConvolveMatrix$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeDiffuseLighting$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeDisplacementMap$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeDistantLight$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeDropShadow$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeFlood$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeFuncA$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeFuncB$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeFuncG$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeFuncR$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeGaussianBlur$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeImage$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeMerge$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeMergeNode$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeMorphology$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeOffset$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFePointLight$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeSpecularLighting$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeSpotLight$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeTile$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeTurbulence$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionForeignObject$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionLinearGradient$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionRadialGradient$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionTextPath$1: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;

declare namespace namespace_d$2 {
  export { MotionA$1 as a, MotionAbbr$1 as abbr, MotionAddress$1 as address, MotionAnimate$1 as animate, MotionArea$1 as area, MotionArticle$1 as article, MotionAside$1 as aside, MotionAudio$1 as audio, MotionB$1 as b, MotionBase$1 as base, MotionBdi$1 as bdi, MotionBdo$1 as bdo, MotionBig$1 as big, MotionBlockquote$1 as blockquote, MotionBody$1 as body, MotionButton$1 as button, MotionCanvas$1 as canvas, MotionCaption$1 as caption, MotionCircle$1 as circle, MotionCite$1 as cite, MotionClipPath$1 as clipPath, MotionCode$1 as code, MotionCol$1 as col, MotionColgroup$1 as colgroup, MotionData$1 as data, MotionDatalist$1 as datalist, MotionDd$1 as dd, MotionDefs$1 as defs, MotionDel$1 as del, MotionDesc$1 as desc, MotionDetails$1 as details, MotionDfn$1 as dfn, MotionDialog$1 as dialog, MotionDiv$1 as div, MotionDl$1 as dl, MotionDt$1 as dt, MotionEllipse$1 as ellipse, MotionEm$1 as em, MotionEmbed$1 as embed, MotionFeBlend$1 as feBlend, MotionFeColorMatrix$1 as feColorMatrix, MotionFeComponentTransfer$1 as feComponentTransfer, MotionFeComposite$1 as feComposite, MotionFeConvolveMatrix$1 as feConvolveMatrix, MotionFeDiffuseLighting$1 as feDiffuseLighting, MotionFeDisplacementMap$1 as feDisplacementMap, MotionFeDistantLight$1 as feDistantLight, MotionFeDropShadow$1 as feDropShadow, MotionFeFlood$1 as feFlood, MotionFeFuncA$1 as feFuncA, MotionFeFuncB$1 as feFuncB, MotionFeFuncG$1 as feFuncG, MotionFeFuncR$1 as feFuncR, MotionFeGaussianBlur$1 as feGaussianBlur, MotionFeImage$1 as feImage, MotionFeMerge$1 as feMerge, MotionFeMergeNode$1 as feMergeNode, MotionFeMorphology$1 as feMorphology, MotionFeOffset$1 as feOffset, MotionFePointLight$1 as fePointLight, MotionFeSpecularLighting$1 as feSpecularLighting, MotionFeSpotLight$1 as feSpotLight, MotionFeTile$1 as feTile, MotionFeTurbulence$1 as feTurbulence, MotionFieldset$1 as fieldset, MotionFigcaption$1 as figcaption, MotionFigure$1 as figure, MotionFilter$1 as filter, MotionFooter$1 as footer, MotionForeignObject$1 as foreignObject, MotionForm$1 as form, MotionG$1 as g, MotionH1$1 as h1, MotionH2$1 as h2, MotionH3$1 as h3, MotionH4$1 as h4, MotionH5$1 as h5, MotionH6$1 as h6, MotionHead$1 as head, MotionHeader$1 as header, MotionHgroup$1 as hgroup, MotionHr$1 as hr, MotionHtml$1 as html, MotionI$1 as i, MotionIframe$1 as iframe, MotionImage$1 as image, MotionImg$1 as img, MotionInput$1 as input, MotionIns$1 as ins, MotionKbd$1 as kbd, MotionKeygen$1 as keygen, MotionLabel$1 as label, MotionLegend$1 as legend, MotionLi$1 as li, MotionLine$1 as line, MotionLinearGradient$1 as linearGradient, MotionLink$1 as link, MotionMain$1 as main, MotionMap$1 as map, MotionMark$1 as mark, MotionMarker$1 as marker, MotionMask$1 as mask, MotionMenu$1 as menu, MotionMenuitem$1 as menuitem, MotionMetadata$1 as metadata, MotionMeter$1 as meter, MotionNav$1 as nav, MotionObject$1 as object, MotionOl$1 as ol, MotionOptgroup$1 as optgroup, MotionOption$1 as option, MotionOutput$1 as output, MotionP$1 as p, MotionParam$1 as param, MotionPath$1 as path, MotionPattern$1 as pattern, MotionPicture$1 as picture, MotionPolygon$1 as polygon, MotionPolyline$1 as polyline, MotionPre$1 as pre, MotionProgress$1 as progress, MotionQ$1 as q, MotionRadialGradient$1 as radialGradient, MotionRect$1 as rect, MotionRp$1 as rp, MotionRt$1 as rt, MotionRuby$1 as ruby, MotionS$1 as s, MotionSamp$1 as samp, MotionScript$1 as script, MotionSection$1 as section, MotionSelect$1 as select, MotionSmall$1 as small, MotionSource$1 as source, MotionSpan$1 as span, MotionStop$1 as stop, MotionStrong$1 as strong, MotionStyle$1 as style, MotionSub$1 as sub, MotionSummary$1 as summary, MotionSup$1 as sup, MotionSvg$1 as svg, MotionSymbol$1 as symbol, MotionTable$1 as table, MotionTbody$1 as tbody, MotionTd$1 as td, MotionText$1 as text, MotionTextPath$1 as textPath, MotionTextarea$1 as textarea, MotionTfoot$1 as tfoot, MotionTh$1 as th, MotionThead$1 as thead, MotionTime$1 as time, MotionTitle$1 as title, MotionTr$1 as tr, MotionTrack$1 as track, MotionTspan$1 as tspan, MotionU$1 as u, MotionUl$1 as ul, MotionUse$1 as use, MotionVideo$1 as video, MotionView$1 as view, MotionWbr$1 as wbr, MotionWebview$1 as webview };
}

/**
 * HTML components
 */
declare const MotionA: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    type?: string | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    media?: string | undefined;
    target?: react.HTMLAttributeAnchorTarget | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    href?: string | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLAnchorElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLAnchorElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLAnchorElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLAnchorElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLAnchorElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLAnchorElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLAnchorElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLAnchorElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLAnchorElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLAnchorElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLAnchorElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLAnchorElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLAnchorElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLAnchorElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLAnchorElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLAnchorElement> | undefined;
    onChange?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onInput?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onReset?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLAnchorElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onError?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLAnchorElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLAnchorElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLAnchorElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLAnchorElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLAnchorElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLAnchorElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLAnchorElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLAnchorElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLAnchorElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLAnchorElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLAnchorElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLAnchorElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLAnchorElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLAnchorElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLAnchorElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLAnchorElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLAnchorElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLAnchorElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLAnchorElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLAnchorElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLAnchorElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLAnchorElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLAnchorElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLAnchorElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLAnchorElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLAnchorElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLAnchorElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLAnchorElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLAnchorElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    download?: any;
    hrefLang?: string | undefined;
    ping?: string | undefined;
    referrerPolicy?: react.HTMLAttributeReferrerPolicy | undefined;
} & MotionProps & react.RefAttributes<HTMLAnchorElement>>;
declare const MotionAbbr: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionAddress: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionArea: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    media?: string | undefined;
    target?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    href?: string | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLAreaElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLAreaElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLAreaElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLAreaElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLAreaElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLAreaElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLAreaElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLAreaElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLAreaElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLAreaElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLAreaElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLAreaElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLAreaElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLAreaElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLAreaElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLAreaElement> | undefined;
    onChange?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onInput?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onReset?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLAreaElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onError?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLAreaElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLAreaElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLAreaElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLAreaElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLAreaElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLAreaElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLAreaElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLAreaElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLAreaElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLAreaElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLAreaElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLAreaElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLAreaElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLAreaElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLAreaElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLAreaElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLAreaElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLAreaElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLAreaElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLAreaElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLAreaElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLAreaElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLAreaElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLAreaElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLAreaElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLAreaElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLAreaElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLAreaElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLAreaElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    download?: any;
    hrefLang?: string | undefined;
    referrerPolicy?: react.HTMLAttributeReferrerPolicy | undefined;
    alt?: string | undefined;
    coords?: string | undefined;
    shape?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLAreaElement>>;
declare const MotionArticle: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionAside: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionAudio: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    crossOrigin?: "" | "anonymous" | "use-credentials" | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLAudioElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLAudioElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLAudioElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLAudioElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLAudioElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLAudioElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLAudioElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLAudioElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLAudioElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLAudioElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLAudioElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLAudioElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLAudioElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLAudioElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLAudioElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLAudioElement> | undefined;
    onChange?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onInput?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onReset?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLAudioElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onError?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLAudioElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLAudioElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLAudioElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLAudioElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLAudioElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLAudioElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLAudioElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLAudioElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLAudioElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLAudioElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLAudioElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLAudioElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLAudioElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLAudioElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLAudioElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLAudioElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLAudioElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLAudioElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLAudioElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLAudioElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLAudioElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLAudioElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLAudioElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLAudioElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLAudioElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLAudioElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLAudioElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLAudioElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLAudioElement> | undefined;
    loop?: boolean | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    autoPlay?: boolean | undefined;
    controls?: boolean | undefined;
    controlsList?: string | undefined;
    mediaGroup?: string | undefined;
    muted?: boolean | undefined;
    playsInline?: boolean | undefined;
    preload?: string | undefined;
    src?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLAudioElement>>;
declare const MotionB: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionBase: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    target?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    href?: string | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLBaseElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLBaseElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLBaseElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLBaseElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLBaseElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLBaseElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLBaseElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLBaseElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLBaseElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLBaseElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLBaseElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLBaseElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLBaseElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLBaseElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLBaseElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLBaseElement> | undefined;
    onChange?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onInput?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onReset?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLBaseElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onError?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLBaseElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLBaseElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLBaseElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLBaseElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLBaseElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLBaseElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLBaseElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLBaseElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLBaseElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLBaseElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLBaseElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLBaseElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLBaseElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLBaseElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLBaseElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLBaseElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLBaseElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLBaseElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLBaseElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLBaseElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLBaseElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLBaseElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLBaseElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLBaseElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLBaseElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLBaseElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLBaseElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLBaseElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLBaseElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLBaseElement>>;
declare const MotionBdi: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionBdo: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionBig: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionBlockquote: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLQuoteElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLQuoteElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLQuoteElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLQuoteElement> | undefined;
    onChange?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onInput?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onReset?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onError?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLQuoteElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLQuoteElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLQuoteElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLQuoteElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLQuoteElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLQuoteElement> | undefined;
    nonce?: string | undefined;
    cite?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLQuoteElement>>;
declare const MotionBody: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLBodyElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLBodyElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLBodyElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLBodyElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLBodyElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLBodyElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLBodyElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLBodyElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLBodyElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLBodyElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLBodyElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLBodyElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLBodyElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLBodyElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLBodyElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLBodyElement> | undefined;
    onChange?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onInput?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onReset?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLBodyElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onError?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLBodyElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLBodyElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLBodyElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLBodyElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLBodyElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLBodyElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLBodyElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLBodyElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLBodyElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLBodyElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLBodyElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLBodyElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLBodyElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLBodyElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLBodyElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLBodyElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLBodyElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLBodyElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLBodyElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLBodyElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLBodyElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLBodyElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLBodyElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLBodyElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLBodyElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLBodyElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLBodyElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLBodyElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLBodyElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLBodyElement>>;
declare const MotionButton: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    type?: "button" | "reset" | "submit" | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLButtonElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLButtonElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLButtonElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLButtonElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLButtonElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLButtonElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLButtonElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLButtonElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLButtonElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLButtonElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLButtonElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLButtonElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLButtonElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLButtonElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLButtonElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLButtonElement> | undefined;
    onChange?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onInput?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onReset?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLButtonElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onError?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLButtonElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLButtonElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLButtonElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLButtonElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLButtonElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLButtonElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLButtonElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLButtonElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLButtonElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLButtonElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLButtonElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLButtonElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLButtonElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLButtonElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLButtonElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLButtonElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLButtonElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLButtonElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLButtonElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLButtonElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLButtonElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLButtonElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLButtonElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLButtonElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLButtonElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLButtonElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLButtonElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLButtonElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLButtonElement> | undefined;
    nonce?: string | undefined;
    disabled?: boolean | undefined;
    form?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    formAction?: string | undefined;
    formEncType?: string | undefined;
    formMethod?: string | undefined;
    formNoValidate?: boolean | undefined;
    formTarget?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLButtonElement>>;
declare const MotionCanvas: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLCanvasElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLCanvasElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLCanvasElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLCanvasElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLCanvasElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLCanvasElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLCanvasElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLCanvasElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLCanvasElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLCanvasElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLCanvasElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLCanvasElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLCanvasElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLCanvasElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLCanvasElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLCanvasElement> | undefined;
    onChange?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onInput?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onReset?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLCanvasElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onError?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLCanvasElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLCanvasElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLCanvasElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLCanvasElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLCanvasElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLCanvasElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLCanvasElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLCanvasElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLCanvasElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLCanvasElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLCanvasElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLCanvasElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLCanvasElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLCanvasElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLCanvasElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLCanvasElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLCanvasElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLCanvasElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLCanvasElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLCanvasElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLCanvasElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLCanvasElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLCanvasElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLCanvasElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLCanvasElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLCanvasElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLCanvasElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLCanvasElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLCanvasElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLCanvasElement>>;
declare const MotionCaption: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionCite: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionCode: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionCol: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableColElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableColElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableColElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableColElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableColElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableColElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableColElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableColElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableColElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableColElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    span?: number | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTableColElement>>;
declare const MotionColgroup: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableColElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableColElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableColElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableColElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableColElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableColElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableColElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableColElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableColElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableColElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableColElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableColElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableColElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableColElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableColElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableColElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableColElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableColElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableColElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableColElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    span?: number | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTableColElement>>;
declare const MotionData: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLDataElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLDataElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLDataElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLDataElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLDataElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLDataElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLDataElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLDataElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLDataElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLDataElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLDataElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLDataElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLDataElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLDataElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLDataElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLDataElement> | undefined;
    onChange?: react.FormEventHandler<HTMLDataElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLDataElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLDataElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLDataElement> | undefined;
    onInput?: react.FormEventHandler<HTMLDataElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLDataElement> | undefined;
    onReset?: react.FormEventHandler<HTMLDataElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLDataElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLDataElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLDataElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLDataElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLDataElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onError?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLDataElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLDataElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLDataElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLDataElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLDataElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLDataElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLDataElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLDataElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLDataElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLDataElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLDataElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLDataElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLDataElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLDataElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLDataElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLDataElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLDataElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLDataElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLDataElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLDataElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLDataElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLDataElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLDataElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLDataElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLDataElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLDataElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLDataElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLDataElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLDataElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLDataElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLDataElement>>;
declare const MotionDatalist: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLDataListElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLDataListElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLDataListElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLDataListElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLDataListElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLDataListElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLDataListElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLDataListElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLDataListElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLDataListElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLDataListElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLDataListElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLDataListElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLDataListElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLDataListElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLDataListElement> | undefined;
    onChange?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onInput?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onReset?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLDataListElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onError?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLDataListElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLDataListElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLDataListElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLDataListElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLDataListElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLDataListElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLDataListElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLDataListElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLDataListElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLDataListElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLDataListElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLDataListElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLDataListElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLDataListElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLDataListElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLDataListElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLDataListElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLDataListElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLDataListElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLDataListElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLDataListElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLDataListElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLDataListElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLDataListElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLDataListElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLDataListElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLDataListElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLDataListElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLDataListElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLDataListElement>>;
declare const MotionDd: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionDel: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLModElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLModElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLModElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLModElement> | undefined;
    onChange?: react.FormEventHandler<HTMLModElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLModElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onInput?: react.FormEventHandler<HTMLModElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onReset?: react.FormEventHandler<HTMLModElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLModElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLModElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onError?: react.ReactEventHandler<HTMLModElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLModElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLModElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLModElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLModElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLModElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLModElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLModElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLModElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLModElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLModElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLModElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLModElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLModElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLModElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLModElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLModElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLModElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLModElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLModElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLModElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLModElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLModElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLModElement> | undefined;
    nonce?: string | undefined;
    cite?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    dateTime?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLModElement>>;
declare const MotionDetails: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLDetailsElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLDetailsElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLDetailsElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLDetailsElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLDetailsElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLDetailsElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLDetailsElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLDetailsElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLDetailsElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLDetailsElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLDetailsElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLDetailsElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLDetailsElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLDetailsElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLDetailsElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLDetailsElement> | undefined;
    onChange?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onInput?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onReset?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLDetailsElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onError?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLDetailsElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLDetailsElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLDetailsElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLDetailsElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLDetailsElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLDetailsElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLDetailsElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLDetailsElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLDetailsElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLDetailsElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLDetailsElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLDetailsElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLDetailsElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLDetailsElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLDetailsElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLDetailsElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLDetailsElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLDetailsElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLDetailsElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLDetailsElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLDetailsElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLDetailsElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLDetailsElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLDetailsElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLDetailsElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLDetailsElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLDetailsElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLDetailsElement> | undefined;
    nonce?: string | undefined;
    open?: boolean | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    onToggle?: react.ReactEventHandler<HTMLDetailsElement> | undefined;
} & MotionProps & react.RefAttributes<HTMLDetailsElement>>;
declare const MotionDfn: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionDialog: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLDialogElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLDialogElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLDialogElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLDialogElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLDialogElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLDialogElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLDialogElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLDialogElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLDialogElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLDialogElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLDialogElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLDialogElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLDialogElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLDialogElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLDialogElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLDialogElement> | undefined;
    onChange?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onInput?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onReset?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLDialogElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onError?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLDialogElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLDialogElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLDialogElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLDialogElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLDialogElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLDialogElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLDialogElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLDialogElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLDialogElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLDialogElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLDialogElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLDialogElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLDialogElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLDialogElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLDialogElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLDialogElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLDialogElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLDialogElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLDialogElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLDialogElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLDialogElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLDialogElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLDialogElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLDialogElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLDialogElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLDialogElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLDialogElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLDialogElement> | undefined;
    nonce?: string | undefined;
    open?: boolean | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    onCancel?: react.ReactEventHandler<HTMLDialogElement> | undefined;
    onClose?: react.ReactEventHandler<HTMLDialogElement> | undefined;
} & MotionProps & react.RefAttributes<HTMLDialogElement>>;
declare const MotionDiv: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLDivElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLDivElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLDivElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLDivElement> | undefined;
    onChange?: react.FormEventHandler<HTMLDivElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLDivElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    onInput?: react.FormEventHandler<HTMLDivElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    onReset?: react.FormEventHandler<HTMLDivElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLDivElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLDivElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onError?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLDivElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLDivElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLDivElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLDivElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLDivElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLDivElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLDivElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLDivElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLDivElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLDivElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLDivElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLDivElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLDivElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLDivElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLDivElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLDivElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLDivElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLDivElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLDivElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLDivElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLDivElement>>;
declare const MotionDl: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLDListElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLDListElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLDListElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLDListElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLDListElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLDListElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLDListElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLDListElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLDListElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLDListElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLDListElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLDListElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLDListElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLDListElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLDListElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLDListElement> | undefined;
    onChange?: react.FormEventHandler<HTMLDListElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLDListElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLDListElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLDListElement> | undefined;
    onInput?: react.FormEventHandler<HTMLDListElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLDListElement> | undefined;
    onReset?: react.FormEventHandler<HTMLDListElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLDListElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLDListElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLDListElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLDListElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLDListElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onError?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLDListElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLDListElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLDListElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLDListElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLDListElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLDListElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLDListElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLDListElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLDListElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLDListElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLDListElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLDListElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLDListElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLDListElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLDListElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLDListElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLDListElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLDListElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLDListElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLDListElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLDListElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLDListElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLDListElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLDListElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLDListElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLDListElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLDListElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLDListElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLDListElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLDListElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLDListElement>>;
declare const MotionDt: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionEm: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionEmbed: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    type?: string | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLEmbedElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLEmbedElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLEmbedElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLEmbedElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLEmbedElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLEmbedElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLEmbedElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLEmbedElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLEmbedElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLEmbedElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLEmbedElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLEmbedElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLEmbedElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLEmbedElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLEmbedElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLEmbedElement> | undefined;
    onChange?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onInput?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onReset?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLEmbedElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onError?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLEmbedElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLEmbedElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLEmbedElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLEmbedElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLEmbedElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLEmbedElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLEmbedElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLEmbedElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLEmbedElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLEmbedElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLEmbedElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLEmbedElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLEmbedElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLEmbedElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLEmbedElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLEmbedElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLEmbedElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLEmbedElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLEmbedElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLEmbedElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLEmbedElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLEmbedElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLEmbedElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLEmbedElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLEmbedElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLEmbedElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLEmbedElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLEmbedElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLEmbedElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    src?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLEmbedElement>>;
declare const MotionFieldset: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLFieldSetElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLFieldSetElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLFieldSetElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLFieldSetElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLFieldSetElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLFieldSetElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLFieldSetElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLFieldSetElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLFieldSetElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLFieldSetElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLFieldSetElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLFieldSetElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLFieldSetElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLFieldSetElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLFieldSetElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLFieldSetElement> | undefined;
    onChange?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onInput?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onReset?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLFieldSetElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onError?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLFieldSetElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLFieldSetElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLFieldSetElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLFieldSetElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLFieldSetElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLFieldSetElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLFieldSetElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLFieldSetElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLFieldSetElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLFieldSetElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLFieldSetElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLFieldSetElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLFieldSetElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLFieldSetElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLFieldSetElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLFieldSetElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLFieldSetElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLFieldSetElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLFieldSetElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLFieldSetElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLFieldSetElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLFieldSetElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLFieldSetElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLFieldSetElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLFieldSetElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLFieldSetElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLFieldSetElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLFieldSetElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLFieldSetElement> | undefined;
    nonce?: string | undefined;
    disabled?: boolean | undefined;
    form?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLFieldSetElement>>;
declare const MotionFigcaption: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionFigure: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionFooter: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionForm: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    method?: string | undefined;
    name?: string | undefined;
    target?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLFormElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLFormElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLFormElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLFormElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLFormElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLFormElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLFormElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLFormElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLFormElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLFormElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLFormElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLFormElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLFormElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLFormElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLFormElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLFormElement> | undefined;
    onChange?: react.FormEventHandler<HTMLFormElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLFormElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLFormElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLFormElement> | undefined;
    onInput?: react.FormEventHandler<HTMLFormElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLFormElement> | undefined;
    onReset?: react.FormEventHandler<HTMLFormElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLFormElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLFormElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLFormElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLFormElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLFormElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onError?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLFormElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLFormElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLFormElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLFormElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLFormElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLFormElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLFormElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLFormElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLFormElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLFormElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLFormElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLFormElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLFormElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLFormElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLFormElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLFormElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLFormElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLFormElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLFormElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLFormElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLFormElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLFormElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLFormElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLFormElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLFormElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLFormElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLFormElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLFormElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLFormElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLFormElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    acceptCharset?: string | undefined;
    action?: string | undefined;
    autoComplete?: string | undefined;
    encType?: string | undefined;
    noValidate?: boolean | undefined;
} & MotionProps & react.RefAttributes<HTMLFormElement>>;
declare const MotionH1: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onChange?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onReset?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onError?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHeadingElement>>;
declare const MotionH2: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onChange?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onReset?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onError?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHeadingElement>>;
declare const MotionH3: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onChange?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onReset?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onError?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHeadingElement>>;
declare const MotionH4: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onChange?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onReset?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onError?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHeadingElement>>;
declare const MotionH5: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onChange?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onReset?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onError?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHeadingElement>>;
declare const MotionH6: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLHeadingElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLHeadingElement> | undefined;
    onChange?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInput?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onReset?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLHeadingElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onError?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLHeadingElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLHeadingElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLHeadingElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLHeadingElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLHeadingElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLHeadingElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLHeadingElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLHeadingElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHeadingElement>>;
declare const MotionHead: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHeadElement>>;
declare const MotionHeader: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionHgroup: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionHr: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLHRElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLHRElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLHRElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLHRElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLHRElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLHRElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLHRElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLHRElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLHRElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLHRElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLHRElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLHRElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLHRElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLHRElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLHRElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLHRElement> | undefined;
    onChange?: react.FormEventHandler<HTMLHRElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLHRElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLHRElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLHRElement> | undefined;
    onInput?: react.FormEventHandler<HTMLHRElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLHRElement> | undefined;
    onReset?: react.FormEventHandler<HTMLHRElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLHRElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLHRElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLHRElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLHRElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLHRElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onError?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLHRElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLHRElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLHRElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLHRElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLHRElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLHRElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLHRElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLHRElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLHRElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLHRElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLHRElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLHRElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLHRElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLHRElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLHRElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLHRElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLHRElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLHRElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLHRElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLHRElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLHRElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLHRElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLHRElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLHRElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLHRElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLHRElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLHRElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLHRElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLHRElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLHRElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHRElement>>;
declare const MotionHtml: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLHtmlElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLHtmlElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLHtmlElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLHtmlElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLHtmlElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLHtmlElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLHtmlElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLHtmlElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLHtmlElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLHtmlElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLHtmlElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLHtmlElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLHtmlElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLHtmlElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLHtmlElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLHtmlElement> | undefined;
    onChange?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onInput?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onReset?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLHtmlElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onError?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLHtmlElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLHtmlElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLHtmlElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLHtmlElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLHtmlElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLHtmlElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLHtmlElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLHtmlElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLHtmlElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLHtmlElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLHtmlElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLHtmlElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLHtmlElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLHtmlElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLHtmlElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLHtmlElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLHtmlElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLHtmlElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLHtmlElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLHtmlElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLHtmlElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLHtmlElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLHtmlElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLHtmlElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLHtmlElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLHtmlElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLHtmlElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLHtmlElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLHtmlElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    manifest?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLHtmlElement>>;
declare const MotionI: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionIframe: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLIFrameElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLIFrameElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLIFrameElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLIFrameElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLIFrameElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLIFrameElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLIFrameElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLIFrameElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLIFrameElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLIFrameElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLIFrameElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLIFrameElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLIFrameElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLIFrameElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLIFrameElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLIFrameElement> | undefined;
    onChange?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onInput?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onReset?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLIFrameElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onError?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLIFrameElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLIFrameElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLIFrameElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLIFrameElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLIFrameElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLIFrameElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLIFrameElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLIFrameElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLIFrameElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLIFrameElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLIFrameElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLIFrameElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLIFrameElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLIFrameElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLIFrameElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLIFrameElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLIFrameElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLIFrameElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLIFrameElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLIFrameElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLIFrameElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLIFrameElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLIFrameElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLIFrameElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLIFrameElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLIFrameElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLIFrameElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLIFrameElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLIFrameElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    referrerPolicy?: react.HTMLAttributeReferrerPolicy | undefined;
    src?: string | undefined;
    allow?: string | undefined;
    allowFullScreen?: boolean | undefined;
    allowTransparency?: boolean | undefined;
    frameBorder?: string | number | undefined;
    loading?: "eager" | "lazy" | undefined;
    marginHeight?: number | undefined;
    marginWidth?: number | undefined;
    sandbox?: string | undefined;
    scrolling?: string | undefined;
    seamless?: boolean | undefined;
    srcDoc?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLIFrameElement>>;
declare const MotionImg: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    crossOrigin?: "" | "anonymous" | "use-credentials" | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLImageElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLImageElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLImageElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLImageElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLImageElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLImageElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLImageElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLImageElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLImageElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLImageElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLImageElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLImageElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLImageElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLImageElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLImageElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLImageElement> | undefined;
    onChange?: react.FormEventHandler<HTMLImageElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLImageElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLImageElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLImageElement> | undefined;
    onInput?: react.FormEventHandler<HTMLImageElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLImageElement> | undefined;
    onReset?: react.FormEventHandler<HTMLImageElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLImageElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLImageElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLImageElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLImageElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLImageElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onError?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLImageElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLImageElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLImageElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLImageElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLImageElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLImageElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLImageElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLImageElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLImageElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLImageElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLImageElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLImageElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLImageElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLImageElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLImageElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLImageElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLImageElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLImageElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLImageElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLImageElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLImageElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLImageElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLImageElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLImageElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLImageElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLImageElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLImageElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLImageElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLImageElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLImageElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    referrerPolicy?: react.HTMLAttributeReferrerPolicy | undefined;
    alt?: string | undefined;
    src?: string | undefined;
    loading?: "eager" | "lazy" | undefined;
    decoding?: "auto" | "async" | "sync" | undefined;
    fetchPriority?: "auto" | "high" | "low" | undefined;
    sizes?: string | undefined;
    srcSet?: string | undefined;
    useMap?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLImageElement>>;
declare const MotionInput: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    size?: number | undefined;
    hidden?: boolean | undefined;
    type?: react.HTMLInputTypeAttribute | undefined;
    min?: string | number | undefined;
    max?: string | number | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLInputElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLInputElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLInputElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLInputElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLInputElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLInputElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLInputElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLInputElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLInputElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLInputElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLInputElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLInputElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLInputElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLInputElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLInputElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLInputElement> | undefined;
    onChange?: react.ChangeEventHandler<HTMLInputElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLInputElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLInputElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLInputElement> | undefined;
    onInput?: react.FormEventHandler<HTMLInputElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLInputElement> | undefined;
    onReset?: react.FormEventHandler<HTMLInputElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLInputElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLInputElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLInputElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLInputElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLInputElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onError?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLInputElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLInputElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLInputElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLInputElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLInputElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLInputElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLInputElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLInputElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLInputElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLInputElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLInputElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLInputElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLInputElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLInputElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLInputElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLInputElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLInputElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLInputElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLInputElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLInputElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLInputElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLInputElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLInputElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLInputElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLInputElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLInputElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLInputElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLInputElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLInputElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLInputElement> | undefined;
    nonce?: string | undefined;
    multiple?: boolean | undefined;
    disabled?: boolean | undefined;
    form?: string | undefined;
    list?: string | undefined;
    step?: string | number | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    pattern?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    alt?: string | undefined;
    src?: string | undefined;
    formAction?: string | undefined;
    formEncType?: string | undefined;
    formMethod?: string | undefined;
    formNoValidate?: boolean | undefined;
    formTarget?: string | undefined;
    autoComplete?: react.HTMLInputAutoCompleteAttribute | undefined;
    accept?: string | undefined;
    capture?: boolean | "user" | "environment" | undefined;
    checked?: boolean | undefined;
    enterKeyHint?: "done" | "search" | "enter" | "go" | "next" | "previous" | "send" | undefined;
    maxLength?: number | undefined;
    minLength?: number | undefined;
    placeholder?: string | undefined;
    readOnly?: boolean | undefined;
    required?: boolean | undefined;
} & MotionProps & react.RefAttributes<HTMLInputElement>>;
declare const MotionIns: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLModElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLModElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLModElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLModElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLModElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLModElement> | undefined;
    onChange?: react.FormEventHandler<HTMLModElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLModElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onInput?: react.FormEventHandler<HTMLModElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onReset?: react.FormEventHandler<HTMLModElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLModElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLModElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLModElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onError?: react.ReactEventHandler<HTMLModElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLModElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLModElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLModElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLModElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLModElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLModElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLModElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLModElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLModElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLModElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLModElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLModElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLModElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLModElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLModElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLModElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLModElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLModElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLModElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLModElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLModElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLModElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLModElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLModElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLModElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLModElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLModElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLModElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLModElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLModElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLModElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLModElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLModElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLModElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLModElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLModElement> | undefined;
    nonce?: string | undefined;
    cite?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    dateTime?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLModElement>>;
declare const MotionKbd: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionKeygen: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    disabled?: boolean | undefined;
    form?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    challenge?: string | undefined;
    keyType?: string | undefined;
    keyParams?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionLabel: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLLabelElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLLabelElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLLabelElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLLabelElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLLabelElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLLabelElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLLabelElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLLabelElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLLabelElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLLabelElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLLabelElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLLabelElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLLabelElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLLabelElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLLabelElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLLabelElement> | undefined;
    onChange?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onInput?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onReset?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLLabelElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onError?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLLabelElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLLabelElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLLabelElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLLabelElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLLabelElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLLabelElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLLabelElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLLabelElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLLabelElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLLabelElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLLabelElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLLabelElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLLabelElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLLabelElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLLabelElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLLabelElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLLabelElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLLabelElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLLabelElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLLabelElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLLabelElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLLabelElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLLabelElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLLabelElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLLabelElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLLabelElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLLabelElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLLabelElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLLabelElement> | undefined;
    nonce?: string | undefined;
    form?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    htmlFor?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLLabelElement>>;
declare const MotionLegend: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLLegendElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLLegendElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLLegendElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLLegendElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLLegendElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLLegendElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLLegendElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLLegendElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLLegendElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLLegendElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLLegendElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLLegendElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLLegendElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLLegendElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLLegendElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLLegendElement> | undefined;
    onChange?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onInput?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onReset?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLLegendElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onError?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLLegendElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLLegendElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLLegendElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLLegendElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLLegendElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLLegendElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLLegendElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLLegendElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLLegendElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLLegendElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLLegendElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLLegendElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLLegendElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLLegendElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLLegendElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLLegendElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLLegendElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLLegendElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLLegendElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLLegendElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLLegendElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLLegendElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLLegendElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLLegendElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLLegendElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLLegendElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLLegendElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLLegendElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLLegendElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLLegendElement>>;
declare const MotionLi: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLLIElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLLIElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLLIElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLLIElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLLIElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLLIElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLLIElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLLIElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLLIElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLLIElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLLIElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLLIElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLLIElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLLIElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLLIElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLLIElement> | undefined;
    onChange?: react.FormEventHandler<HTMLLIElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLLIElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLLIElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLLIElement> | undefined;
    onInput?: react.FormEventHandler<HTMLLIElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLLIElement> | undefined;
    onReset?: react.FormEventHandler<HTMLLIElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLLIElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLLIElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLLIElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLLIElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLLIElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onError?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLLIElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLLIElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLLIElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLLIElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLLIElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLLIElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLLIElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLLIElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLLIElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLLIElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLLIElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLLIElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLLIElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLLIElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLLIElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLLIElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLLIElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLLIElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLLIElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLLIElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLLIElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLLIElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLLIElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLLIElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLLIElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLLIElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLLIElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLLIElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLLIElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLLIElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLLIElement>>;
declare const MotionLink: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    type?: string | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    media?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    crossOrigin?: "" | "anonymous" | "use-credentials" | undefined;
    href?: string | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLLinkElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLLinkElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLLinkElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLLinkElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLLinkElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLLinkElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLLinkElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLLinkElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLLinkElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLLinkElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLLinkElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLLinkElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLLinkElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLLinkElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLLinkElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLLinkElement> | undefined;
    onChange?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onInput?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onReset?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLLinkElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onError?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLLinkElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLLinkElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLLinkElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLLinkElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLLinkElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLLinkElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLLinkElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLLinkElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLLinkElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLLinkElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLLinkElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLLinkElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLLinkElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLLinkElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLLinkElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLLinkElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLLinkElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLLinkElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLLinkElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLLinkElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLLinkElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLLinkElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLLinkElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLLinkElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLLinkElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLLinkElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLLinkElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLLinkElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLLinkElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    hrefLang?: string | undefined;
    referrerPolicy?: react.HTMLAttributeReferrerPolicy | undefined;
    fetchPriority?: "auto" | "high" | "low" | undefined;
    sizes?: string | undefined;
    as?: string | undefined;
    integrity?: string | undefined;
    imageSrcSet?: string | undefined;
    imageSizes?: string | undefined;
    charSet?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLLinkElement>>;
declare const MotionMain: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionMap: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLMapElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLMapElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLMapElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLMapElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLMapElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLMapElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLMapElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLMapElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLMapElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLMapElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLMapElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLMapElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLMapElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLMapElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLMapElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLMapElement> | undefined;
    onChange?: react.FormEventHandler<HTMLMapElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLMapElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLMapElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLMapElement> | undefined;
    onInput?: react.FormEventHandler<HTMLMapElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLMapElement> | undefined;
    onReset?: react.FormEventHandler<HTMLMapElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLMapElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLMapElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLMapElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLMapElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLMapElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onError?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLMapElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLMapElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLMapElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLMapElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLMapElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLMapElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLMapElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLMapElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLMapElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLMapElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLMapElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLMapElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLMapElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLMapElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLMapElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLMapElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLMapElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLMapElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLMapElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLMapElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLMapElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLMapElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLMapElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLMapElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLMapElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLMapElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLMapElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLMapElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLMapElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLMapElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLMapElement>>;
declare const MotionMark: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionMenu: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    type?: string | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionMenuitem: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionMeter: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    min?: string | number | undefined;
    max?: string | number | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLMeterElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLMeterElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLMeterElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLMeterElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLMeterElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLMeterElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLMeterElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLMeterElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLMeterElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLMeterElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLMeterElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLMeterElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLMeterElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLMeterElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLMeterElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLMeterElement> | undefined;
    onChange?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onInput?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onReset?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLMeterElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onError?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLMeterElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLMeterElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLMeterElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLMeterElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLMeterElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLMeterElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLMeterElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLMeterElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLMeterElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLMeterElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLMeterElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLMeterElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLMeterElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLMeterElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLMeterElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLMeterElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLMeterElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLMeterElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLMeterElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLMeterElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLMeterElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLMeterElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLMeterElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLMeterElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLMeterElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLMeterElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLMeterElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLMeterElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLMeterElement> | undefined;
    nonce?: string | undefined;
    form?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    high?: number | undefined;
    low?: number | undefined;
    optimum?: number | undefined;
} & MotionProps & react.RefAttributes<HTMLMeterElement>>;
declare const MotionNav: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionObject: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    type?: string | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLObjectElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLObjectElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLObjectElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLObjectElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLObjectElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLObjectElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLObjectElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLObjectElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLObjectElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLObjectElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLObjectElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLObjectElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLObjectElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLObjectElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLObjectElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLObjectElement> | undefined;
    onChange?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onInput?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onReset?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLObjectElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onError?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLObjectElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLObjectElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLObjectElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLObjectElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLObjectElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLObjectElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLObjectElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLObjectElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLObjectElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLObjectElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLObjectElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLObjectElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLObjectElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLObjectElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLObjectElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLObjectElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLObjectElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLObjectElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLObjectElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLObjectElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLObjectElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLObjectElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLObjectElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLObjectElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLObjectElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLObjectElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLObjectElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLObjectElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLObjectElement> | undefined;
    nonce?: string | undefined;
    form?: string | undefined;
    data?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    useMap?: string | undefined;
    classID?: string | undefined;
    wmode?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLObjectElement>>;
declare const MotionOl: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    start?: number | undefined;
    type?: "1" | "a" | "i" | "A" | "I" | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLOListElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLOListElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLOListElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLOListElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLOListElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLOListElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLOListElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLOListElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLOListElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLOListElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLOListElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLOListElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLOListElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLOListElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLOListElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLOListElement> | undefined;
    onChange?: react.FormEventHandler<HTMLOListElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLOListElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLOListElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLOListElement> | undefined;
    onInput?: react.FormEventHandler<HTMLOListElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLOListElement> | undefined;
    onReset?: react.FormEventHandler<HTMLOListElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLOListElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLOListElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLOListElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLOListElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLOListElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onError?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLOListElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLOListElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLOListElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLOListElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLOListElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLOListElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLOListElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLOListElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLOListElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLOListElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLOListElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLOListElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLOListElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLOListElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLOListElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLOListElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLOListElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLOListElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLOListElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLOListElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLOListElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLOListElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLOListElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLOListElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLOListElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLOListElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLOListElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLOListElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLOListElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLOListElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    reversed?: boolean | undefined;
} & MotionProps & react.RefAttributes<HTMLOListElement>>;
declare const MotionOptgroup: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLOptGroupElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLOptGroupElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLOptGroupElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLOptGroupElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLOptGroupElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLOptGroupElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLOptGroupElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLOptGroupElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLOptGroupElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLOptGroupElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLOptGroupElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLOptGroupElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLOptGroupElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLOptGroupElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLOptGroupElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLOptGroupElement> | undefined;
    onChange?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onInput?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onReset?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLOptGroupElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onError?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLOptGroupElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLOptGroupElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLOptGroupElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLOptGroupElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLOptGroupElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLOptGroupElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLOptGroupElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLOptGroupElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLOptGroupElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLOptGroupElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLOptGroupElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLOptGroupElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLOptGroupElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLOptGroupElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLOptGroupElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLOptGroupElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLOptGroupElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLOptGroupElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLOptGroupElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLOptGroupElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLOptGroupElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLOptGroupElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLOptGroupElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLOptGroupElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLOptGroupElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLOptGroupElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLOptGroupElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLOptGroupElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLOptGroupElement> | undefined;
    nonce?: string | undefined;
    disabled?: boolean | undefined;
    label?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLOptGroupElement>>;
declare const MotionOption: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLOptionElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLOptionElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLOptionElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLOptionElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLOptionElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLOptionElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLOptionElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLOptionElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLOptionElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLOptionElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLOptionElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLOptionElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLOptionElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLOptionElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLOptionElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLOptionElement> | undefined;
    onChange?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onInput?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onReset?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLOptionElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onError?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLOptionElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLOptionElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLOptionElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLOptionElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLOptionElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLOptionElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLOptionElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLOptionElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLOptionElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLOptionElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLOptionElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLOptionElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLOptionElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLOptionElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLOptionElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLOptionElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLOptionElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLOptionElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLOptionElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLOptionElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLOptionElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLOptionElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLOptionElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLOptionElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLOptionElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLOptionElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLOptionElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLOptionElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLOptionElement> | undefined;
    nonce?: string | undefined;
    disabled?: boolean | undefined;
    label?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    selected?: boolean | undefined;
} & MotionProps & react.RefAttributes<HTMLOptionElement>>;
declare const MotionOutput: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLOutputElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLOutputElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLOutputElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLOutputElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLOutputElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLOutputElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLOutputElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLOutputElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLOutputElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLOutputElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLOutputElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLOutputElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLOutputElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLOutputElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLOutputElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLOutputElement> | undefined;
    onChange?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onInput?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onReset?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLOutputElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onError?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLOutputElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLOutputElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLOutputElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLOutputElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLOutputElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLOutputElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLOutputElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLOutputElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLOutputElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLOutputElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLOutputElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLOutputElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLOutputElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLOutputElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLOutputElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLOutputElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLOutputElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLOutputElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLOutputElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLOutputElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLOutputElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLOutputElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLOutputElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLOutputElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLOutputElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLOutputElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLOutputElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLOutputElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLOutputElement> | undefined;
    nonce?: string | undefined;
    form?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    htmlFor?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLOutputElement>>;
declare const MotionP: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLParagraphElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLParagraphElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLParagraphElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLParagraphElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLParagraphElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLParagraphElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLParagraphElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLParagraphElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLParagraphElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLParagraphElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLParagraphElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLParagraphElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLParagraphElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLParagraphElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLParagraphElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLParagraphElement> | undefined;
    onChange?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onInput?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onReset?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLParagraphElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onError?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLParagraphElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLParagraphElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLParagraphElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLParagraphElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLParagraphElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLParagraphElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLParagraphElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLParagraphElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLParagraphElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLParagraphElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLParagraphElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLParagraphElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLParagraphElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLParagraphElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLParagraphElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLParagraphElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLParagraphElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLParagraphElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLParagraphElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLParagraphElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLParagraphElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLParagraphElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLParagraphElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLParagraphElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLParagraphElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLParagraphElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLParagraphElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLParagraphElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLParagraphElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLParagraphElement>>;
declare const MotionParam: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLParamElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLParamElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLParamElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLParamElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLParamElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLParamElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLParamElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLParamElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLParamElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLParamElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLParamElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLParamElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLParamElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLParamElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLParamElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLParamElement> | undefined;
    onChange?: react.FormEventHandler<HTMLParamElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLParamElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLParamElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLParamElement> | undefined;
    onInput?: react.FormEventHandler<HTMLParamElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLParamElement> | undefined;
    onReset?: react.FormEventHandler<HTMLParamElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLParamElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLParamElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLParamElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLParamElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLParamElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onError?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLParamElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLParamElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLParamElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLParamElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLParamElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLParamElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLParamElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLParamElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLParamElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLParamElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLParamElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLParamElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLParamElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLParamElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLParamElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLParamElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLParamElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLParamElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLParamElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLParamElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLParamElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLParamElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLParamElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLParamElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLParamElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLParamElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLParamElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLParamElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLParamElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLParamElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLParamElement>>;
declare const MotionPicture: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionPre: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLPreElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLPreElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLPreElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLPreElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLPreElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLPreElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLPreElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLPreElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLPreElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLPreElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLPreElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLPreElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLPreElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLPreElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLPreElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLPreElement> | undefined;
    onChange?: react.FormEventHandler<HTMLPreElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLPreElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLPreElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLPreElement> | undefined;
    onInput?: react.FormEventHandler<HTMLPreElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLPreElement> | undefined;
    onReset?: react.FormEventHandler<HTMLPreElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLPreElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLPreElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLPreElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLPreElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLPreElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onError?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLPreElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLPreElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLPreElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLPreElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLPreElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLPreElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLPreElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLPreElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLPreElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLPreElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLPreElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLPreElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLPreElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLPreElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLPreElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLPreElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLPreElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLPreElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLPreElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLPreElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLPreElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLPreElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLPreElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLPreElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLPreElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLPreElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLPreElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLPreElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLPreElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLPreElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLPreElement>>;
declare const MotionProgress: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    max?: string | number | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLProgressElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLProgressElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLProgressElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLProgressElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLProgressElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLProgressElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLProgressElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLProgressElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLProgressElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLProgressElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLProgressElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLProgressElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLProgressElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLProgressElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLProgressElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLProgressElement> | undefined;
    onChange?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onInput?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onReset?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLProgressElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onError?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLProgressElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLProgressElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLProgressElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLProgressElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLProgressElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLProgressElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLProgressElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLProgressElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLProgressElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLProgressElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLProgressElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLProgressElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLProgressElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLProgressElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLProgressElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLProgressElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLProgressElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLProgressElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLProgressElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLProgressElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLProgressElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLProgressElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLProgressElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLProgressElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLProgressElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLProgressElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLProgressElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLProgressElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLProgressElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLProgressElement>>;
declare const MotionQ: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLQuoteElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLQuoteElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLQuoteElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLQuoteElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLQuoteElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLQuoteElement> | undefined;
    onChange?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onInput?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onReset?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLQuoteElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onError?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLQuoteElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLQuoteElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLQuoteElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLQuoteElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLQuoteElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLQuoteElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLQuoteElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLQuoteElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLQuoteElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLQuoteElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLQuoteElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLQuoteElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLQuoteElement> | undefined;
    nonce?: string | undefined;
    cite?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLQuoteElement>>;
declare const MotionRp: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionRt: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionRuby: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionS: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionSamp: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionScript: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    type?: string | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    crossOrigin?: "" | "anonymous" | "use-credentials" | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLScriptElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLScriptElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLScriptElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLScriptElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLScriptElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLScriptElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLScriptElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLScriptElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLScriptElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLScriptElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLScriptElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLScriptElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLScriptElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLScriptElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLScriptElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLScriptElement> | undefined;
    onChange?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onInput?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onReset?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLScriptElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onError?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLScriptElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLScriptElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLScriptElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLScriptElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLScriptElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLScriptElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLScriptElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLScriptElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLScriptElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLScriptElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLScriptElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLScriptElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLScriptElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLScriptElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLScriptElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLScriptElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLScriptElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLScriptElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLScriptElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLScriptElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLScriptElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLScriptElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLScriptElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLScriptElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLScriptElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLScriptElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLScriptElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLScriptElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLScriptElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    referrerPolicy?: react.HTMLAttributeReferrerPolicy | undefined;
    src?: string | undefined;
    integrity?: string | undefined;
    charSet?: string | undefined;
    async?: boolean | undefined;
    defer?: boolean | undefined;
    noModule?: boolean | undefined;
} & MotionProps & react.RefAttributes<HTMLScriptElement>>;
declare const MotionSection: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionSelect: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    size?: number | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLSelectElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLSelectElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLSelectElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLSelectElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLSelectElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLSelectElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLSelectElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLSelectElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLSelectElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLSelectElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLSelectElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLSelectElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLSelectElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLSelectElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLSelectElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLSelectElement> | undefined;
    onChange?: react.ChangeEventHandler<HTMLSelectElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onInput?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onReset?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLSelectElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onError?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLSelectElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLSelectElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLSelectElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLSelectElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLSelectElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLSelectElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLSelectElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLSelectElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLSelectElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLSelectElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLSelectElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLSelectElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLSelectElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLSelectElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLSelectElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLSelectElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLSelectElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLSelectElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLSelectElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLSelectElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLSelectElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLSelectElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLSelectElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLSelectElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLSelectElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLSelectElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLSelectElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLSelectElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLSelectElement> | undefined;
    nonce?: string | undefined;
    multiple?: boolean | undefined;
    disabled?: boolean | undefined;
    form?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    autoComplete?: string | undefined;
    required?: boolean | undefined;
} & MotionProps & react.RefAttributes<HTMLSelectElement>>;
declare const MotionSmall: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionSource: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    type?: string | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    media?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLSourceElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLSourceElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLSourceElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLSourceElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLSourceElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLSourceElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLSourceElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLSourceElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLSourceElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLSourceElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLSourceElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLSourceElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLSourceElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLSourceElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLSourceElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLSourceElement> | undefined;
    onChange?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onInput?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onReset?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLSourceElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onError?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLSourceElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLSourceElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLSourceElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLSourceElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLSourceElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLSourceElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLSourceElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLSourceElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLSourceElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLSourceElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLSourceElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLSourceElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLSourceElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLSourceElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLSourceElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLSourceElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLSourceElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLSourceElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLSourceElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLSourceElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLSourceElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLSourceElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLSourceElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLSourceElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLSourceElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLSourceElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLSourceElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLSourceElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLSourceElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    src?: string | undefined;
    sizes?: string | undefined;
    srcSet?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLSourceElement>>;
declare const MotionSpan: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLSpanElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLSpanElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLSpanElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLSpanElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLSpanElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLSpanElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLSpanElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLSpanElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLSpanElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLSpanElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLSpanElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLSpanElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLSpanElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLSpanElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLSpanElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLSpanElement> | undefined;
    onChange?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onInput?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onReset?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLSpanElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onError?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLSpanElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLSpanElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLSpanElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLSpanElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLSpanElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLSpanElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLSpanElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLSpanElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLSpanElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLSpanElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLSpanElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLSpanElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLSpanElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLSpanElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLSpanElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLSpanElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLSpanElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLSpanElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLSpanElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLSpanElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLSpanElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLSpanElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLSpanElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLSpanElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLSpanElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLSpanElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLSpanElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLSpanElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLSpanElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLSpanElement>>;
declare const MotionStrong: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionStyle: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    type?: string | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    media?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLStyleElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLStyleElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLStyleElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLStyleElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLStyleElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLStyleElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLStyleElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLStyleElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLStyleElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLStyleElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLStyleElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLStyleElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLStyleElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLStyleElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLStyleElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLStyleElement> | undefined;
    onChange?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onInput?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onReset?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLStyleElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onError?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLStyleElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLStyleElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLStyleElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLStyleElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLStyleElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLStyleElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLStyleElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLStyleElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLStyleElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLStyleElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLStyleElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLStyleElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLStyleElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLStyleElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLStyleElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLStyleElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLStyleElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLStyleElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLStyleElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLStyleElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLStyleElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLStyleElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLStyleElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLStyleElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLStyleElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLStyleElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLStyleElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLStyleElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLStyleElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    scoped?: boolean | undefined;
} & MotionProps & react.RefAttributes<HTMLStyleElement>>;
declare const MotionSub: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionSummary: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionSup: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionTable: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    border?: number | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    summary?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    frame?: boolean | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    align?: "left" | "right" | "center" | undefined;
    bgcolor?: string | undefined;
    cellPadding?: string | number | undefined;
    cellSpacing?: string | number | undefined;
    rules?: "all" | "columns" | "none" | "rows" | "groups" | undefined;
} & MotionProps & react.RefAttributes<HTMLTableElement>>;
declare const MotionTbody: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableSectionElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableSectionElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableSectionElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableSectionElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableSectionElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTableSectionElement>>;
declare const MotionTd: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableDataCellElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableDataCellElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableDataCellElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableDataCellElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableDataCellElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableDataCellElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableDataCellElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableDataCellElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableDataCellElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableDataCellElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableDataCellElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableDataCellElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableDataCellElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableDataCellElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableDataCellElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableDataCellElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableDataCellElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableDataCellElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableDataCellElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableDataCellElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableDataCellElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableDataCellElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableDataCellElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableDataCellElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableDataCellElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableDataCellElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableDataCellElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableDataCellElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableDataCellElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableDataCellElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableDataCellElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableDataCellElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableDataCellElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableDataCellElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableDataCellElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableDataCellElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableDataCellElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableDataCellElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableDataCellElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableDataCellElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableDataCellElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableDataCellElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableDataCellElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableDataCellElement> | undefined;
    nonce?: string | undefined;
    abbr?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    align?: "left" | "right" | "center" | "justify" | "char" | undefined;
    colSpan?: number | undefined;
    headers?: string | undefined;
    rowSpan?: number | undefined;
    scope?: string | undefined;
    valign?: "bottom" | "top" | "baseline" | "middle" | undefined;
} & MotionProps & react.RefAttributes<HTMLTableDataCellElement>>;
declare const MotionTextarea: react.ForwardRefExoticComponent<{
    value?: string | number | readonly string[] | undefined;
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    name?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTextAreaElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTextAreaElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTextAreaElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTextAreaElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTextAreaElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTextAreaElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTextAreaElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTextAreaElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTextAreaElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTextAreaElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTextAreaElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTextAreaElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTextAreaElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTextAreaElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTextAreaElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTextAreaElement> | undefined;
    onChange?: react.ChangeEventHandler<HTMLTextAreaElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTextAreaElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTextAreaElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTextAreaElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTextAreaElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTextAreaElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTextAreaElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTextAreaElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTextAreaElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTextAreaElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTextAreaElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTextAreaElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTextAreaElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTextAreaElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTextAreaElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTextAreaElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTextAreaElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTextAreaElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTextAreaElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTextAreaElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTextAreaElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTextAreaElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTextAreaElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTextAreaElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTextAreaElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTextAreaElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTextAreaElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTextAreaElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTextAreaElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTextAreaElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTextAreaElement> | undefined;
    nonce?: string | undefined;
    wrap?: string | undefined;
    disabled?: boolean | undefined;
    form?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    autoComplete?: string | undefined;
    maxLength?: number | undefined;
    minLength?: number | undefined;
    placeholder?: string | undefined;
    readOnly?: boolean | undefined;
    required?: boolean | undefined;
    cols?: number | undefined;
    dirName?: string | undefined;
    rows?: number | undefined;
} & MotionProps & react.RefAttributes<HTMLTextAreaElement>>;
declare const MotionTfoot: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableSectionElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableSectionElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableSectionElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableSectionElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableSectionElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTableSectionElement>>;
declare const MotionTh: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableHeaderCellElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableHeaderCellElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableHeaderCellElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableHeaderCellElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableHeaderCellElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableHeaderCellElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableHeaderCellElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableHeaderCellElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableHeaderCellElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableHeaderCellElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableHeaderCellElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableHeaderCellElement> | undefined;
    nonce?: string | undefined;
    abbr?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    align?: "left" | "right" | "center" | "justify" | "char" | undefined;
    colSpan?: number | undefined;
    headers?: string | undefined;
    rowSpan?: number | undefined;
    scope?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTableHeaderCellElement>>;
declare const MotionThead: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableSectionElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableSectionElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableSectionElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableSectionElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableSectionElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableSectionElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableSectionElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableSectionElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableSectionElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableSectionElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableSectionElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableSectionElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableSectionElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableSectionElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableSectionElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTableSectionElement>>;
declare const MotionTime: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTimeElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTimeElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTimeElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTimeElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTimeElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTimeElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTimeElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTimeElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTimeElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTimeElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTimeElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTimeElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTimeElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTimeElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTimeElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTimeElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTimeElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTimeElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTimeElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTimeElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTimeElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTimeElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTimeElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTimeElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTimeElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTimeElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTimeElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTimeElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTimeElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTimeElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTimeElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTimeElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTimeElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTimeElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTimeElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTimeElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTimeElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTimeElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTimeElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTimeElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTimeElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTimeElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTimeElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTimeElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTimeElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTimeElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    dateTime?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTimeElement>>;
declare const MotionTitle: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTitleElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTitleElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTitleElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTitleElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTitleElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTitleElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTitleElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTitleElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTitleElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTitleElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTitleElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTitleElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTitleElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTitleElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTitleElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTitleElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTitleElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTitleElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTitleElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTitleElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTitleElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTitleElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTitleElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTitleElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTitleElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTitleElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTitleElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTitleElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTitleElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTitleElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTitleElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTitleElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTitleElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTitleElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTitleElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTitleElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTitleElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTitleElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTitleElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTitleElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTitleElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTitleElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTitleElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTitleElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTitleElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTitleElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTitleElement>>;
declare const MotionTr: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTableRowElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTableRowElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTableRowElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTableRowElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTableRowElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTableRowElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTableRowElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTableRowElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTableRowElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTableRowElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTableRowElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTableRowElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTableRowElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTableRowElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTableRowElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTableRowElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTableRowElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTableRowElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTableRowElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTableRowElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTableRowElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTableRowElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTableRowElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTableRowElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTableRowElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTableRowElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTableRowElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTableRowElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTableRowElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTableRowElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTableRowElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTableRowElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTableRowElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTableRowElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTableRowElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTableRowElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTableRowElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTableRowElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTableRowElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTableRowElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTableRowElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTableRowElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTableRowElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTableRowElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTableRowElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTableRowElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTableRowElement>>;
declare const MotionTrack: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    default?: boolean | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLTrackElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLTrackElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLTrackElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLTrackElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLTrackElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLTrackElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLTrackElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLTrackElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLTrackElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLTrackElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLTrackElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLTrackElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLTrackElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLTrackElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLTrackElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLTrackElement> | undefined;
    onChange?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onInput?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onReset?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLTrackElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onError?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLTrackElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLTrackElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLTrackElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLTrackElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLTrackElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLTrackElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLTrackElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLTrackElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLTrackElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLTrackElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLTrackElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLTrackElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLTrackElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLTrackElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLTrackElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLTrackElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLTrackElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLTrackElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLTrackElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLTrackElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLTrackElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLTrackElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLTrackElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLTrackElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLTrackElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLTrackElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLTrackElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLTrackElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLTrackElement> | undefined;
    nonce?: string | undefined;
    label?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    src?: string | undefined;
    kind?: string | undefined;
    srcLang?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLTrackElement>>;
declare const MotionU: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionUl: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLUListElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLUListElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLUListElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLUListElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLUListElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLUListElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLUListElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLUListElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLUListElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLUListElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLUListElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLUListElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLUListElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLUListElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLUListElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLUListElement> | undefined;
    onChange?: react.FormEventHandler<HTMLUListElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLUListElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLUListElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLUListElement> | undefined;
    onInput?: react.FormEventHandler<HTMLUListElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLUListElement> | undefined;
    onReset?: react.FormEventHandler<HTMLUListElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLUListElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLUListElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLUListElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLUListElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLUListElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onError?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLUListElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLUListElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLUListElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLUListElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLUListElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLUListElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLUListElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLUListElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLUListElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLUListElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLUListElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLUListElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLUListElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLUListElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLUListElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLUListElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLUListElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLUListElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLUListElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLUListElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLUListElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLUListElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLUListElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLUListElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLUListElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLUListElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLUListElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLUListElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLUListElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLUListElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLUListElement>>;
declare const MotionVideo: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    height?: string | number | undefined;
    translate?: "no" | "yes" | undefined;
    width?: string | number | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    crossOrigin?: "" | "anonymous" | "use-credentials" | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLVideoElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLVideoElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLVideoElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLVideoElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLVideoElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLVideoElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLVideoElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLVideoElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLVideoElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLVideoElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLVideoElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLVideoElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLVideoElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLVideoElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLVideoElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLVideoElement> | undefined;
    onChange?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onInput?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onReset?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLVideoElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onError?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLVideoElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLVideoElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLVideoElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLVideoElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLVideoElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLVideoElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLVideoElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLVideoElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLVideoElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLVideoElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLVideoElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLVideoElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLVideoElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLVideoElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLVideoElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLVideoElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLVideoElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLVideoElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLVideoElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLVideoElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLVideoElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLVideoElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLVideoElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLVideoElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLVideoElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLVideoElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLVideoElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLVideoElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLVideoElement> | undefined;
    loop?: boolean | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    autoPlay?: boolean | undefined;
    controls?: boolean | undefined;
    controlsList?: string | undefined;
    mediaGroup?: string | undefined;
    muted?: boolean | undefined;
    playsInline?: boolean | undefined;
    preload?: string | undefined;
    src?: string | undefined;
    poster?: string | undefined;
    disablePictureInPicture?: boolean | undefined;
    disableRemotePlayback?: boolean | undefined;
} & MotionProps & react.RefAttributes<HTMLVideoElement>>;
declare const MotionWbr: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLElement> | undefined;
    onChange?: react.FormEventHandler<HTMLElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInput?: react.FormEventHandler<HTMLElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onReset?: react.FormEventHandler<HTMLElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onError?: react.ReactEventHandler<HTMLElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLElement>>;
declare const MotionWebview: react.ForwardRefExoticComponent<{
    color?: string | undefined;
    content?: string | undefined;
    translate?: "no" | "yes" | undefined;
    hidden?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    className?: string | undefined;
    id?: string | undefined;
    lang?: string | undefined;
    role?: react.AriaRole | undefined;
    tabIndex?: number | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "false" | "true") | undefined;
    "aria-autocomplete"?: "both" | "none" | "inline" | "list" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "false" | "true") | undefined;
    "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "page" | "false" | "true" | "step" | "location" | "date" | "time" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "false" | "true") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "move" | "link" | "execute" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "false" | "true") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    "aria-haspopup"?: boolean | "grid" | "listbox" | "menu" | "false" | "true" | "dialog" | "tree" | undefined;
    "aria-hidden"?: (boolean | "false" | "true") | undefined;
    "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-label"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "false" | "true") | undefined;
    "aria-multiline"?: (boolean | "false" | "true") | undefined;
    "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    "aria-readonly"?: (boolean | "false" | "true") | undefined;
    "aria-relevant"?: "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "false" | "true") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-selected"?: (boolean | "false" | "true") | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: react.ClipboardEventHandler<HTMLWebViewElement> | undefined;
    onCopyCapture?: react.ClipboardEventHandler<HTMLWebViewElement> | undefined;
    onCut?: react.ClipboardEventHandler<HTMLWebViewElement> | undefined;
    onCutCapture?: react.ClipboardEventHandler<HTMLWebViewElement> | undefined;
    onPaste?: react.ClipboardEventHandler<HTMLWebViewElement> | undefined;
    onPasteCapture?: react.ClipboardEventHandler<HTMLWebViewElement> | undefined;
    onCompositionEnd?: react.CompositionEventHandler<HTMLWebViewElement> | undefined;
    onCompositionEndCapture?: react.CompositionEventHandler<HTMLWebViewElement> | undefined;
    onCompositionStart?: react.CompositionEventHandler<HTMLWebViewElement> | undefined;
    onCompositionStartCapture?: react.CompositionEventHandler<HTMLWebViewElement> | undefined;
    onCompositionUpdate?: react.CompositionEventHandler<HTMLWebViewElement> | undefined;
    onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLWebViewElement> | undefined;
    onFocus?: react.FocusEventHandler<HTMLWebViewElement> | undefined;
    onFocusCapture?: react.FocusEventHandler<HTMLWebViewElement> | undefined;
    onBlur?: react.FocusEventHandler<HTMLWebViewElement> | undefined;
    onBlurCapture?: react.FocusEventHandler<HTMLWebViewElement> | undefined;
    onChange?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onChangeCapture?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onBeforeInput?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onBeforeInputCapture?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onInput?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onInputCapture?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onReset?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onResetCapture?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onSubmit?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onSubmitCapture?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onInvalid?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onInvalidCapture?: react.FormEventHandler<HTMLWebViewElement> | undefined;
    onLoad?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onLoadCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onError?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onErrorCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onKeyDown?: react.KeyboardEventHandler<HTMLWebViewElement> | undefined;
    onKeyDownCapture?: react.KeyboardEventHandler<HTMLWebViewElement> | undefined;
    onKeyPress?: react.KeyboardEventHandler<HTMLWebViewElement> | undefined;
    onKeyPressCapture?: react.KeyboardEventHandler<HTMLWebViewElement> | undefined;
    onKeyUp?: react.KeyboardEventHandler<HTMLWebViewElement> | undefined;
    onKeyUpCapture?: react.KeyboardEventHandler<HTMLWebViewElement> | undefined;
    onAbort?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onAbortCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onCanPlay?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onCanPlayCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onCanPlayThrough?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onCanPlayThroughCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onDurationChange?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onDurationChangeCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onEmptied?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onEmptiedCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onEncrypted?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onEncryptedCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onEnded?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onEndedCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onLoadedData?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onLoadedDataCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onLoadedMetadata?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onLoadedMetadataCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onLoadStart?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onLoadStartCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onPause?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onPauseCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onPlay?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onPlayCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onPlaying?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onPlayingCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onProgress?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onProgressCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onRateChange?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onRateChangeCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onResize?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onResizeCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onSeeked?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onSeekedCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onSeeking?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onSeekingCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onStalled?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onStalledCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onSuspend?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onSuspendCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onTimeUpdate?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onTimeUpdateCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onVolumeChange?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onVolumeChangeCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onWaiting?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onWaitingCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onAuxClick?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onAuxClickCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onClick?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onClickCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onContextMenu?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onContextMenuCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onDoubleClick?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onDoubleClickCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onDragCapture?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragEndCapture?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragEnter?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragEnterCapture?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragExit?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragExitCapture?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragLeave?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragLeaveCapture?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragOver?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragOverCapture?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDragStartCapture?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDrop?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onDropCapture?: react.DragEventHandler<HTMLWebViewElement> | undefined;
    onMouseDown?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseDownCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseEnter?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseLeave?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseMove?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseMoveCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseOut?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseOutCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseOver?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseOverCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseUp?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onMouseUpCapture?: react.MouseEventHandler<HTMLWebViewElement> | undefined;
    onSelect?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onSelectCapture?: react.ReactEventHandler<HTMLWebViewElement> | undefined;
    onTouchCancel?: react.TouchEventHandler<HTMLWebViewElement> | undefined;
    onTouchCancelCapture?: react.TouchEventHandler<HTMLWebViewElement> | undefined;
    onTouchEnd?: react.TouchEventHandler<HTMLWebViewElement> | undefined;
    onTouchEndCapture?: react.TouchEventHandler<HTMLWebViewElement> | undefined;
    onTouchMove?: react.TouchEventHandler<HTMLWebViewElement> | undefined;
    onTouchMoveCapture?: react.TouchEventHandler<HTMLWebViewElement> | undefined;
    onTouchStart?: react.TouchEventHandler<HTMLWebViewElement> | undefined;
    onTouchStartCapture?: react.TouchEventHandler<HTMLWebViewElement> | undefined;
    onPointerDown?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerDownCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerMove?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerMoveCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerUp?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerUpCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerCancel?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerCancelCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerEnter?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerLeave?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerOver?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerOverCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerOut?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onPointerOutCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onGotPointerCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onLostPointerCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLWebViewElement> | undefined;
    onScroll?: react.UIEventHandler<HTMLWebViewElement> | undefined;
    onScrollCapture?: react.UIEventHandler<HTMLWebViewElement> | undefined;
    onWheel?: react.WheelEventHandler<HTMLWebViewElement> | undefined;
    onWheelCapture?: react.WheelEventHandler<HTMLWebViewElement> | undefined;
    onAnimationStartCapture?: react.AnimationEventHandler<HTMLWebViewElement> | undefined;
    onAnimationEnd?: react.AnimationEventHandler<HTMLWebViewElement> | undefined;
    onAnimationEndCapture?: react.AnimationEventHandler<HTMLWebViewElement> | undefined;
    onAnimationIteration?: react.AnimationEventHandler<HTMLWebViewElement> | undefined;
    onAnimationIterationCapture?: react.AnimationEventHandler<HTMLWebViewElement> | undefined;
    onTransitionEnd?: react.TransitionEventHandler<HTMLWebViewElement> | undefined;
    onTransitionEndCapture?: react.TransitionEventHandler<HTMLWebViewElement> | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    title?: string | undefined;
    dir?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoFocus?: boolean | undefined;
    contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    draggable?: (boolean | "false" | "true") | undefined;
    spellCheck?: (boolean | "false" | "true") | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCapitalize?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    preload?: string | undefined;
    src?: string | undefined;
    allowFullScreen?: boolean | undefined;
    allowpopups?: boolean | undefined;
    autosize?: boolean | undefined;
    blinkfeatures?: string | undefined;
    disableblinkfeatures?: string | undefined;
    disableguestresize?: boolean | undefined;
    disablewebsecurity?: boolean | undefined;
    guestinstance?: string | undefined;
    httpreferrer?: string | undefined;
    nodeintegration?: boolean | undefined;
    partition?: string | undefined;
    plugins?: boolean | undefined;
    useragent?: string | undefined;
    webpreferences?: string | undefined;
} & MotionProps & react.RefAttributes<HTMLWebViewElement>>;
/**
 * SVG components
 * TODO: Generate list with props/instance
 */
declare const MotionAnimate: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionCircle: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionDefs: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionDesc: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionEllipse: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionG: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionImage: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionLine: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFilter: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionMarker: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionMask: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionMetadata: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionPath: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionPattern: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionPolygon: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionPolyline: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionRect: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionStop: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionSvg: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionSymbol: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionText: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionTspan: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionUse: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionView: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionClipPath: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeBlend: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeColorMatrix: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeComponentTransfer: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeComposite: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeConvolveMatrix: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeDiffuseLighting: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeDisplacementMap: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeDistantLight: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeDropShadow: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeFlood: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeFuncA: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeFuncB: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeFuncG: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeFuncR: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeGaussianBlur: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeImage: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeMerge: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeMergeNode: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeMorphology: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeOffset: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFePointLight: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeSpecularLighting: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeSpotLight: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeTile: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionFeTurbulence: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionForeignObject: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionLinearGradient: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionRadialGradient: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;
declare const MotionTextPath: react.ForwardRefExoticComponent<{} & MotionProps & react.RefAttributes<SVGElement | HTMLElement>>;

declare namespace namespace_d$1 {
  export { MotionA as a, MotionAbbr as abbr, MotionAddress as address, MotionAnimate as animate, MotionArea as area, MotionArticle as article, MotionAside as aside, MotionAudio as audio, MotionB as b, MotionBase as base, MotionBdi as bdi, MotionBdo as bdo, MotionBig as big, MotionBlockquote as blockquote, MotionBody as body, MotionButton as button, MotionCanvas as canvas, MotionCaption as caption, MotionCircle as circle, MotionCite as cite, MotionClipPath as clipPath, MotionCode as code, MotionCol as col, MotionColgroup as colgroup, MotionData as data, MotionDatalist as datalist, MotionDd as dd, MotionDefs as defs, MotionDel as del, MotionDesc as desc, MotionDetails as details, MotionDfn as dfn, MotionDialog as dialog, MotionDiv as div, MotionDl as dl, MotionDt as dt, MotionEllipse as ellipse, MotionEm as em, MotionEmbed as embed, MotionFeBlend as feBlend, MotionFeColorMatrix as feColorMatrix, MotionFeComponentTransfer as feComponentTransfer, MotionFeComposite as feComposite, MotionFeConvolveMatrix as feConvolveMatrix, MotionFeDiffuseLighting as feDiffuseLighting, MotionFeDisplacementMap as feDisplacementMap, MotionFeDistantLight as feDistantLight, MotionFeDropShadow as feDropShadow, MotionFeFlood as feFlood, MotionFeFuncA as feFuncA, MotionFeFuncB as feFuncB, MotionFeFuncG as feFuncG, MotionFeFuncR as feFuncR, MotionFeGaussianBlur as feGaussianBlur, MotionFeImage as feImage, MotionFeMerge as feMerge, MotionFeMergeNode as feMergeNode, MotionFeMorphology as feMorphology, MotionFeOffset as feOffset, MotionFePointLight as fePointLight, MotionFeSpecularLighting as feSpecularLighting, MotionFeSpotLight as feSpotLight, MotionFeTile as feTile, MotionFeTurbulence as feTurbulence, MotionFieldset as fieldset, MotionFigcaption as figcaption, MotionFigure as figure, MotionFilter as filter, MotionFooter as footer, MotionForeignObject as foreignObject, MotionForm as form, MotionG as g, MotionH1 as h1, MotionH2 as h2, MotionH3 as h3, MotionH4 as h4, MotionH5 as h5, MotionH6 as h6, MotionHead as head, MotionHeader as header, MotionHgroup as hgroup, MotionHr as hr, MotionHtml as html, MotionI as i, MotionIframe as iframe, MotionImage as image, MotionImg as img, MotionInput as input, MotionIns as ins, MotionKbd as kbd, MotionKeygen as keygen, MotionLabel as label, MotionLegend as legend, MotionLi as li, MotionLine as line, MotionLinearGradient as linearGradient, MotionLink as link, MotionMain as main, MotionMap as map, MotionMark as mark, MotionMarker as marker, MotionMask as mask, MotionMenu as menu, MotionMenuitem as menuitem, MotionMetadata as metadata, MotionMeter as meter, MotionNav as nav, MotionObject as object, MotionOl as ol, MotionOptgroup as optgroup, MotionOption as option, MotionOutput as output, MotionP as p, MotionParam as param, MotionPath as path, MotionPattern as pattern, MotionPicture as picture, MotionPolygon as polygon, MotionPolyline as polyline, MotionPre as pre, MotionProgress as progress, MotionQ as q, MotionRadialGradient as radialGradient, MotionRect as rect, MotionRp as rp, MotionRt as rt, MotionRuby as ruby, MotionS as s, MotionSamp as samp, MotionScript as script, MotionSection as section, MotionSelect as select, MotionSmall as small, MotionSource as source, MotionSpan as span, MotionStop as stop, MotionStrong as strong, MotionStyle as style, MotionSub as sub, MotionSummary as summary, MotionSup as sup, MotionSvg as svg, MotionSymbol as symbol, MotionTable as table, MotionTbody as tbody, MotionTd as td, MotionText as text, MotionTextPath as textPath, MotionTextarea as textarea, MotionTfoot as tfoot, MotionTh as th, MotionThead as thead, MotionTime as time, MotionTitle as title, MotionTr as tr, MotionTrack as track, MotionTspan as tspan, MotionU as u, MotionUl as ul, MotionUse as use, MotionVideo as video, MotionView as view, MotionWbr as wbr, MotionWebview as webview };
}

/**
 * @public
 */
interface AnimatePresenceProps {
    /**
     * By passing `initial={false}`, `AnimatePresence` will disable any initial animations on children
     * that are present when the component is first rendered.
     *
     * ```jsx
     * <AnimatePresence initial={false}>
     *   {isVisible && (
     *     <motion.div
     *       key="modal"
     *       initial={{ opacity: 0 }}
     *       animate={{ opacity: 1 }}
     *       exit={{ opacity: 0 }}
     *     />
     *   )}
     * </AnimatePresence>
     * ```
     *
     * @public
     */
    initial?: boolean;
    /**
     * When a component is removed, there's no longer a chance to update its props. So if a component's `exit`
     * prop is defined as a dynamic variant and you want to pass a new `custom` prop, you can do so via `AnimatePresence`.
     * This will ensure all leaving components animate using the latest data.
     *
     * @public
     */
    custom?: any;
    /**
     * Fires when all exiting nodes have completed animating out.
     *
     * @public
     */
    onExitComplete?: () => void;
    /**
     * Replace with `mode="wait"`
     *
     * @deprecated
     *
     * Replace with `mode="wait"`
     */
    exitBeforeEnter?: boolean;
    /**
     * Determines how to handle entering and exiting elements.
     *
     * - `"sync"`: Default. Elements animate in and out as soon as they're added/removed.
     * - `"popLayout"`: Exiting elements are "popped" from the page layout, allowing sibling
     *      elements to immediately occupy their new layouts.
     * - `"wait"`: Only renders one component at a time. Wait for the exiting component to animate out
     *      before animating the next component in.
     *
     * @public
     */
    mode?: "sync" | "popLayout" | "wait";
    /**
     * Internal. Used in Framer to flag that sibling children *shouldn't* re-render as a result of a
     * child being removed.
     */
    presenceAffectsLayout?: boolean;
}

/**
 * `AnimatePresence` enables the animation of components that have been removed from the tree.
 *
 * When adding/removing more than a single child, every child **must** be given a unique `key` prop.
 *
 * Any `motion` components that have an `exit` property defined will animate out when removed from
 * the tree.
 *
 * ```jsx
 * import { motion, AnimatePresence } from 'framer-motion'
 *
 * export const Items = ({ items }) => (
 *   <AnimatePresence>
 *     {items.map(item => (
 *       <motion.div
 *         key={item.id}
 *         initial={{ opacity: 0 }}
 *         animate={{ opacity: 1 }}
 *         exit={{ opacity: 0 }}
 *       />
 *     ))}
 *   </AnimatePresence>
 * )
 * ```
 *
 * You can sequence exit animations throughout a tree using variants.
 *
 * If a child contains multiple `motion` components with `exit` props, it will only unmount the child
 * once all `motion` components have finished animating out. Likewise, any components using
 * `usePresence` all need to call `safeToRemove`.
 *
 * @public
 */
declare const AnimatePresence: react.FunctionComponent<react.PropsWithChildren<AnimatePresenceProps>>;

type IsValidProp = (key: string) => boolean;
declare function filterProps(props: MotionProps, isDom: boolean, forwardMotionProps: boolean): MotionProps;

interface MotionConfigProps extends Partial<MotionConfigContext> {
    children?: react.ReactNode;
    isValidProp?: IsValidProp;
}
/**
 * `MotionConfig` is used to set configuration options for all children `motion` components.
 *
 * ```jsx
 * import { motion, MotionConfig } from "framer-motion"
 *
 * export function App() {
 *   return (
 *     <MotionConfig transition={{ type: "spring" }}>
 *       <motion.div animate={{ x: 100 }} />
 *     </MotionConfig>
 *   )
 * }
 * ```
 *
 * @public
 */
declare function MotionConfig({ children, isValidProp, ...config }: MotionConfigProps): react_jsx_runtime.JSX.Element;

declare abstract class Feature<T extends any = any> {
    isMounted: boolean;
    node: VisualElement<T>;
    constructor(node: VisualElement<T>);
    abstract mount(): void;
    abstract unmount(): void;
    update(): void;
}

declare function MeasureLayout(props: MotionProps & {
    visualElement: VisualElement;
}): react_jsx_runtime.JSX.Element;

interface FeatureClass<Props = unknown> {
    new (props: Props): Feature<Props>;
}
type HydratedFeatureDefinition = {
    isEnabled: (props: MotionProps) => boolean;
    Feature: FeatureClass<unknown>;
    ProjectionNode?: any;
    MeasureLayout?: typeof MeasureLayout;
};
interface HydratedFeatureDefinitions {
    animation?: HydratedFeatureDefinition;
    exit?: HydratedFeatureDefinition;
    drag?: HydratedFeatureDefinition;
    tap?: HydratedFeatureDefinition;
    focus?: HydratedFeatureDefinition;
    hover?: HydratedFeatureDefinition;
    pan?: HydratedFeatureDefinition;
    inView?: HydratedFeatureDefinition;
    layout?: HydratedFeatureDefinition;
}
type FeatureDefinition = {
    isEnabled: HydratedFeatureDefinition["isEnabled"];
    Feature?: HydratedFeatureDefinition["Feature"];
    ProjectionNode?: HydratedFeatureDefinition["ProjectionNode"];
    MeasureLayout?: HydratedFeatureDefinition["MeasureLayout"];
};
type FeatureDefinitions = {
    [K in keyof HydratedFeatureDefinitions]: FeatureDefinition;
};
type FeaturePackage = {
    Feature?: HydratedFeatureDefinition["Feature"];
    ProjectionNode?: HydratedFeatureDefinition["ProjectionNode"];
    MeasureLayout?: HydratedFeatureDefinition["MeasureLayout"];
};
type FeaturePackages = {
    [K in keyof HydratedFeatureDefinitions]: FeaturePackage;
};
interface FeatureBundle extends FeaturePackages {
    renderer: CreateVisualElement<any>;
}
type LazyFeatureBundle$1 = () => Promise<FeatureBundle>;
type RenderComponent<Instance, RenderState> = (Component: string | react.ComponentType<react.PropsWithChildren<unknown>>, props: MotionProps, ref: react.Ref<Instance>, visualState: VisualState<Instance, RenderState>, isStatic: boolean, visualElement?: VisualElement<Instance>) => any;

type LazyFeatureBundle = () => Promise<FeatureBundle>;
/**
 * @public
 */
interface LazyProps {
    children?: React.ReactNode;
    /**
     * Can be used to provide a feature bundle synchronously or asynchronously.
     *
     * ```jsx
     * // features.js
     * import { domAnimation } from "framer-motion"
     * export default domAnimation
     *
     * // index.js
     * import { LazyMotion, m } from "framer-motion"
     *
     * const loadFeatures = import("./features.js")
     *   .then(res => res.default)
     *
     * function Component() {
     *   return (
     *     <LazyMotion features={loadFeatures}>
     *       <m.div animate={{ scale: 1.5 }} />
     *     </LazyMotion>
     *   )
     * }
     * ```
     *
     * @public
     */
    features: FeatureBundle | LazyFeatureBundle;
    /**
     * If `true`, will throw an error if a `motion` component renders within
     * a `LazyMotion` component.
     *
     * ```jsx
     * // This component will throw an error that explains using a motion component
     * // instead of the m component will break the benefits of code-splitting.
     * function Component() {
     *   return (
     *     <LazyMotion features={domAnimation} strict>
     *       <motion.div />
     *     </LazyMotion>
     *   )
     * }
     * ```
     *
     * @public
     */
    strict?: boolean;
}

/**
 * Used in conjunction with the `m` component to reduce bundle size.
 *
 * `m` is a version of the `motion` component that only loads functionality
 * critical for the initial render.
 *
 * `LazyMotion` can then be used to either synchronously or asynchronously
 * load animation and gesture support.
 *
 * ```jsx
 * // Synchronous loading
 * import { LazyMotion, m, domAnimation } from "framer-motion"
 *
 * function App() {
 *   return (
 *     <LazyMotion features={domAnimation}>
 *       <m.div animate={{ scale: 2 }} />
 *     </LazyMotion>
 *   )
 * }
 *
 * // Asynchronous loading
 * import { LazyMotion, m } from "framer-motion"
 *
 * function App() {
 *   return (
 *     <LazyMotion features={() => import('./path/to/domAnimation')}>
 *       <m.div animate={{ scale: 2 }} />
 *     </LazyMotion>
 *   )
 * }
 * ```
 *
 * @public
 */
declare function LazyMotion({ children, features, strict }: LazyProps): react_jsx_runtime.JSX.Element;

type InheritOption = boolean | "id";
interface Props$2 {
    id?: string;
    inherit?: InheritOption;
}
declare const LayoutGroup: react.FunctionComponent<react.PropsWithChildren<Props$2>>;

interface Props$1<V> {
    /**
     * A HTML element to render this component as. Defaults to `"ul"`.
     *
     * @public
     */
    as?: keyof ReactHTML;
    /**
     * The axis to reorder along. By default, items will be draggable on this axis.
     * To make draggable on both axes, set `<Reorder.Item drag />`
     *
     * @public
     */
    axis?: "x" | "y";
    /**
     * A callback to fire with the new value order. For instance, if the values
     * are provided as a state from `useState`, this could be the set state function.
     *
     * @public
     */
    onReorder: (newOrder: V[]) => void;
    /**
     * The latest values state.
     *
     * ```jsx
     * function Component() {
     *   const [items, setItems] = useState([0, 1, 2])
     *
     *   return (
     *     <Reorder.Group values={items} onReorder={setItems}>
     *         {items.map((item) => <Reorder.Item key={item} value={item} />)}
     *     </Reorder.Group>
     *   )
     * }
     * ```
     *
     * @public
     */
    values: V[];
}
type ReorderGroupProps<V> = Props$1<V> & Omit<HTMLMotionProps<any>, "values"> & react.PropsWithChildren<{}>;
declare function ReorderGroupComponent<V>({ children, as, axis, onReorder, values, ...props }: ReorderGroupProps<V>, externalRef?: react.ForwardedRef<any>): react_jsx_runtime.JSX.Element;
declare const ReorderGroup: <V>(props: ReorderGroupProps<V> & {
    ref?: react.ForwardedRef<any>;
}) => ReturnType<typeof ReorderGroupComponent>;

interface Props<V> {
    /**
     * A HTML element to render this component as. Defaults to `"li"`.
     *
     * @public
     */
    as?: keyof ReactHTML;
    /**
     * The value in the list that this component represents.
     *
     * @public
     */
    value: V;
    /**
     * A subset of layout options primarily used to disable layout="size"
     *
     * @public
     * @default true
     */
    layout?: true | "position";
}
type ReorderItemProps<V> = Props<V> & HTMLMotionProps<any> & react.PropsWithChildren<{}>;
declare function ReorderItemComponent<V>({ children, style, value, as, onDrag, layout, ...props }: ReorderItemProps<V>, externalRef?: react.ForwardedRef<any>): react_jsx_runtime.JSX.Element;
declare const ReorderItem: <V>(props: ReorderItemProps<V> & {
    ref?: react.ForwardedRef<any>;
}) => ReturnType<typeof ReorderItemComponent>;

declare namespace namespace_d {
  export { ReorderGroup as Group, ReorderItem as Item };
}

type SequenceTime = number | "<" | `+${number}` | `-${number}` | `${string}`;
type SequenceLabel = string;
interface SequenceLabelWithTime {
    name: SequenceLabel;
    at: SequenceTime;
}
interface At {
    at?: SequenceTime;
}
type MotionValueSegment = [
    MotionValue,
    UnresolvedValueKeyframe | UnresolvedValueKeyframe[]
];
type MotionValueSegmentWithTransition = [
    MotionValue,
    UnresolvedValueKeyframe | UnresolvedValueKeyframe[],
    Transition & At
];
type DOMSegment = [ElementOrSelector, DOMKeyframesDefinition];
type DOMSegmentWithTransition = [
    ElementOrSelector,
    DOMKeyframesDefinition,
    DynamicAnimationOptions & At
];
type Segment = MotionValueSegment | MotionValueSegmentWithTransition | DOMSegment | DOMSegmentWithTransition | SequenceLabel | SequenceLabelWithTime;
type AnimationSequence = Segment[];
interface SequenceOptions extends AnimationPlaybackOptions {
    delay?: number;
    duration?: number;
    defaultTransition?: Transition;
}
interface AbsoluteKeyframe {
    value: string | number | null;
    at: number;
    easing?: Easing;
}
type ValueSequence = AbsoluteKeyframe[];
interface SequenceMap {
    [key: string]: ValueSequence;
}
type ResolvedAnimationDefinition = {
    keyframes: {
        [key: string]: UnresolvedValueKeyframe[];
    };
    transition: {
        [key: string]: Transition;
    };
};
type ResolvedAnimationDefinitions = Map<Element | MotionValue, ResolvedAnimationDefinition>;

declare const createScopedAnimate: (scope?: AnimationScope) => {
    <V>(from: V, to: V | GenericKeyframesTarget<V>, options?: ValueAnimationTransition<V>): AnimationPlaybackControls;
    <V_1>(value: MotionValue<V_1>, keyframes: V_1 | GenericKeyframesTarget<V_1>, options?: ValueAnimationTransition<V_1> | undefined): AnimationPlaybackControls;
    (value: ElementOrSelector, keyframes: DOMKeyframesDefinition, options?: DynamicAnimationOptions): AnimationPlaybackControls;
    (sequence: AnimationSequence, options?: SequenceOptions): AnimationPlaybackControls;
};
declare const animate: {
    <V>(from: V, to: V | GenericKeyframesTarget<V>, options?: ValueAnimationTransition<V>): AnimationPlaybackControls;
    <V_1>(value: MotionValue<V_1>, keyframes: V_1 | GenericKeyframesTarget<V_1>, options?: ValueAnimationTransition<V_1> | undefined): AnimationPlaybackControls;
    (value: ElementOrSelector, keyframes: DOMKeyframesDefinition, options?: DynamicAnimationOptions): AnimationPlaybackControls;
    (sequence: AnimationSequence, options?: SequenceOptions): AnimationPlaybackControls;
};

interface ScrollOptions {
    source?: Element;
    axis?: "x" | "y";
}
type OnScroll = (progress: number) => void;
interface AxisScrollInfo {
    current: number;
    offset: number[];
    progress: number;
    scrollLength: number;
    velocity: number;
    targetOffset: number;
    targetLength: number;
    containerLength: number;
    interpolatorOffsets?: number[];
    interpolate?: EasingFunction;
}
interface ScrollInfo {
    time: number;
    x: AxisScrollInfo;
    y: AxisScrollInfo;
}
type OnScrollInfo = (info: ScrollInfo) => void;
type SupportedEdgeUnit = "px" | "vw" | "vh" | "%";
type EdgeUnit = `${number}${SupportedEdgeUnit}`;
type NamedEdges = "start" | "end" | "center";
type EdgeString = NamedEdges | EdgeUnit | `${number}`;
type Edge = EdgeString | number;
type ProgressIntersection = [number, number];
type Intersection = `${Edge} ${Edge}`;
type ScrollOffset = Array<Edge | Intersection | ProgressIntersection>;
interface ScrollInfoOptions {
    container?: HTMLElement;
    target?: Element;
    axis?: "x" | "y";
    offset?: ScrollOffset;
    smooth?: number;
}

declare class GroupPlaybackControls implements AnimationPlaybackControls {
    animations: AnimationPlaybackControls[];
    constructor(animations: Array<AnimationPlaybackControls | undefined>);
    then(onResolve: VoidFunction, onReject?: VoidFunction): Promise<void>;
    /**
     * TODO: Filter out cancelled or stopped animations before returning
     */
    private getAll;
    private setAll;
    attachTimeline(timeline: any): () => void;
    get time(): number;
    set time(time: number);
    get speed(): number;
    set speed(speed: number);
    get startTime(): any;
    get duration(): number;
    private runAll;
    play(): void;
    pause(): void;
    stop: () => void;
    cancel(): void;
    complete(): void;
}

declare class ScrollTimeline implements ProgressTimeline {
    constructor(options: ScrollOptions);
    currentTime: null | {
        value: number;
    };
    cancel?: VoidFunction;
}
declare global {
    interface Window {
        ScrollTimeline: ScrollTimeline;
    }
}
declare function scroll(onScroll: OnScroll | GroupPlaybackControls, options?: ScrollOptions): VoidFunction;

declare function scrollInfo(onScroll: OnScrollInfo, { container, ...options }?: ScrollInfoOptions): () => void;

type ViewChangeHandler = (entry: IntersectionObserverEntry) => void;
type MarginValue = `${number}${'px' | '%'}`;
type MarginType = MarginValue | `${MarginValue} ${MarginValue}` | `${MarginValue} ${MarginValue} ${MarginValue}` | `${MarginValue} ${MarginValue} ${MarginValue} ${MarginValue}`;
interface InViewOptions {
    root?: Element | Document;
    margin?: MarginType;
    amount?: "some" | "all" | number;
}
declare function inView(elementOrSelector: ElementOrSelector, onStart: (entry: IntersectionObserverEntry) => void | ViewChangeHandler, { root, margin: rootMargin, amount }?: InViewOptions): VoidFunction;

declare const anticipate: (p: number) => number;

declare const backOut: (t: number) => number;
declare const backIn: EasingFunction;
declare const backInOut: EasingFunction;

declare const circIn: EasingFunction;
declare const circOut: EasingFunction;
declare const circInOut: EasingFunction;

declare const easeIn: (t: number) => number;
declare const easeOut: (t: number) => number;
declare const easeInOut: (t: number) => number;

declare function cubicBezier(mX1: number, mY1: number, mX2: number, mY2: number): (t: number) => number;

declare const mirrorEasing: EasingModifier;

declare const reverseEasing: EasingModifier;

type StaggerOrigin = "first" | "last" | "center" | number;
type StaggerOptions = {
    startDelay?: number;
    from?: StaggerOrigin;
    ease?: Easing;
};
declare function stagger(duration?: number, { startDelay, from, ease }?: StaggerOptions): DynamicOption<number>;

/**
 * @public
 */
interface TransformOptions<T> {
    /**
     * Clamp values to within the given range. Defaults to `true`
     *
     * @public
     */
    clamp?: boolean;
    /**
     * Easing functions to use on the interpolations between each value in the input and output ranges.
     *
     * If provided as an array, the array must be one item shorter than the input and output ranges, as the easings apply to the transition **between** each.
     *
     * @public
     */
    ease?: EasingFunction | EasingFunction[];
    /**
     * Provide a function that can interpolate between any two values in the provided range.
     *
     * @public
     */
    mixer?: (from: T, to: T) => (v: number) => any;
}
/**
 * Transforms numbers into other values by mapping them from an input range to an output range.
 * Returns the type of the input provided.
 *
 * @remarks
 *
 * Given an input range of `[0, 200]` and an output range of
 * `[0, 1]`, this function will return a value between `0` and `1`.
 * The input range must be a linear series of numbers. The output range
 * can be any supported value type, such as numbers, colors, shadows, arrays, objects and more.
 * Every value in the output range must be of the same type and in the same format.
 *
 * ```jsx
 * import * as React from "react"
 * import { transform } from "framer-motion"
 *
 * export function MyComponent() {
 *    const inputRange = [0, 200]
 *    const outputRange = [0, 1]
 *    const output = transform(100, inputRange, outputRange)
 *
 *    // Returns 0.5
 *    return <div>{output}</div>
 * }
 * ```
 *
 * @param inputValue - A number to transform between the input and output ranges.
 * @param inputRange - A linear series of numbers (either all increasing or decreasing).
 * @param outputRange - A series of numbers, colors, strings, or arrays/objects of those. Must be the same length as `inputRange`.
 * @param options - Clamp: Clamp values to within the given range. Defaults to `true`.
 *
 * @public
 */
declare function transform<T>(inputValue: number, inputRange: number[], outputRange: T[], options?: TransformOptions<T>): T;
/**
 *
 * Transforms numbers into other values by mapping them from an input range to an output range.
 *
 * Given an input range of `[0, 200]` and an output range of
 * `[0, 1]`, this function will return a value between `0` and `1`.
 * The input range must be a linear series of numbers. The output range
 * can be any supported value type, such as numbers, colors, shadows, arrays, objects and more.
 * Every value in the output range must be of the same type and in the same format.
 *
 * ```jsx
 * import * as React from "react"
 * import { Frame, transform } from "framer"
 *
 * export function MyComponent() {
 *     const inputRange = [-200, -100, 100, 200]
 *     const outputRange = [0, 1, 1, 0]
 *     const convertRange = transform(inputRange, outputRange)
 *     const output = convertRange(-150)
 *
 *     // Returns 0.5
 *     return <div>{output}</div>
 * }
 *
 * ```
 *
 * @param inputRange - A linear series of numbers (either all increasing or decreasing).
 * @param outputRange - A series of numbers, colors or strings. Must be the same length as `inputRange`.
 * @param options - Clamp: clamp values to within the given range. Defaults to `true`.
 *
 * @public
 */
declare function transform<T>(inputRange: number[], outputRange: T[], options?: TransformOptions<T>): (inputValue: number) => T;

declare const clamp: (min: number, max: number, v: number) => number;

type DelayedFunction = (overshoot: number) => void;
/**
 * Timeout defined in ms
 */
declare function delay(callback: DelayedFunction, timeout: number): () => void;

declare const distance: (a: number, b: number) => number;
declare function distance2D(a: Point, b: Point): number;

type DevMessage = (check: boolean, message: string) => void;
declare let warning: DevMessage;
declare let invariant: DevMessage;

type Mix<T> = (v: number) => T;
type MixerFactory<T> = (from: T, to: T) => Mix<T>;
interface InterpolateOptions<T> {
    clamp?: boolean;
    ease?: EasingFunction | EasingFunction[];
    mixer?: MixerFactory<T>;
}
/**
 * Create a function that maps from a numerical input array to a generic output array.
 *
 * Accepts:
 *   - Numbers
 *   - Colors (hex, hsl, hsla, rgb, rgba)
 *   - Complex (combinations of one or more numbers or strings)
 *
 * ```jsx
 * const mixColor = interpolate([0, 1], ['#fff', '#000'])
 *
 * mixColor(0.5) // 'rgba(128, 128, 128, 1)'
 * ```
 *
 * TODO Revist this approach once we've moved to data models for values,
 * probably not needed to pregenerate mixer functions.
 *
 * @public
 */
declare function interpolate<T>(input: number[], output: T[], { clamp: isClamp, ease, mixer }?: InterpolateOptions<T>): (v: number) => T;

type Mixer<T> = (p: number) => T;

declare function mix<T>(from: T, to: T): Mixer<T>;
declare function mix(from: number, to: number, p: number): number;

declare const pipe: (...transformers: Function[]) => Function;

declare const progress: (from: number, to: number, value: number) => number;

declare const wrap: (min: number, max: number, v: number) => number;

type Process = (data: FrameData) => void;
type Schedule = (process: Process, keepAlive?: boolean, immediate?: boolean) => Process;
interface Step {
    schedule: Schedule;
    cancel: (process: Process) => void;
    process: (data: FrameData) => void;
}
type StepId = "read" | "resolveKeyframes" | "update" | "preRender" | "render" | "postRender";
type Batcher = {
    [key in StepId]: Schedule;
};
type Steps = {
    [key in StepId]: Step;
};
interface FrameData {
    delta: number;
    timestamp: number;
    isProcessing: boolean;
}

declare const frame: Batcher;
declare const cancelFrame: (process: Process) => void;
declare const frameData: FrameData;
declare const steps: Steps;

/**
 * @deprecated
 *
 * Import as `frame` instead.
 */
declare const sync: Batcher;
/**
 * @deprecated
 *
 * Use cancelFrame(callback) instead.
 */
declare const cancelSync: Record<string, (process: Process) => void>;

declare const animations: FeaturePackages;

interface MotionContextProps<Instance = unknown> {
    visualElement?: VisualElement<Instance>;
    initial?: false | string | string[];
    animate?: string | string[];
}
declare const MotionContext: react.Context<MotionContextProps<unknown>>;

declare const createBox: () => Box;

declare function calcLength(axis: Axis): number;

declare function isDragActive(): boolean;

type EventListenerWithPointInfo = (e: PointerEvent, info: EventInfo) => void;
declare const addPointerInfo: (handler: EventListenerWithPointInfo) => EventListener;

declare function addPointerEvent(target: EventTarget, eventName: string, handler: EventListenerWithPointInfo, options?: AddEventListenerOptions): () => void;

declare const isMotionValue: (value: any) => value is MotionValue<any>;

declare const isBrowser: boolean;

declare function useUnmountEffect(callback: () => void): void;

declare const useIsomorphicLayoutEffect: typeof useEffect;

declare function useForceUpdate(): [VoidFunction, number];

/**
 * @public
 */
declare const domMin: FeatureBundle;

/**
 * @public
 */
declare const domAnimation: FeatureBundle;

/**
 * @public
 */
declare const domMax: FeatureBundle;

/**
 * Creates a `MotionValue` to track the state and velocity of a value.
 *
 * Usually, these are created automatically. For advanced use-cases, like use with `useTransform`, you can create `MotionValue`s externally and pass them into the animated component via the `style` prop.
 *
 * ```jsx
 * export const MyComponent = () => {
 *   const scale = useMotionValue(1)
 *
 *   return <motion.div style={{ scale }} />
 * }
 * ```
 *
 * @param initial - The initial state.
 *
 * @public
 */
declare function useMotionValue<T>(initial: T): MotionValue<T>;

/**
 * Combine multiple motion values into a new one using a string template literal.
 *
 * ```jsx
 * import {
 *   motion,
 *   useSpring,
 *   useMotionValue,
 *   useMotionTemplate
 * } from "framer-motion"
 *
 * function Component() {
 *   const shadowX = useSpring(0)
 *   const shadowY = useMotionValue(0)
 *   const shadow = useMotionTemplate`drop-shadow(${shadowX}px ${shadowY}px 20px rgba(0,0,0,0.3))`
 *
 *   return <motion.div style={{ filter: shadow }} />
 * }
 * ```
 *
 * @public
 */
declare function useMotionTemplate(fragments: TemplateStringsArray, ...values: Array<MotionValue | number | string>): MotionValue<string>;

/**
 * If the provided value is a MotionValue, this returns the actual value, otherwise just the value itself
 *
 * TODO: Remove and move to library
 */
declare function resolveMotionValue(value?: string | number | CustomValueType | MotionValue): string | number;

type InputRange = number[];
type SingleTransformer<I, O> = (input: I) => O;
type MultiTransformer<I, O> = (input: I[]) => O;
/**
 * Create a `MotionValue` that transforms the output of another `MotionValue` by mapping it from one range of values into another.
 *
 * @remarks
 *
 * Given an input range of `[-200, -100, 100, 200]` and an output range of
 * `[0, 1, 1, 0]`, the returned `MotionValue` will:
 *
 * - When provided a value between `-200` and `-100`, will return a value between `0` and  `1`.
 * - When provided a value between `-100` and `100`, will return `1`.
 * - When provided a value between `100` and `200`, will return a value between `1` and  `0`
 *
 *
 * The input range must be a linear series of numbers. The output range
 * can be any value type supported by Framer Motion: numbers, colors, shadows, etc.
 *
 * Every value in the output range must be of the same type and in the same format.
 *
 * ```jsx
 * export const MyComponent = () => {
 *   const x = useMotionValue(0)
 *   const xRange = [-200, -100, 100, 200]
 *   const opacityRange = [0, 1, 1, 0]
 *   const opacity = useTransform(x, xRange, opacityRange)
 *
 *   return (
 *     <motion.div
 *       animate={{ x: 200 }}
 *       style={{ opacity, x }}
 *     />
 *   )
 * }
 * ```
 *
 * @param inputValue - `MotionValue`
 * @param inputRange - A linear series of numbers (either all increasing or decreasing)
 * @param outputRange - A series of numbers, colors or strings. Must be the same length as `inputRange`.
 * @param options -
 *
 *  - clamp: boolean. Clamp values to within the given range. Defaults to `true`
 *  - ease: EasingFunction[]. Easing functions to use on the interpolations between each value in the input and output ranges. If provided as an array, the array must be one item shorter than the input and output ranges, as the easings apply to the transition between each.
 *
 * @returns `MotionValue`
 *
 * @public
 */
declare function useTransform<I, O>(value: MotionValue<number>, inputRange: InputRange, outputRange: O[], options?: TransformOptions<O>): MotionValue<O>;
/**
 * Create a `MotionValue` that transforms the output of another `MotionValue` through a function.
 * In this example, `y` will always be double `x`.
 *
 * ```jsx
 * export const MyComponent = () => {
 *   const x = useMotionValue(10)
 *   const y = useTransform(x, value => value * 2)
 *
 *   return <motion.div style={{ x, y }} />
 * }
 * ```
 *
 * @param input - A `MotionValue` that will pass its latest value through `transform` to update the returned `MotionValue`.
 * @param transform - A function that accepts the latest value from `input` and returns a new value.
 * @returns `MotionValue`
 *
 * @public
 */
declare function useTransform<I, O>(input: MotionValue<I>, transformer: SingleTransformer<I, O>): MotionValue<O>;
/**
 * Pass an array of `MotionValue`s and a function to combine them. In this example, `z` will be the `x` multiplied by `y`.
 *
 * ```jsx
 * export const MyComponent = () => {
 *   const x = useMotionValue(0)
 *   const y = useMotionValue(0)
 *   const z = useTransform([x, y], ([latestX, latestY]) => latestX * latestY)
 *
 *   return <motion.div style={{ x, y, z }} />
 * }
 * ```
 *
 * @param input - An array of `MotionValue`s that will pass their latest values through `transform` to update the returned `MotionValue`.
 * @param transform - A function that accepts the latest values from `input` and returns a new value.
 * @returns `MotionValue`
 *
 * @public
 */
declare function useTransform<I, O>(input: MotionValue<string>[] | MotionValue<number>[] | MotionValue<string | number>[], transformer: MultiTransformer<I, O>): MotionValue<O>;
declare function useTransform<I, O>(transformer: () => O): MotionValue<O>;

/**
 * Creates a `MotionValue` that, when `set`, will use a spring animation to animate to its new state.
 *
 * It can either work as a stand-alone `MotionValue` by initialising it with a value, or as a subscriber
 * to another `MotionValue`.
 *
 * @remarks
 *
 * ```jsx
 * const x = useSpring(0, { stiffness: 300 })
 * const y = useSpring(x, { damping: 10 })
 * ```
 *
 * @param inputValue - `MotionValue` or number. If provided a `MotionValue`, when the input `MotionValue` changes, the created `MotionValue` will spring towards that value.
 * @param springConfig - Configuration options for the spring.
 * @returns `MotionValue`
 *
 * @public
 */
declare function useSpring(source: MotionValue<string> | MotionValue<number> | number, config?: SpringOptions): MotionValue<number>;

/**
 * Creates a `MotionValue` that updates when the velocity of the provided `MotionValue` changes.
 *
 * ```javascript
 * const x = useMotionValue(0)
 * const xVelocity = useVelocity(x)
 * const xAcceleration = useVelocity(xVelocity)
 * ```
 *
 * @public
 */
declare function useVelocity(value: MotionValue<number>): MotionValue<number>;

interface UseScrollOptions extends Omit<ScrollInfoOptions, "container" | "target"> {
    container?: RefObject$1<HTMLElement>;
    target?: RefObject$1<HTMLElement>;
    layoutEffect?: boolean;
}
declare function useScroll({ container, target, layoutEffect, ...options }?: UseScrollOptions): {
    scrollX: MotionValue<number>;
    scrollY: MotionValue<number>;
    scrollXProgress: MotionValue<number>;
    scrollYProgress: MotionValue<number>;
};

/**
 * @deprecated useElementScroll is deprecated. Convert to useScroll({ container: ref })
 */
declare function useElementScroll(ref: RefObject$1<HTMLElement>): {
    scrollX: MotionValue<number>;
    scrollY: MotionValue<number>;
    scrollXProgress: MotionValue<number>;
    scrollYProgress: MotionValue<number>;
};

/**
 * @deprecated useViewportScroll is deprecated. Convert to useScroll()
 */
declare function useViewportScroll(): {
    scrollX: MotionValue<number>;
    scrollY: MotionValue<number>;
    scrollXProgress: MotionValue<number>;
    scrollYProgress: MotionValue<number>;
};

declare function useTime(): MotionValue<number>;

interface WillChange extends MotionValue {
    add(name: string): undefined | VoidFunction;
}

declare function useWillChange(): WillChange;

declare function useMotionValueEvent<V, EventName extends keyof MotionValueEventCallbacks<V>>(value: MotionValue<V>, event: EventName, callback: MotionValueEventCallbacks<V>[EventName]): void;

/**
 * A hook that returns `true` if we should be using reduced motion based on the current device's Reduced Motion setting.
 *
 * This can be used to implement changes to your UI based on Reduced Motion. For instance, replacing motion-sickness inducing
 * `x`/`y` animations with `opacity`, disabling the autoplay of background videos, or turning off parallax motion.
 *
 * It will actively respond to changes and re-render your components with the latest setting.
 *
 * ```jsx
 * export function Sidebar({ isOpen }) {
 *   const shouldReduceMotion = useReducedMotion()
 *   const closedX = shouldReduceMotion ? 0 : "-100%"
 *
 *   return (
 *     <motion.div animate={{
 *       opacity: isOpen ? 1 : 0,
 *       x: isOpen ? 0 : closedX
 *     }} />
 *   )
 * }
 * ```
 *
 * @return boolean
 *
 * @public
 */
declare function useReducedMotion(): boolean | null;

declare function useReducedMotionConfig(): boolean | null;

/**
 * @public
 */
declare function animationControls(): AnimationControls;

declare function useAnimate<T extends Element = any>(): [AnimationScope<T>, {
    <V>(from: V, to: V | GenericKeyframesTarget<V>, options?: ValueAnimationTransition<V> | undefined): AnimationPlaybackControls;
    <V_1>(value: MotionValue<V_1>, keyframes: V_1 | GenericKeyframesTarget<V_1>, options?: ValueAnimationTransition<V_1> | undefined): AnimationPlaybackControls;
    (value: ElementOrSelector, keyframes: DOMKeyframesDefinition, options?: DynamicAnimationOptions | undefined): AnimationPlaybackControls;
    (sequence: AnimationSequence, options?: SequenceOptions | undefined): AnimationPlaybackControls;
}];

/**
 * Creates `AnimationControls`, which can be used to manually start, stop
 * and sequence animations on one or more components.
 *
 * The returned `AnimationControls` should be passed to the `animate` property
 * of the components you want to animate.
 *
 * These components can then be animated with the `start` method.
 *
 * ```jsx
 * import * as React from 'react'
 * import { motion, useAnimation } from 'framer-motion'
 *
 * export function MyComponent(props) {
 *    const controls = useAnimation()
 *
 *    controls.start({
 *        x: 100,
 *        transition: { duration: 0.5 },
 *    })
 *
 *    return <motion.div animate={controls} />
 * }
 * ```
 *
 * @returns Animation controller with `start` and `stop` methods
 *
 * @public
 */
declare function useAnimationControls(): AnimationControls;
declare const useAnimation: typeof useAnimationControls;

type FrameCallback = (timestamp: number, delta: number) => void;
declare function useAnimationFrame(callback: FrameCallback): void;

declare function animateVisualElement(visualElement: VisualElement, definition: AnimationDefinition, options?: VisualElementAnimationOptions): Promise<void>;

type Cycle = (i?: number) => void;
type CycleState<T> = [T, Cycle];
/**
 * Cycles through a series of visual properties. Can be used to toggle between or cycle through animations. It works similar to `useState` in React. It is provided an initial array of possible states, and returns an array of two arguments.
 *
 * An index value can be passed to the returned `cycle` function to cycle to a specific index.
 *
 * ```jsx
 * import * as React from "react"
 * import { motion, useCycle } from "framer-motion"
 *
 * export const MyComponent = () => {
 *   const [x, cycleX] = useCycle(0, 50, 100)
 *
 *   return (
 *     <motion.div
 *       animate={{ x: x }}
 *       onTap={() => cycleX()}
 *      />
 *    )
 * }
 * ```
 *
 * @param items - items to cycle through
 * @returns [currentState, cycleState]
 *
 * @public
 */
declare function useCycle<T>(...items: T[]): CycleState<T>;

/**
 * Check whether a prop name is a valid `MotionProp` key.
 *
 * @param key - Name of the property to check
 * @returns `true` is key is a valid `MotionProp`.
 *
 * @public
 */
declare function isValidMotionProp(key: string): boolean;

type SafeToRemove = () => void;
type AlwaysPresent = [true, null];
type Present = [true];
type NotPresent = [false, SafeToRemove];
/**
 * When a component is the child of `AnimatePresence`, it can use `usePresence`
 * to access information about whether it's still present in the React tree.
 *
 * ```jsx
 * import { usePresence } from "framer-motion"
 *
 * export const Component = () => {
 *   const [isPresent, safeToRemove] = usePresence()
 *
 *   useEffect(() => {
 *     !isPresent && setTimeout(safeToRemove, 1000)
 *   }, [isPresent])
 *
 *   return <div />
 * }
 * ```
 *
 * If `isPresent` is `false`, it means that a component has been removed the tree, but
 * `AnimatePresence` won't really remove it until `safeToRemove` has been called.
 *
 * @public
 */
declare function usePresence(): AlwaysPresent | Present | NotPresent;
/**
 * Similar to `usePresence`, except `useIsPresent` simply returns whether or not the component is present.
 * There is no `safeToRemove` function.
 *
 * ```jsx
 * import { useIsPresent } from "framer-motion"
 *
 * export const Component = () => {
 *   const isPresent = useIsPresent()
 *
 *   useEffect(() => {
 *     !isPresent && console.log("I've been removed!")
 *   }, [isPresent])
 *
 *   return <div />
 * }
 * ```
 *
 * @public
 */
declare function useIsPresent(): boolean;

interface UseInViewOptions extends Omit<InViewOptions, "root" | "amount"> {
    root?: RefObject$1<Element>;
    once?: boolean;
    amount?: "some" | "all" | number;
}
declare function useInView(ref: RefObject$1<Element>, { root, margin, amount, once }?: UseInViewOptions): boolean;

/**
 * Attaches an event listener directly to the provided DOM element.
 *
 * Bypassing React's event system can be desirable, for instance when attaching non-passive
 * event handlers.
 *
 * ```jsx
 * const ref = useRef(null)
 *
 * useDomEvent(ref, 'wheel', onWheel, { passive: false })
 *
 * return <div ref={ref} />
 * ```
 *
 * @param ref - React.RefObject that's been provided to the element you want to bind the listener to.
 * @param eventName - Name of the event you want listen for.
 * @param handler - Function to fire when receiving the event.
 * @param options - Options to pass to `Event.addEventListener`.
 *
 * @public
 */
declare function useDomEvent(ref: RefObject$1<EventTarget>, eventName: string, handler?: EventListener | undefined, options?: AddEventListenerOptions): void;

interface MotionComponentConfig<Instance, RenderState> {
    preloadedFeatures?: FeatureBundle;
    createVisualElement?: CreateVisualElement<Instance>;
    useRender: RenderComponent<Instance, RenderState>;
    useVisualState: UseVisualState<Instance, RenderState>;
    Component: string | react.ComponentType<react.PropsWithChildren<unknown>>;
}
type MotionComponentProps<Props> = {
    [K in Exclude<keyof Props, keyof MotionProps>]?: Props[K];
} & MotionProps;
/**
 * Create a `motion` component.
 *
 * This function accepts a Component argument, which can be either a string (ie "div"
 * for `motion.div`), or an actual React component.
 *
 * Alongside this is a config option which provides a way of rendering the provided
 * component "offline", or outside the React render cycle.
 */
declare function createRendererMotionComponent<Props extends {}, Instance, RenderState>({ preloadedFeatures, createVisualElement, useRender, useVisualState, Component, }: MotionComponentConfig<Instance, RenderState>): react.ForwardRefExoticComponent<react.PropsWithoutRef<MotionComponentProps<Props>> & react.RefAttributes<Instance>>;

/**
 * Checks if a component is a `motion` component.
 */
declare function isMotionComponent(component: React.ComponentType | string): boolean;

/**
 * Unwraps a `motion` component and returns either a string for `motion.div` or
 * the React component for `motion(Component)`.
 *
 * If the component is not a `motion` component it returns undefined.
 */
declare function unwrapMotionComponent(component: React.ComponentType | string): React.ComponentType | string | undefined;

type ScaleCorrector = (latest: string | number, node: IProjectionNode) => string | number;
interface ScaleCorrectorDefinition {
    correct: ScaleCorrector;
    applyTo?: string[];
}
interface ScaleCorrectorMap {
    [key: string]: ScaleCorrectorDefinition;
}

declare function addScaleCorrector(correctors: ScaleCorrectorMap): void;

declare function useInstantTransition(): (callback: () => void) => void;
declare function disableInstantTransitions(): void;

declare function useInstantLayoutTransition(): (cb?: (() => void) | undefined) => void;

declare function useResetProjection(): () => void;

/**
 * Build a CSS transform style from individual x/y/scale etc properties.
 *
 * This outputs with a default order of transforms/scales/rotations, this can be customised by
 * providing a transformTemplate function.
 */
declare function buildTransform(latestValues: ResolvedValues$1, transform: HTMLRenderState["transform"], transformTemplate?: MotionProps["transformTemplate"]): string;

declare const visualElementStore: WeakMap<any, VisualElement<unknown, unknown, {}>>;

interface ValueAnimationOptionsWithDefaults<T extends string | number> extends ValueAnimationOptions<T> {
    autoplay: boolean;
    delay: number;
    repeat: number;
    repeatDelay: number;
    repeatType: RepeatType;
}
declare abstract class BaseAnimation<T extends string | number, Resolved> implements AnimationPlaybackControls {
    protected options: ValueAnimationOptionsWithDefaults<T>;
    protected resolveFinishedPromise: VoidFunction;
    protected currentFinishedPromise: Promise<void>;
    protected isStopped: boolean;
    protected _resolved: Resolved & {
        keyframes: ResolvedKeyframes<T>;
    };
    protected hasAttemptedResolve: boolean;
    protected resolver: KeyframeResolver<T>;
    private createdAt;
    private resolvedAt;
    constructor({ autoplay, delay, type, repeat, repeatDelay, repeatType, ...options }: ValueAnimationOptions<T>);
    /**
     * This method uses the createdAt and resolvedAt to calculate the
     * animation startTime. *Ideally*, we would use the createdAt time as t=0
     * as the following frame would then be the first frame of the animation in
     * progress, which would feel snappier.
     *
     * However, if there's a delay (main thread work) between the creation of
     * the animation and the first commited frame, we prefer to use resolvedAt
     * to avoid a sudden jump into the animation.
     */
    calcStartTime(): number;
    protected abstract initPlayback(keyframes: ResolvedKeyframes<T>, finalKeyframe?: T): Resolved | false;
    abstract play(): void;
    abstract pause(): void;
    abstract stop(): void;
    abstract cancel(): void;
    abstract complete(): void;
    abstract get speed(): number;
    abstract set speed(newSpeed: number);
    abstract get time(): number;
    abstract set time(newTime: number);
    abstract get duration(): number;
    abstract get state(): AnimationPlayState;
    abstract get startTime(): number | null;
    /**
     * A getter for resolved data. If keyframes are not yet resolved, accessing
     * this.resolved will synchronously flush all pending keyframe resolvers.
     * This is a deoptimisation, but at its worst still batches read/writes.
     */
    get resolved(): (Resolved & {
        keyframes: ResolvedKeyframes<T>;
        finalKeyframe?: T;
    }) | undefined;
    /**
     * A method to be called when the keyframes resolver completes. This method
     * will check if its possible to run the animation and, if not, skip it.
     * Otherwise, it will call initPlayback on the implementing class.
     */
    protected onKeyframesResolved(keyframes: ResolvedKeyframes<T>, finalKeyframe?: T): void;
    onPostResolved(): void;
    /**
     * Allows the returned animation to be awaited or promise-chained. Currently
     * resolves when the animation finishes at all but in a future update could/should
     * reject if its cancels.
     */
    then(resolve: VoidFunction, reject?: VoidFunction): Promise<void>;
    protected updateFinishedPromise(): void;
}

interface AnimationState<V> {
    value: V;
    done: boolean;
}
interface KeyframeGenerator<V> {
    calculatedDuration: null | number;
    next: (t: number) => AnimationState<V>;
}

interface ResolvedData<T extends string | number> {
    generator: KeyframeGenerator<T>;
    mirroredGenerator: KeyframeGenerator<T> | undefined;
    mapPercentToKeyframes: ((v: number) => T) | undefined;
    /**
     * Duration of the animation as calculated by the generator.
     */
    calculatedDuration: number;
    /**
     * Duration of the animation plus repeatDelay.
     */
    resolvedDuration: number;
    /**
     * Total duration of the animation including repeats.
     */
    totalDuration: number;
}
/**
 * Animation that runs on the main thread. Designed to be WAAPI-spec in the subset of
 * features we expose publically. Mostly the compatibility is to ensure visual identity
 * between both WAAPI and main thread animations.
 */
declare class MainThreadAnimation<T extends string | number> extends BaseAnimation<T, ResolvedData<T>> {
    /**
     * The driver that's controlling the animation loop. Normally this is a requestAnimationFrame loop
     * but in tests we can pass in a synchronous loop.
     */
    private driver?;
    /**
     * The time at which the animation was paused.
     */
    private holdTime;
    /**
     * The time at which the animation was cancelled.
     */
    private cancelTime;
    /**
     * The current time of the animation.
     */
    private currentTime;
    /**
     * Playback speed as a factor. 0 would be stopped, -1 reverse and 2 double speed.
     */
    private playbackSpeed;
    /**
     * The state of the animation to apply when the animation is resolved. This
     * allows calls to the public API to control the animation before it is resolved,
     * without us having to resolve it first.
     */
    private pendingPlayState;
    /**
     * The time at which the animation was started.
     */
    startTime: number | null;
    constructor(options: ValueAnimationOptions<T>);
    protected initPlayback(keyframes: ResolvedKeyframes<T>): {
        generator: KeyframeGenerator<any>;
        mirroredGenerator: KeyframeGenerator<T> | undefined;
        mapPercentToKeyframes: ((v: number) => T) | undefined;
        calculatedDuration: number;
        resolvedDuration: number;
        totalDuration: number;
    };
    onPostResolved(): void;
    tick(timestamp: number, sample?: boolean): {
        done: boolean;
        value: T;
    };
    state: AnimationPlayState;
    get duration(): number;
    get time(): number;
    set time(newTime: number);
    get speed(): number;
    set speed(newSpeed: number);
    play(): void;
    pause(): void;
    /**
     * This method is bound to the instance to fix a pattern where
     * animation.stop is returned as a reference from a useEffect.
     */
    stop: () => void;
    complete(): void;
    finish(): void;
    cancel(): void;
    private teardown;
    private stopDriver;
    sample(time: number): AnimationState<T>;
}
declare function animateValue(options: ValueAnimationOptions<any>): MainThreadAnimation<any>;

type Transformer = (v: any) => any;
type ValueType = {
    test: (v: any) => boolean;
    parse: (v: any) => any;
    transform?: Transformer;
    createTransformer?: (template: string) => Transformer;
    default?: any;
    getAnimatableNone?: (v: any) => any;
};
type RGBA = {
    red: number;
    green: number;
    blue: number;
    alpha: number;
};
type HSLA = {
    hue: number;
    saturation: number;
    lightness: number;
    alpha: number;
};
type Color = HSLA | RGBA;

declare const color: {
    test: (v: any) => boolean;
    parse: (v: any) => RGBA | HSLA;
    transform: (v: HSLA | RGBA | string) => string;
};

type CSSVariableName = `--${string}`;
type CSSVariableToken = `var(${CSSVariableName})`;

declare function test(v: any): boolean;
type ComplexValues = Array<CSSVariableToken | string | number | Color>;
declare function parseComplexValue(v: string | number): ComplexValues;
declare function createTransformer(source: string | number): (v: Array<CSSVariableToken | Color | number | string>) => string;
declare function getAnimatableNone(v: string | number): string;
declare const complex: {
    test: typeof test;
    parse: typeof parseComplexValue;
    createTransformer: typeof createTransformer;
    getAnimatableNone: typeof getAnimatableNone;
};

declare const px: {
    test: (v: string | number) => boolean;
    parse: typeof parseFloat;
    transform: (v: number | string) => string;
};

declare const MotionGlobalConfig: {
    skipAnimations: boolean;
    useManualTiming: boolean;
};

interface AcceleratedValueAnimationOptions<T extends string | number = number> extends ValueAnimationOptions<T> {
    name: string;
    motionValue: MotionValue<T>;
}
interface ResolvedAcceleratedAnimation {
    animation: Animation;
    duration: number;
    times: ValueAnimationOptions["times"];
    type: ValueAnimationOptions["type"];
    ease: ValueAnimationOptions["ease"];
    keyframes: string[] | number[];
}
declare class AcceleratedAnimation<T extends string | number> extends BaseAnimation<T, ResolvedAcceleratedAnimation> {
    protected options: ValueAnimationOptionsWithDefaults<T> & {
        name: string;
        motionValue: MotionValue<T>;
    };
    constructor(options: ValueAnimationOptions<T>);
    /**
     * An AnimationTimline to attach to the WAAPI animation once it's created.
     */
    private pendingTimeline;
    protected initPlayback(keyframes: ResolvedKeyframes<T>, finalKeyframe: T): false | {
        animation: Animation;
        duration: number;
        times: number[] | undefined;
        type: "keyframes" | "spring" | "decay" | "tween" | "inertia" | undefined;
        ease: Easing | Easing[] | undefined;
        keyframes: number[] | string[];
    };
    get duration(): number;
    get time(): number;
    set time(newTime: number);
    get speed(): number;
    set speed(newSpeed: number);
    get state(): AnimationPlayState;
    get startTime(): number | null;
    /**
     * Replace the default DocumentTimeline with another AnimationTimeline.
     * Currently used for scroll animations.
     */
    attachTimeline(timeline: any): (any: void) => void;
    play(): void;
    pause(): void;
    stop(): void;
    complete(): void;
    cancel(): void;
    static supports(options: ValueAnimationOptions): options is AcceleratedValueAnimationOptions;
}

interface NativeAnimationOptions {
    delay?: number;
    duration?: number;
    ease?: Easing | Easing[];
    times?: number[];
    repeat?: number;
    repeatType?: "loop" | "reverse" | "mirror";
}

declare const optimizedAppearDataAttribute: "data-framer-appear-id";

/**
 * Expose only the needed part of the VisualElement interface to
 * ensure React types don't end up in the generic DOM bundle.
 */
interface WithAppearProps {
    props: {
        [optimizedAppearDataAttribute]?: string;
        values?: {
            [key: string]: MotionValue<number> | MotionValue<string>;
        };
    };
}
type HandoffFunction = (storeId: string, valueName: string, frame: Batcher) => number | null;
/**
 * The window global object acts as a bridge between our inline script
 * triggering the optimized appear animations, and Framer Motion.
 */
declare global {
    interface Window {
        MotionHandoffAnimation?: HandoffFunction;
        MotionHandoffIsComplete?: boolean;
        MotionHasOptimisedAnimation?: (elementId?: string, valueName?: string) => boolean;
        MotionCancelOptimisedAnimation?: (elementId?: string, valueName?: string, frame?: Batcher, canResume?: boolean) => void;
        MotionCheckAppearSync?: (visualElement: WithAppearProps, valueName: string, value: MotionValue) => VoidFunction | void;
    }
}

declare function startOptimizedAppearAnimation(element: HTMLElement, name: string, keyframes: string[] | number[], options: NativeAnimationOptions, onReady?: (animation: Animation) => void): void;

declare function spring({ keyframes, restDelta, restSpeed, ...options }: ValueAnimationOptions<number>): KeyframeGenerator<number>;

interface NodeGroup {
    add: (node: IProjectionNode) => void;
    remove: (node: IProjectionNode) => void;
    dirty: VoidFunction;
}

interface LayoutGroupContextProps {
    id?: string;
    group?: NodeGroup;
    forceRender?: VoidFunction;
}
declare const LayoutGroupContext: react.Context<LayoutGroupContextProps>;

type DOMMotionComponents = HTMLMotionComponents & SVGMotionComponents;

/**
 * @public
 */
interface ScrollMotionValues {
    scrollX: MotionValue<number>;
    scrollY: MotionValue<number>;
    scrollXProgress: MotionValue<number>;
    scrollYProgress: MotionValue<number>;
}

/**
 * Note: Still used by components generated by old versions of Framer
 *
 * @deprecated
 */
declare const DeprecatedLayoutGroupContext: react.Context<string | null>;

/**
 * This is not an officially supported API and may be removed
 * on any version.
 */
declare function useAnimatedState(initialState: any): any[];

interface ScaleMotionValues {
    scaleX: MotionValue<number>;
    scaleY: MotionValue<number>;
}
/**
 * Returns a `MotionValue` each for `scaleX` and `scaleY` that update with the inverse
 * of their respective parent scales.
 *
 * This is useful for undoing the distortion of content when scaling a parent component.
 *
 * By default, `useInvertedScale` will automatically fetch `scaleX` and `scaleY` from the nearest parent.
 * By passing other `MotionValue`s in as `useInvertedScale({ scaleX, scaleY })`, it will invert the output
 * of those instead.
 *
 * ```jsx
 * const MyComponent = () => {
 *   const { scaleX, scaleY } = useInvertedScale()
 *   return <motion.div style={{ scaleX, scaleY }} />
 * }
 * ```
 *
 * @deprecated
 */
declare function useInvertedScale(scale?: Partial<ScaleMotionValues>): ScaleMotionValues;

declare const AnimateSharedLayout: react.FunctionComponent<react.PropsWithChildren<unknown>>;

export { type AbsoluteKeyframe, AcceleratedAnimation, AnimatePresence, type AnimatePresenceProps, AnimateSharedLayout, type AnimationControls, type AnimationDefinition, type AnimationLifecycles, type AnimationOptionsWithValueOverrides, type AnimationPlaybackControls, type AnimationPlaybackLifecycles, type AnimationPlaybackOptions, type AnimationProps, type AnimationScope, type AnimationSequence, type AnimationType, type At, type Axis, type AxisDelta, type BezierDefinition, type BoundingBox, type Box, type CSSStyleDeclarationWithTransform, type CreateVisualElement, type CustomValueType, type Cycle, type CycleState, type DOMKeyframesDefinition, type DOMMotionComponents, type DOMSegment, type DOMSegmentWithTransition, type DecayOptions, type DelayedFunction, type Delta, DeprecatedLayoutGroupContext, type DevMessage, DragControls, type DragElastic, type DragHandlers, type DraggableProps, type DurationSpringOptions, type DynamicAnimationOptions, type DynamicOption, type Easing, type EasingDefinition, type EasingFunction, type EasingModifier, type ElementOrSelector, type EventInfo, type FeatureBundle, type FeatureDefinition, type FeatureDefinitions, type FeaturePackage, type FeaturePackages, FlatTree, type FocusHandlers, type ForwardRefComponent, type HTMLMotionProps, type HoverHandlers, type HydratedFeatureDefinition, type HydratedFeatureDefinitions, type IProjectionNode, type Inertia, type InertiaOptions$1 as InertiaOptions, type InterpolateOptions, type KeyframeOptions, type Keyframes, type KeyframesTarget, LayoutGroup, LayoutGroupContext, type LayoutProps, type LazyFeatureBundle$1 as LazyFeatureBundle, LazyMotion, type LazyProps, type MixerFactory, type MotionAdvancedProps, MotionConfig, MotionConfigContext, type MotionConfigProps, MotionContext, MotionGlobalConfig, type MotionProps, type MotionStyle$2 as MotionStyle, type MotionTransform, MotionValue, type MotionValueSegment, type MotionValueSegmentWithTransition, type None, type Orchestration, type PanHandlers, type PanInfo, type PassiveEffect, type Point, PresenceContext, type RelayoutInfo, type RenderComponent, namespace_d as Reorder, type Repeat, type RepeatType, type ResolveKeyframes, type ResolveLayoutTransition, type ResolvedAnimationDefinition, type ResolvedAnimationDefinitions, type ResolvedKeyframesTarget, type ResolvedSingleTarget, type ResolvedValueTarget, type ResolvedValues$1 as ResolvedValues, type SVGAttributesAsMotionValues, type SVGKeyframesDefinition, type SVGMotionProps, type SVGPathKeyframesDefinition, type SVGPathTransitions, type SVGTransitions, type ScrapeMotionValuesFromProps, type ScrollMotionValues, type Segment, type SequenceLabel, type SequenceLabelWithTime, type SequenceMap, type SequenceOptions, type SequenceTime, type SingleTarget, type Spring, type SpringOptions, type StyleKeyframesDefinition, type StyleTransitions, type Subscriber, SwitchLayoutGroupContext, type TapHandlers, type TapInfo, type Target, type TargetAndTransition, type TransformPoint, type Transition$1 as Transition, type Tween, type UnresolvedValueKeyframe, type UseInViewOptions, type UseScrollOptions, type ValueAnimationOptions, type ValueAnimationTransition, type ValueKeyframe, type ValueKeyframesDefinition, type ValueSequence, type ValueTarget, type ValueType, type VariableKeyframesDefinition, type VariableTransitions, type Variant, type VariantLabels, type Variants, type VelocityOptions, VisualElement, type VisualState, addPointerEvent, addPointerInfo, addScaleCorrector, animate, animateValue, animateVisualElement, animationControls, animations, anticipate, backIn, backInOut, backOut, buildTransform, calcLength, cancelFrame, cancelSync, circIn, circInOut, circOut, clamp, color, complex, createBox, createMinimalMotionComponent, createMotionComponent, createRendererMotionComponent, createScopedAnimate, cubicBezier, delay, disableInstantTransitions, distance, distance2D, domAnimation, domMax, domMin, easeIn, easeInOut, easeOut, filterProps, frame, frameData, inView, interpolate, invariant, isBrowser, isDragActive, isMotionComponent, isMotionValue, isValidMotionProp, namespace_d$1 as m, makeUseVisualState, mirrorEasing, mix, namespace_d$2 as motion, motionValue, optimizedAppearDataAttribute, pipe, progress, px, resolveMotionValue, reverseEasing, scroll, scrollInfo, spring, stagger, startOptimizedAppearAnimation, steps, sync, transform, unwrapMotionComponent, useAnimate, useAnimation, useAnimationControls, useAnimationFrame, useCycle, useAnimatedState as useDeprecatedAnimatedState, useInvertedScale as useDeprecatedInvertedScale, useDomEvent, useDragControls, useElementScroll, useForceUpdate, useInView, useInstantLayoutTransition, useInstantTransition, useIsPresent, useIsomorphicLayoutEffect, useMotionTemplate, useMotionValue, useMotionValueEvent, usePresence, useReducedMotion, useReducedMotionConfig, useResetProjection, useScroll, useSpring, useTime, useTransform, useUnmountEffect, useVelocity, useViewportScroll, useWillChange, visualElementStore, warning, wrap };
